@@ -262,6 +262,12 @@ public abstract class AbstractBDBMessageStore implements MessageStore
         return true;
     }
 
+    @Override
+    public void resetStatistics()
+    {
+        _bytesEvacuatedFromMemory.set(0L);
+    }
+
     @Override
     public org.apache.qpid.server.store.Transaction newTransaction()
     {
@@ -491,7 +497,7 @@ public abstract class AbstractBDBMessageStore implements MessageStore
             getLogger().info("Lock conflict exception. Retrying (attempt {} of {})", attempts, LOCK_RETRY_ATTEMPTS);
             try
             {
-                Thread.sleep(500l + (long)(500l * _lockConflictRandom.nextDouble()));
+                Thread.sleep(500L + (long)(500L * _lockConflictRandom.nextDouble()));
             }
             catch (InterruptedException ie)
             {
@@ -1327,11 +1333,12 @@ public abstract class AbstractBDBMessageStore implements MessageStore
 
     private class BDBTransaction implements org.apache.qpid.server.store.Transaction
     {
-        private Transaction _txn;
-        private int _storeSizeIncrease;
+        private final Transaction _txn;
         private final List<Runnable> _preCommitActions = new ArrayList<>();
         private final List<Runnable> _postCommitActions = new ArrayList<>();
 
+        private int _storeSizeIncrease;
+
         private BDBTransaction() throws StoreException
         {
             try
