@@ -83,9 +83,8 @@ import org.apache.qpid.test.utils.VirtualHostNodeStoreType;
 public class BDBHAVirtualHostNodeTest extends UnitTestBase
 {
     private final static Logger LOGGER = LoggerFactory.getLogger(BDBHAVirtualHostNodeTest.class);
-
+    private final PortHelper _portHelper = new PortHelper();
     private BDBHAVirtualHostNodeTestHelper _helper;
-    private PortHelper _portHelper = new PortHelper();
 
     @Before
     public void setUp() throws Exception
@@ -826,7 +825,7 @@ public class BDBHAVirtualHostNodeTest extends UnitTestBase
         int waitCounter = 100;
         while ( remote.getLastKnownReplicationTransactionId() != node1.getLastKnownReplicationTransactionId() && (waitCounter--) != 0)
         {
-            Thread.sleep(100l);
+            Thread.sleep(100L);
         }
         assertEquals("Last transaction was not replicated",
                             Long.valueOf(remote.getLastKnownReplicationTransactionId()),
