@@ -69,7 +69,7 @@ import org.apache.qpid.test.utils.VirtualHostNodeStoreType;
  */
 public class BDBMessageStoreTest extends MessageStoreTestCase
 {
-    private static byte[] CONTENT_BYTES = new byte[] {0, 1, 2, 3, 4, 5, 6, 7, 8, 9};
+    private static final byte[] CONTENT_BYTES = new byte[] {0, 1, 2, 3, 4, 5, 6, 7, 8, 9};
 
     private String _storeLocation;
 
