@@ -23,6 +23,10 @@ package org.apache.qpid.server.store.berkeleydb.replication;
 import static org.apache.qpid.server.store.berkeleydb.EnvironmentFacade.JUL_LOGGER_LEVEL_OVERRIDE;
 import static org.apache.qpid.server.store.berkeleydb.EnvironmentFacade.LOG_HANDLER_CLEANER_PROTECTED_FILES_LIMIT_PROPERTY_NAME;
 import static org.apache.qpid.server.store.berkeleydb.replication.ReplicatedEnvironmentFacade.*;
+import static org.apache.qpid.server.virtualhost.berkeleydb.BDBVirtualHost.DEFAULT_QPID_BROKER_BDB_COMMITER_NOTIFY_THRESHOLD;
+import static org.apache.qpid.server.virtualhost.berkeleydb.BDBVirtualHost.DEFAULT_QPID_BROKER_BDB_COMMITER_WAIT_TIMEOUT;
+import static org.apache.qpid.server.virtualhost.berkeleydb.BDBVirtualHost.QPID_BROKER_BDB_COMMITER_NOTIFY_THRESHOLD;
+import static org.apache.qpid.server.virtualhost.berkeleydb.BDBVirtualHost.QPID_BROKER_BDB_COMMITER_WAIT_TIMEOUT;
 import static org.hamcrest.CoreMatchers.equalTo;
 import static org.hamcrest.CoreMatchers.is;
 import static org.junit.Assert.assertEquals;
@@ -36,6 +40,7 @@ import static org.junit.Assume.assumeThat;
 import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.ArgumentMatchers.anyBoolean;
 import static org.mockito.ArgumentMatchers.anyInt;
+import static org.mockito.ArgumentMatchers.anyLong;
 import static org.mockito.ArgumentMatchers.anyString;
 import static org.mockito.ArgumentMatchers.eq;
 import static org.mockito.Mockito.mock;
@@ -95,14 +100,11 @@ import org.apache.qpid.test.utils.TestFileUtils;
 import org.apache.qpid.test.utils.UnitTestBase;
 import org.apache.qpid.test.utils.VirtualHostNodeStoreType;
 
-
 public class ReplicatedEnvironmentFacadeTest extends UnitTestBase
 {
     private static final Logger LOGGER = LoggerFactory.getLogger(ReplicatedEnvironmentFacadeTest.class);
-    private int _timeout = 30;
 
     private final PortHelper _portHelper = new PortHelper();
-
     private final String TEST_GROUP_NAME = "testGroupName";
     private final String TEST_NODE_NAME = "testNodeName";
     private final int TEST_NODE_PORT = _portHelper.getNextAvailable();
@@ -112,11 +114,12 @@ public class ReplicatedEnvironmentFacadeTest extends UnitTestBase
     private final boolean TEST_DESIGNATED_PRIMARY = false;
     private final int TEST_PRIORITY = 1;
     private final int TEST_ELECTABLE_GROUP_OVERRIDE = 0;
-
-    private File _storePath;
     private final Map<String, ReplicatedEnvironmentFacade> _nodes = new HashMap<String, ReplicatedEnvironmentFacade>();
+    private final CopyOnWriteArrayList<Throwable> _unhandledExceptions = new CopyOnWriteArrayList<>();
+
+    private int _timeout = 30;
+    private File _storePath;
     private Thread.UncaughtExceptionHandler _defaultUncaughtExceptionHandler;
-    private CopyOnWriteArrayList<Throwable> _unhandledExceptions = new CopyOnWriteArrayList<>();
 
     @Before
     public void setUp() throws Exception
@@ -549,13 +552,15 @@ public class ReplicatedEnvironmentFacadeTest extends UnitTestBase
     public void testRemoveNodeFromGroup() throws Exception
     {
         TestStateChangeListener stateChangeListener = new TestStateChangeListener();
-        ReplicatedEnvironmentFacade environmentFacade = addNode(TEST_NODE_NAME, TEST_NODE_HOST_PORT, true, stateChangeListener, new NoopReplicationGroupListener());
+        ReplicatedEnvironmentFacade environmentFacade = addNode(TEST_NODE_NAME, TEST_NODE_HOST_PORT, true, stateChangeListener,
+                                                                new NoopReplicationGroupListener());
         assertTrue("Environment was not created", stateChangeListener.awaitForStateChange(State.MASTER,
                                                                                           _timeout, TimeUnit.SECONDS));
 
         String node2Name = TEST_NODE_NAME + "_2";
         String node2NodeHostPort = "localhost:" + _portHelper.getNextAvailable();
-        ReplicatedEnvironmentFacade ref2 = createReplica(node2Name, node2NodeHostPort, new NoopReplicationGroupListener());
+        ReplicatedEnvironmentFacade ref2 = createReplica(node2Name, node2NodeHostPort,
+                                                         new NoopReplicationGroupListener());
 
         assertEquals("Unexpected group members count",
                      (long) 2,
@@ -648,7 +653,8 @@ public class ReplicatedEnvironmentFacadeTest extends UnitTestBase
         int replica1Port = _portHelper.getNextAvailable();
         String node1NodeHostPort = "localhost:" + replica1Port;
         masterEnvironment.setPermittedNodes(Arrays.asList(masterEnvironment.getHostPort(), node1NodeHostPort));
-        ReplicatedEnvironmentFacade replica = createReplica(replicaName, node1NodeHostPort, new NoopReplicationGroupListener());
+        ReplicatedEnvironmentFacade replica = createReplica(replicaName, node1NodeHostPort,
+                                                            new NoopReplicationGroupListener());
 
         assertTrue("Node should be added", nodeAddedLatch.await(_timeout, TimeUnit.SECONDS));
 
@@ -717,7 +723,8 @@ public class ReplicatedEnvironmentFacadeTest extends UnitTestBase
         // make sure that node is re-elected as MASTER on second start-up
         ReplicatedEnvironmentConfiguration config = createReplicatedEnvironmentConfiguration(TEST_NODE_NAME, TEST_NODE_HOST_PORT, TEST_DESIGNATED_PRIMARY);
         when(config.getPriority()).thenReturn(2);
-        createReplicatedEnvironmentFacade(TEST_NODE_NAME, stateChangeListener, new NoopReplicationGroupListener(), config);
+        createReplicatedEnvironmentFacade(TEST_NODE_NAME, stateChangeListener,
+                                          new NoopReplicationGroupListener(), config);
 
         assertTrue("Master was not started", masterLatch.await(_timeout, TimeUnit.SECONDS));
 
@@ -726,8 +733,10 @@ public class ReplicatedEnvironmentFacadeTest extends UnitTestBase
         int replica2Port = _portHelper.getNextAvailable();
         String node2NodeHostPort = "localhost:" + replica2Port;
 
-        ReplicatedEnvironmentFacade replica1 = createReplica(TEST_NODE_NAME + "_1", node1NodeHostPort, new NoopReplicationGroupListener());
-        ReplicatedEnvironmentFacade replica2 = createReplica(TEST_NODE_NAME + "_2", node2NodeHostPort, new NoopReplicationGroupListener());
+        ReplicatedEnvironmentFacade replica1 = createReplica(TEST_NODE_NAME + "_1", node1NodeHostPort,
+                                                             new NoopReplicationGroupListener());
+        ReplicatedEnvironmentFacade replica2 = createReplica(TEST_NODE_NAME + "_2", node2NodeHostPort,
+                                                             new NoopReplicationGroupListener());
 
         // close replicas
         replica1.close();
@@ -776,7 +785,8 @@ public class ReplicatedEnvironmentFacadeTest extends UnitTestBase
 
         int replica1Port = _portHelper.getNextAvailable();
         String node1NodeHostPort = "localhost:" + replica1Port;
-        ReplicatedEnvironmentFacade secondNode = createReplica(TEST_NODE_NAME + "_1", node1NodeHostPort, new NoopReplicationGroupListener());
+        ReplicatedEnvironmentFacade secondNode = createReplica(TEST_NODE_NAME + "_1", node1NodeHostPort,
+                                                               new NoopReplicationGroupListener());
         assertEquals("Unexpected state", State.REPLICA.name(), secondNode.getNodeState());
 
         int replica2Port = _portHelper.getNextAvailable();
@@ -800,7 +810,8 @@ public class ReplicatedEnvironmentFacadeTest extends UnitTestBase
             }
         };
         ReplicatedEnvironmentFacade thirdNode = addNode(TEST_NODE_NAME + "_2", node2NodeHostPort, TEST_DESIGNATED_PRIMARY,
-                                                        testStateChangeListener, new NoopReplicationGroupListener());
+                                                        testStateChangeListener,
+                                                        new NoopReplicationGroupListener());
         assertTrue("Environment did not become a replica", replicaStateLatch.await(_timeout, TimeUnit.SECONDS));
         assertEquals((long) 3, (long) thirdNode.getNumberOfElectableGroupMembers());
 
@@ -838,7 +849,8 @@ public class ReplicatedEnvironmentFacadeTest extends UnitTestBase
 
         int replica1Port = _portHelper.getNextAvailable();
         String node1NodeHostPort = "localhost:" + replica1Port;
-        ReplicatedEnvironmentFacade secondNode = createReplica(TEST_NODE_NAME + "_1", node1NodeHostPort, new NoopReplicationGroupListener());
+        ReplicatedEnvironmentFacade secondNode = createReplica(TEST_NODE_NAME + "_1", node1NodeHostPort,
+                                                               new NoopReplicationGroupListener());
         assertEquals("Unexpected state", State.REPLICA.name(), secondNode.getNodeState());
 
         int replica2Port = _portHelper.getNextAvailable();
@@ -971,13 +983,15 @@ public class ReplicatedEnvironmentFacadeTest extends UnitTestBase
         DatabaseConfig createConfig = createDatabaseConfig();
 
         TestStateChangeListener masterListener = new TestStateChangeListener();
-        ReplicatedEnvironmentFacade node1 = addNode(TEST_NODE_NAME, TEST_NODE_HOST_PORT, true, masterListener, new NoopReplicationGroupListener());
+        ReplicatedEnvironmentFacade node1 = addNode(TEST_NODE_NAME, TEST_NODE_HOST_PORT, true, masterListener,
+                                                    new NoopReplicationGroupListener());
         assertTrue("Environment was not created", masterListener.awaitForStateChange(State.MASTER,
                                                                                      _timeout, TimeUnit.SECONDS));
 
         String replicaNodeHostPort = "localhost:" + _portHelper.getNextAvailable();
         String replicaName = TEST_NODE_NAME + 1;
-        ReplicatedEnvironmentFacade node2 = createReplica(replicaName, replicaNodeHostPort, new NoopReplicationGroupListener());
+        ReplicatedEnvironmentFacade node2 = createReplica(replicaName, replicaNodeHostPort,
+                                                          new NoopReplicationGroupListener());
 
         Database db = node1.openDatabase("mydb", createConfig);
 
@@ -997,7 +1011,8 @@ public class ReplicatedEnvironmentFacadeTest extends UnitTestBase
         LOGGER.debug("RESTARTING " + replicaName);
         // Restart the node2, making it primary so it becomes master
         TestStateChangeListener node2StateChangeListener = new TestStateChangeListener();
-        node2 = addNode(replicaName, replicaNodeHostPort, true, node2StateChangeListener, new NoopReplicationGroupListener());
+        node2 = addNode(replicaName, replicaNodeHostPort, true, node2StateChangeListener,
+                        new NoopReplicationGroupListener());
         boolean awaitForStateChange = node2StateChangeListener.awaitForStateChange(State.MASTER,
                                                                                    _timeout, TimeUnit.SECONDS);
         assertTrue(replicaName + " did not go into desired state; current actual state is "
@@ -1044,7 +1059,8 @@ public class ReplicatedEnvironmentFacadeTest extends UnitTestBase
         int port = _portHelper.getNextAvailable();
         String node2NodeHostPort = host + ":" + port;
 
-        final ReplicatedEnvironmentFacade replica = createReplica(nodeName2, node2NodeHostPort, new NoopReplicationGroupListener() );
+        final ReplicatedEnvironmentFacade replica = createReplica(nodeName2, node2NodeHostPort,
+                                                                  new NoopReplicationGroupListener());
 
         // close the master
         master.close();
@@ -1082,7 +1098,8 @@ public class ReplicatedEnvironmentFacadeTest extends UnitTestBase
         int port = _portHelper.getNextAvailable();
         String node2NodeHostPort = host + ":" + port;
 
-        final ReplicatedEnvironmentFacade replica = createReplica(nodeName2, node2NodeHostPort, new NoopReplicationGroupListener() );
+        final ReplicatedEnvironmentFacade replica = createReplica(nodeName2, node2NodeHostPort,
+                                                                  new NoopReplicationGroupListener());
 
         // close the master
         master.close();
@@ -1127,8 +1144,10 @@ public class ReplicatedEnvironmentFacadeTest extends UnitTestBase
 
         master.setPermittedNodes(Arrays.asList(master.getHostPort(), node1NodeHostPort, node2NodeHostPort));
 
-        ReplicatedEnvironmentFacade replica1 = createReplica(TEST_NODE_NAME + "_1", node1NodeHostPort, new NoopReplicationGroupListener());
-        ReplicatedEnvironmentFacade replica2 = createReplica(TEST_NODE_NAME + "_2", node2NodeHostPort, new NoopReplicationGroupListener());
+        ReplicatedEnvironmentFacade replica1 = createReplica(TEST_NODE_NAME + "_1", node1NodeHostPort,
+                                                             new NoopReplicationGroupListener());
+        ReplicatedEnvironmentFacade replica2 = createReplica(TEST_NODE_NAME + "_2", node2NodeHostPort,
+                                                             new NoopReplicationGroupListener());
 
         replica1.close();
         replica2.close();
@@ -1174,7 +1193,8 @@ public class ReplicatedEnvironmentFacadeTest extends UnitTestBase
 
         master.setPermittedNodes(Arrays.asList(master.getHostPort(), replicaNodeHostPort));
 
-        ReplicatedEnvironmentFacade replica1 = createReplica(TEST_NODE_NAME + "_1", replicaNodeHostPort, new NoopReplicationGroupListener());
+        ReplicatedEnvironmentFacade replica1 = createReplica(TEST_NODE_NAME + "_1", replicaNodeHostPort,
+                                                             new NoopReplicationGroupListener());
         replica1.close();
 
         assertTrue("Node that was master did not become detached after the replica closed",
@@ -1369,7 +1389,7 @@ public class ReplicatedEnvironmentFacadeTest extends UnitTestBase
     }
     private ReplicatedEnvironmentFacade createMaster(final boolean disableCoalescing) throws Exception
     {
-        return createMaster(new NoopReplicationGroupListener(),disableCoalescing);
+        return createMaster(new NoopReplicationGroupListener(), disableCoalescing);
     }
     private ReplicatedEnvironmentFacade createMaster(ReplicationGroupListener replicationGroupListener) throws Exception
     {
@@ -1477,6 +1497,13 @@ public class ReplicatedEnvironmentFacadeTest extends UnitTestBase
         when(node.getFacadeParameter(eq(Boolean.class),
                                      eq(DISABLE_COALESCING_COMMITTER_PROPERTY_NAME),
                                      anyBoolean())).thenReturn(disableCoalescing);
+        when(node.getFacadeParameter(eq(Integer.class),
+                                     eq(QPID_BROKER_BDB_COMMITER_NOTIFY_THRESHOLD),
+                                     anyInt())).thenReturn(DEFAULT_QPID_BROKER_BDB_COMMITER_NOTIFY_THRESHOLD);
+        when(node.getFacadeParameter(eq(Long.class),
+                                     eq(QPID_BROKER_BDB_COMMITER_WAIT_TIMEOUT),
+                                     anyLong())).thenReturn(DEFAULT_QPID_BROKER_BDB_COMMITER_WAIT_TIMEOUT);
+
         Map<String, String> repConfig = new HashMap<>();
         repConfig.put(ReplicationConfig.REPLICA_ACK_TIMEOUT, "2 s");
         repConfig.put(ReplicationConfig.INSUFFICIENT_REPLICAS_TIMEOUT, "2 s");
@@ -1485,7 +1512,7 @@ public class ReplicatedEnvironmentFacadeTest extends UnitTestBase
         return node;
     }
 
-    class NoopReplicationGroupListener implements ReplicationGroupListener
+    static class NoopReplicationGroupListener implements ReplicationGroupListener
     {
 
         @Override
