@@ -27,7 +27,7 @@ import static org.hamcrest.CoreMatchers.instanceOf;
 import static org.hamcrest.CoreMatchers.is;
 import static org.hamcrest.CoreMatchers.nullValue;
 import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertThat;
+import static org.hamcrest.MatcherAssert.assertThat;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
 
@@ -368,9 +368,6 @@ public class MultiNodeTest extends GroupJmsTestBase
                                               final int activeBrokerPort,
                                               final int inactiveBrokerPort) throws Exception
     {
-        LOGGER.info("Transfer mastership to {} from {}",
-                    getBrokerAdmin().getMemberByAmqpPort(inactiveBrokerPort),
-                    getBrokerAdmin().getMemberByAmqpPort(activeBrokerPort));
         _failoverListener = new FailoverAwaitingListener();
         getJmsProvider().addGenericConnectionListener(connection, _failoverListener);
 
@@ -580,7 +577,7 @@ public class MultiNodeTest extends GroupJmsTestBase
                         LOGGER.info("Active connection port {}", activeBrokerPort);
 
                         List<Integer> inactivePorts = new ArrayList<>(ports);
-                        inactivePorts.remove(new Integer(activeBrokerPort));
+                        inactivePorts.remove(Integer.valueOf(activeBrokerPort));
 
                         final CountDownLatch latch = new CountDownLatch(inactivePorts.size());
                         for (int port : inactivePorts)
@@ -721,14 +718,14 @@ public class MultiNodeTest extends GroupJmsTestBase
 
             Map<String, Object> attributes = getBrokerAdmin().getNodeAttributes(activeBrokerPort);
             assertEquals("Broker has unexpected quorum override",
-                         new Integer(0),
+                         Integer.valueOf(0),
                          attributes.get(BDBHAVirtualHostNode.QUORUM_OVERRIDE));
             getBrokerAdmin().setNodeAttributes(activeBrokerPort,
                                                Collections.singletonMap(BDBHAVirtualHostNode.QUORUM_OVERRIDE, 1));
 
             attributes = getBrokerAdmin().getNodeAttributes(activeBrokerPort);
             assertEquals("Broker has unexpected quorum override",
-                         new Integer(1),
+                         Integer.valueOf(1),
                          attributes.get(BDBHAVirtualHostNode.QUORUM_OVERRIDE));
 
             _failoverListener.awaitFailoverCompletion(FAILOVER_COMPLETION_TIMEOUT);
