@@ -30,6 +30,7 @@ import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
+import java.util.Objects;
 import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentMap;
@@ -104,8 +105,30 @@ public abstract class AbstractExchange<T extends AbstractExchange<T>>
             new FixedKeyMapCreator("bindingKey", "destination");
 
     private static final Operation PUBLISH_ACTION = Operation.PERFORM_ACTION("publish");
+
     private final AtomicBoolean _closed = new AtomicBoolean();
 
+    private final Set<DestinationReferrer> _referrers =
+            Collections.newSetFromMap(new ConcurrentHashMap<DestinationReferrer, Boolean>());
+
+    private final QueueManagingVirtualHost<?> _virtualHost;
+
+    //The logSubject for ths exchange
+    private final LogSubject _logSubject;
+
+    private final AtomicLong _receivedMessageCount = new AtomicLong();
+    private final AtomicLong _receivedMessageSize = new AtomicLong();
+    private final AtomicLong _routedMessageCount = new AtomicLong();
+    private final AtomicLong _routedMessageSize = new AtomicLong();
+    private final AtomicLong _droppedMessageCount = new AtomicLong();
+    private final AtomicLong _droppedMessageSize = new AtomicLong();
+    private final AtomicLong _producerCount = new AtomicLong();
+
+    private final List<Binding> _bindings = new CopyOnWriteArrayList<>();
+
+    private final ConcurrentMap<MessageSender, Integer> _linkedSenders = new ConcurrentHashMap<>();
+    private final List<Action<? super Deletable<?>>> _deleteTaskList = new CopyOnWriteArrayList<>();
+
     @ManagedAttributeField(beforeSet = "preSetAlternateBinding", afterSet = "postSetAlternateBinding" )
     private AlternateBinding _alternateBinding;
     @ManagedAttributeField
@@ -113,28 +136,11 @@ public abstract class AbstractExchange<T extends AbstractExchange<T>>
     @ManagedAttributeField
     private CreatingLinkInfo _creatingLinkInfo;
 
-    private QueueManagingVirtualHost<?> _virtualHost;
-
     /**
      * Whether the exchange is automatically deleted once all queues have detached from it
      */
     private boolean _autoDelete;
 
-    //The logSubject for ths exchange
-    private LogSubject _logSubject;
-    private final Set<DestinationReferrer> _referrers = Collections.newSetFromMap(new ConcurrentHashMap<DestinationReferrer,Boolean>());
-
-    private final AtomicLong _receivedMessageCount = new AtomicLong();
-    private final AtomicLong _receivedMessageSize = new AtomicLong();
-    private final AtomicLong _routedMessageCount = new AtomicLong();
-    private final AtomicLong _routedMessageSize = new AtomicLong();
-    private final AtomicLong _droppedMessageCount = new AtomicLong();
-    private final AtomicLong _droppedMessageSize = new AtomicLong();
-
-    private final List<Binding> _bindings = new CopyOnWriteArrayList<>();
-
-    private final ConcurrentMap<MessageSender, Integer> _linkedSenders = new ConcurrentHashMap<>();
-    private final List<Action<? super Deletable<?>>> _deleteTaskList = new CopyOnWriteArrayList<>();
     private volatile MessageDestination _alternateBindingDestination;
 
     public AbstractExchange(Map<String, Object> attributes, QueueManagingVirtualHost<?> vhost)
@@ -142,7 +148,7 @@ public abstract class AbstractExchange<T extends AbstractExchange<T>>
         super(vhost, attributes);
         Set<String> providedAttributeNames = new HashSet<>(attributes.keySet());
         providedAttributeNames.removeAll(getAttributeNames());
-        if(!providedAttributeNames.isEmpty())
+        if (!providedAttributeNames.isEmpty())
         {
             throw new IllegalArgumentException("Unknown attributes provided: " + providedAttributeNames);
         }
@@ -156,7 +162,7 @@ public abstract class AbstractExchange<T extends AbstractExchange<T>>
     {
         super.onValidate();
 
-        if(!isSystemProcess())
+        if (!isSystemProcess())
         {
             if (isReservedExchangeName(getName()))
             {
@@ -172,11 +178,11 @@ public abstract class AbstractExchange<T extends AbstractExchange<T>>
 
         validateOrCreateAlternateBinding(((Exchange<?>) proxyForValidation), false);
 
-        if (changedAttributes.contains(ConfiguredObject.DESIRED_STATE) && proxyForValidation.getDesiredState() == State.DELETED)
+        if (changedAttributes.contains(ConfiguredObject.DESIRED_STATE) &&
+            proxyForValidation.getDesiredState() == State.DELETED)
         {
             doChecks();
         }
-
     }
 
     private boolean isReservedExchangeName(String name)
@@ -191,7 +197,8 @@ public abstract class AbstractExchange<T extends AbstractExchange<T>>
         super.validateOnCreate();
         if (getCreatingLinkInfo() != null && !isSystemProcess())
         {
-            throw new IllegalConfigurationException(String.format("Cannot specify creatingLinkInfo for exchange '%s'", getName()));
+            throw new IllegalConfigurationException(String.format("Cannot specify creatingLinkInfo for exchange '%s'",
+                                                                  getName()));
         }
     }
 
@@ -207,7 +214,10 @@ public abstract class AbstractExchange<T extends AbstractExchange<T>>
     {
         super.onOpen();
         final ConfiguredDerivedMethodAttribute<Exchange<?>, Collection<Binding>> durableBindingsAttribute =
-                (ConfiguredDerivedMethodAttribute<Exchange<?>, Collection<Binding>>) getModel().getTypeRegistry().getAttributeTypes(getTypeClass()).get(DURABLE_BINDINGS);
+                (ConfiguredDerivedMethodAttribute<Exchange<?>, Collection<Binding>>) getModel().getTypeRegistry()
+                                                                                               .getAttributeTypes(
+                                                                                                       getTypeClass())
+                                                                                               .get(DURABLE_BINDINGS);
         final Collection<Binding> bindings =
                 durableBindingsAttribute.convertValue(getActualAttributes().get(DURABLE_BINDINGS), this);
         if (bindings != null)
@@ -218,7 +228,8 @@ public abstract class AbstractExchange<T extends AbstractExchange<T>>
                 final MessageDestination messageDestination = getOpenedMessageDestination(b.getDestination());
                 if (messageDestination != null)
                 {
-                    Map<String, Object> arguments = b.getArguments() == null ? Collections.emptyMap() : b.getArguments();
+                    Map<String, Object> arguments =
+                            b.getArguments() == null ? Collections.emptyMap() : b.getArguments();
                     try
                     {
                         onBind(new BindingIdentifier(b.getBindingKey(), messageDestination), arguments);
@@ -239,11 +250,13 @@ public abstract class AbstractExchange<T extends AbstractExchange<T>>
                 final LinkModel link;
                 if (_creatingLinkInfo.isSendingLink())
                 {
-                    link = _virtualHost.getSendingLink(_creatingLinkInfo.getRemoteContainerId(), _creatingLinkInfo.getLinkName());
+                    link = _virtualHost.getSendingLink(_creatingLinkInfo.getRemoteContainerId(),
+                                                       _creatingLinkInfo.getLinkName());
                 }
                 else
                 {
-                    link = _virtualHost.getReceivingLink(_creatingLinkInfo.getRemoteContainerId(), _creatingLinkInfo.getLinkName());
+                    link = _virtualHost.getReceivingLink(_creatingLinkInfo.getRemoteContainerId(),
+                                                         _creatingLinkInfo.getLinkName());
                 }
                 addLifetimeConstraint(link);
             }
@@ -265,7 +278,9 @@ public abstract class AbstractExchange<T extends AbstractExchange<T>>
             }
             else
             {
-                LOGGER.warn("Cannot find alternate binding destination '{}' for exchange '{}'", alternateDestination, toString());
+                LOGGER.warn("Cannot find alternate binding destination '{}' for exchange '{}'",
+                            alternateDestination,
+                            toString());
             }
         }
     }
@@ -307,19 +322,19 @@ public abstract class AbstractExchange<T extends AbstractExchange<T>>
 
     private void performDelete()
     {
-        if(_closed.compareAndSet(false,true))
+        if (_closed.compareAndSet(false, true))
         {
             performDeleteTasks();
 
-            for(Binding b : _bindings)
+            for (Binding b : _bindings)
             {
                 final MessageDestination messageDestination = getAttainedMessageDestination(b.getDestination());
-                if(messageDestination != null)
+                if (messageDestination != null)
                 {
                     messageDestination.linkRemoved(this, b);
                 }
             }
-            for(MessageSender sender : _linkedSenders.keySet())
+            for (MessageSender sender : _linkedSenders.keySet())
             {
                 sender.destinationRemoved(this);
             }
@@ -333,12 +348,12 @@ public abstract class AbstractExchange<T extends AbstractExchange<T>>
 
     private void doChecks()
     {
-        if(hasReferrers())
+        if (hasReferrers())
         {
             throw new MessageDestinationIsAlternateException(getName());
         }
 
-        if(isReservedExchangeName(getName()))
+        if (isReservedExchangeName(getName()))
         {
             throw new RequiredExchangeException(getName());
         }
@@ -346,13 +361,13 @@ public abstract class AbstractExchange<T extends AbstractExchange<T>>
 
     @Override
     @DoOnConfigThread
-    public void destinationRemoved(@Param(name="destination") final MessageDestination destination)
+    public void destinationRemoved(@Param(name = "destination") final MessageDestination destination)
     {
         Iterator<Binding> bindingIterator = _bindings.iterator();
-        while(bindingIterator.hasNext())
+        while (bindingIterator.hasNext())
         {
             Binding b = bindingIterator.next();
-            if(b.getDestination().equals(destination.getName()))
+            if (b.getDestination().equals(destination.getName()))
             {
                 final Map<String, Object> bindArguments =
                         UNBIND_ARGUMENTS_CREATOR.createMap(b.getBindingKey(), destination);
@@ -361,7 +376,7 @@ public abstract class AbstractExchange<T extends AbstractExchange<T>>
                 _bindings.remove(b);
             }
         }
-        if(!autoDeleteIfNecessary())
+        if (!autoDeleteIfNecessary())
         {
             if (destination.isDurable() && isDurable())
             {
@@ -380,7 +395,7 @@ public abstract class AbstractExchange<T extends AbstractExchange<T>>
     @Override
     public String toString()
     {
-        return getClass().getSimpleName() + "[" + getName() +"]";
+        return getClass().getSimpleName() + "[" + getName() + "]";
     }
 
     @Override
@@ -390,19 +405,19 @@ public abstract class AbstractExchange<T extends AbstractExchange<T>>
     }
 
     @Override
-    public boolean isBound(String bindingKey, Map<String,Object> arguments, Queue<?> queue)
+    public boolean isBound(String bindingKey, Map<String, Object> arguments, Queue<?> queue)
     {
         if (bindingKey == null)
         {
             bindingKey = "";
         }
-        for(Binding b : _bindings)
+        for (Binding b : _bindings)
         {
-            if(bindingKey.equals(b.getBindingKey()) && queue.getName().equals(b.getDestination()))
+            if (bindingKey.equals(b.getBindingKey()) && queue.getName().equals(b.getDestination()))
             {
                 return (b.getArguments() == null || b.getArguments().isEmpty())
-                       ? (arguments == null || arguments.isEmpty())
-                       : b.getArguments().equals(arguments);
+                        ? (arguments == null || arguments.isEmpty())
+                        : b.getArguments().equals(arguments);
             }
         }
         return false;
@@ -416,9 +431,9 @@ public abstract class AbstractExchange<T extends AbstractExchange<T>>
             bindingKey = "";
         }
 
-        for(Binding b : _bindings)
+        for (Binding b : _bindings)
         {
-            if(bindingKey.equals(b.getBindingKey()) && queue.getName().equals(b.getDestination()))
+            if (bindingKey.equals(b.getBindingKey()) && queue.getName().equals(b.getDestination()))
             {
                 return true;
             }
@@ -434,9 +449,9 @@ public abstract class AbstractExchange<T extends AbstractExchange<T>>
             bindingKey = "";
         }
 
-        for(Binding b : _bindings)
+        for (Binding b : _bindings)
         {
-            if(bindingKey.equals(b.getBindingKey()))
+            if (bindingKey.equals(b.getBindingKey()))
             {
                 return true;
             }
@@ -447,9 +462,9 @@ public abstract class AbstractExchange<T extends AbstractExchange<T>>
     @Override
     public boolean isBound(Queue<?> queue)
     {
-        for(Binding b : _bindings)
+        for (Binding b : _bindings)
         {
-            if(queue.getName().equals(b.getDestination()))
+            if (queue.getName().equals(b.getDestination()))
             {
                 return true;
             }
@@ -460,12 +475,12 @@ public abstract class AbstractExchange<T extends AbstractExchange<T>>
     @Override
     public boolean isBound(Map<String, Object> arguments, Queue<?> queue)
     {
-        for(Binding b : _bindings)
+        for (Binding b : _bindings)
         {
-            if(queue.getName().equals(b.getDestination()) &&
-               ((b.getArguments() == null || b.getArguments().isEmpty())
-                       ? (arguments == null || arguments.isEmpty())
-                       : b.getArguments().equals(arguments)))
+            if (queue.getName().equals(b.getDestination()) &&
+                ((b.getArguments() == null || b.getArguments().isEmpty())
+                        ? (arguments == null || arguments.isEmpty())
+                        : b.getArguments().equals(arguments)))
             {
                 return true;
             }
@@ -476,11 +491,11 @@ public abstract class AbstractExchange<T extends AbstractExchange<T>>
     @Override
     public boolean isBound(Map<String, Object> arguments)
     {
-        for(Binding b : _bindings)
+        for (Binding b : _bindings)
         {
-            if(((b.getArguments() == null || b.getArguments().isEmpty())
-                                   ? (arguments == null || arguments.isEmpty())
-                                   : b.getArguments().equals(arguments)))
+            if (((b.getArguments() == null || b.getArguments().isEmpty())
+                    ? (arguments == null || arguments.isEmpty())
+                    : b.getArguments().equals(arguments)))
             {
                 return true;
             }
@@ -497,12 +512,12 @@ public abstract class AbstractExchange<T extends AbstractExchange<T>>
             bindingKey = "";
         }
 
-        for(Binding b : _bindings)
+        for (Binding b : _bindings)
         {
-            if(b.getBindingKey().equals(bindingKey) &&
-               ((b.getArguments() == null || b.getArguments().isEmpty())
-                       ? (arguments == null || arguments.isEmpty())
-                       : b.getArguments().equals(arguments)))
+            if (b.getBindingKey().equals(bindingKey) &&
+                ((b.getArguments() == null || b.getArguments().isEmpty())
+                        ? (arguments == null || arguments.isEmpty())
+                        : b.getArguments().equals(arguments)))
             {
                 return true;
             }
@@ -533,7 +548,7 @@ public abstract class AbstractExchange<T extends AbstractExchange<T>>
     @SuppressWarnings("unused")
     private void postSetAlternateBinding()
     {
-        if(_alternateBinding != null)
+        if (_alternateBinding != null)
         {
             _alternateBindingDestination = getOpenedMessageDestination(_alternateBinding.getDestination());
             if (_alternateBindingDestination != null)
@@ -586,6 +601,11 @@ public abstract class AbstractExchange<T extends AbstractExchange<T>>
         return getBindings().size();
     }
 
+    @Override
+    public long getProducerCount()
+    {
+        return _producerCount.get();
+    }
 
     @Override
     public <M extends ServerMessage<? extends StorableMessageMetaData>> RoutingResult<M> route(final M message,
@@ -654,7 +674,7 @@ public abstract class AbstractExchange<T extends AbstractExchange<T>>
         }
         finally
         {
-            if(topLevel)
+            if (topLevel)
             {
                 CURRENT_ROUTING.set(null);
             }
@@ -663,9 +683,9 @@ public abstract class AbstractExchange<T extends AbstractExchange<T>>
 
 
     protected abstract <M extends ServerMessage<? extends StorableMessageMetaData>> void doRoute(final M message,
-                                    final String routingAddress,
-                                    final InstanceProperties instanceProperties,
-                                    final RoutingResult<M> result);
+                                                                                                 final String routingAddress,
+                                                                                                 final InstanceProperties instanceProperties,
+                                                                                                 final RoutingResult<M> result);
 
     @Override
     public boolean bind(final String destination,
@@ -694,7 +714,7 @@ public abstract class AbstractExchange<T extends AbstractExchange<T>>
             throw new IllegalArgumentException(String.format("Destination '%s' is not found.", destination));
         }
 
-        if(arguments == null)
+        if (arguments == null)
         {
             arguments = Collections.emptyMap();
         }
@@ -702,7 +722,7 @@ public abstract class AbstractExchange<T extends AbstractExchange<T>>
         Binding newBinding = new BindingImpl(bindingKey, destination, arguments);
 
         Binding previousBinding = null;
-        for(Binding b : _bindings)
+        for (Binding b : _bindings)
         {
             if (b.getBindingKey().equals(bindingKey) && b.getDestination().equals(messageDestination.getName()))
             {
@@ -716,9 +736,8 @@ public abstract class AbstractExchange<T extends AbstractExchange<T>>
             return false;
         }
 
-
         final BindingIdentifier bindingIdentifier = new BindingIdentifier(bindingKey, messageDestination);
-        if(previousBinding != null)
+        if (previousBinding != null)
         {
             onBindingUpdated(bindingIdentifier, arguments);
         }
@@ -737,7 +756,7 @@ public abstract class AbstractExchange<T extends AbstractExchange<T>>
             _bindings.remove(previousBinding);
         }
         _bindings.add(newBinding);
-        if(isDurable() && messageDestination.isDurable())
+        if (isDurable() && messageDestination.isDurable())
         {
             final Collection<Binding> durableBindings = getDurableBindings();
             attributeSet(DURABLE_BINDINGS, durableBindings, durableBindings);
@@ -750,9 +769,9 @@ public abstract class AbstractExchange<T extends AbstractExchange<T>>
     {
         List<Binding> bindings = new ArrayList<>();
         final String destinationName = destination.getName();
-        for(Binding b : _bindings)
+        for (Binding b : _bindings)
         {
-            if(b.getDestination().equals(destinationName))
+            if (b.getDestination().equals(destinationName))
             {
                 bindings.add(b);
             }
@@ -764,13 +783,13 @@ public abstract class AbstractExchange<T extends AbstractExchange<T>>
     public Collection<Binding> getDurableBindings()
     {
         List<Binding> durableBindings;
-        if(isDurable())
+        if (isDurable())
         {
             durableBindings = new ArrayList<>();
             for (Binding b : _bindings)
             {
                 MessageDestination destination = getAttainedMessageDestination(b.getDestination());
-                if(destination != null && destination.isDurable())
+                if (destination != null && destination.isDurable())
                 {
                     durableBindings.add(b);
                 }
@@ -798,12 +817,12 @@ public abstract class AbstractExchange<T extends AbstractExchange<T>>
     private MessageDestination getOpenedMessageDestination(final String name)
     {
         MessageDestination destination = getVirtualHost().getSystemDestination(name);
-        if(destination == null)
+        if (destination == null)
         {
             destination = getVirtualHost().getChildByName(Exchange.class, name);
         }
-
-        if(destination == null)
+        // handle same exchange and queue name (QPID-8572)
+        if (destination == null || Objects.equals(this, destination))
         {
             destination = getVirtualHost().getChildByName(Queue.class, name);
         }
@@ -843,7 +862,6 @@ public abstract class AbstractExchange<T extends AbstractExchange<T>>
             }
         }
         return false;
-
     }
 
     @Override
@@ -912,13 +930,14 @@ public abstract class AbstractExchange<T extends AbstractExchange<T>>
 
     private boolean isAutoDeletePending()
     {
-        return (getLifetimePolicy() == LifetimePolicy.DELETE_ON_NO_OUTBOUND_LINKS || getLifetimePolicy() == LifetimePolicy.DELETE_ON_NO_LINKS )
-            && getBindingCount() == 0;
+        return (getLifetimePolicy() == LifetimePolicy.DELETE_ON_NO_OUTBOUND_LINKS ||
+                getLifetimePolicy() == LifetimePolicy.DELETE_ON_NO_LINKS) &&
+               getBindingCount() == 0;
     }
 
 
     @SuppressWarnings("unused")
-    @StateTransition(currentState = {State.UNINITIALIZED,State.ERRORED}, desiredState = State.ACTIVE)
+    @StateTransition(currentState = {State.UNINITIALIZED, State.ERRORED}, desiredState = State.ACTIVE)
     private ListenableFuture<Void> activate()
     {
         setState(State.ACTIVE);
@@ -1029,13 +1048,14 @@ public abstract class AbstractExchange<T extends AbstractExchange<T>>
     @Override
     public void linkAdded(final MessageSender sender, final PublishingLink link)
     {
-        Integer oldValue = _linkedSenders.putIfAbsent(sender, 1);
-        if(oldValue != null)
+        final Integer oldValue = _linkedSenders.putIfAbsent(sender, 1);
+        if (oldValue != null)
         {
-            _linkedSenders.put(sender, oldValue+1);
+            _linkedSenders.put(sender, oldValue + 1);
         }
-        if( link.TYPE_LINK.equals(link.getType()))
+        if (link.TYPE_LINK.equals(link.getType()))
         {
+            _producerCount.incrementAndGet();
             getEventLogger().message(SenderMessages.CREATE(link.getName(), link.getDestination()));
         }
     }
@@ -1043,17 +1063,25 @@ public abstract class AbstractExchange<T extends AbstractExchange<T>>
     @Override
     public void linkRemoved(final MessageSender sender, final PublishingLink link)
     {
-        int oldValue = _linkedSenders.remove(sender);
-        if(oldValue != 1)
+        final int oldValue = _linkedSenders.remove(sender);
+        if (oldValue != 1)
         {
-            _linkedSenders.put(sender, oldValue-1);
+            _linkedSenders.put(sender, oldValue - 1);
         }
-        if( link.TYPE_LINK.equals(link.getType()))
+        if (link.TYPE_LINK.equals(link.getType()))
         {
+            _producerCount.decrementAndGet();
             getEventLogger().message(SenderMessages.CLOSE(link.getName(), link.getDestination()));
         }
     }
 
+    @Override
+    public void close()
+    {
+        _producerCount.set(0);
+        super.close();
+    }
+
     private void validateOrCreateAlternateBinding(final Exchange<?> exchange, final boolean mayCreate)
     {
         Object value = exchange.getAttribute(ALTERNATE_BINDING);
@@ -1083,44 +1111,37 @@ public abstract class AbstractExchange<T extends AbstractExchange<T>>
         }
     }
 
+    @Override
+    public void resetStatistics()
+    {
+        _receivedMessageCount.set(0);
+        _receivedMessageSize.set(0);
+        _routedMessageCount.set(0);
+        _routedMessageSize.set(0);
+        _droppedMessageCount.set(0);
+        _droppedMessageSize.set(0);
+    }
+
     @Override
     protected void logCreated(final Map<String, Object> attributes,
                               final Outcome outcome)
     {
-        if (outcome == Outcome.SUCCESS)
-        {
-            getEventLogger().message(_logSubject, ExchangeMessages.CREATED(getType(), getName(), isDurable()));
-        }
-        else
-        {
-            super.logCreated(attributes, outcome);
-        }
+        getEventLogger().message(_logSubject,
+                                 ExchangeMessages.CREATE(getName(),
+                                                         String.valueOf(outcome),
+                                                         attributesAsString(attributes)));
     }
 
     @Override
     protected void logRecovered(final Outcome outcome)
     {
-        if (outcome == Outcome.SUCCESS)
-        {
-            getEventLogger().message(_logSubject, ExchangeMessages.CREATED(getType(), getName(), isDurable()));
-        }
-        else
-        {
-            super.logRecovered(outcome);
-        }
+        getEventLogger().message(_logSubject, ExchangeMessages.OPEN(getName(), String.valueOf(outcome)));
     }
 
     @Override
     protected void logDeleted(final Outcome outcome)
     {
-        if (outcome == Outcome.SUCCESS)
-        {
-            getEventLogger().message(_logSubject, ExchangeMessages.DELETED());
-        }
-        else
-        {
-            super.logDeleted(outcome);
-        }
+        getEventLogger().message(_logSubject, ExchangeMessages.DELETE(getName(), String.valueOf(outcome)));
     }
 
     @Override
@@ -1131,4 +1152,4 @@ public abstract class AbstractExchange<T extends AbstractExchange<T>>
                                                          String.valueOf(outcome),
                                                          attributesAsString(attributes)));
     }
-}
+}
\ No newline at end of file
