@@ -65,6 +65,7 @@ import org.apache.qpid.server.configuration.IllegalConfigurationException;
 import org.apache.qpid.server.configuration.updater.TaskExecutor;
 import org.apache.qpid.server.configuration.updater.TaskExecutorImpl;
 import org.apache.qpid.server.logging.messages.BrokerMessages;
+import org.apache.qpid.server.model.port.AmqpPort;
 import org.apache.qpid.server.model.preferences.Preference;
 import org.apache.qpid.server.model.preferences.UserPreferences;
 import org.apache.qpid.server.model.preferences.UserPreferencesImpl;
@@ -98,11 +99,8 @@ public class BrokerImpl extends AbstractContainer<BrokerImpl> implements Broker<
 {
     private static final Logger LOGGER = LoggerFactory.getLogger(BrokerImpl.class);
     private static final Logger DIRECT_MEMORY_USAGE_LOGGER = LoggerFactory.getLogger("org.apache.qpid.server.directMemory.broker");
-
     private static final Pattern MODEL_VERSION_PATTERN = Pattern.compile("^\\d+\\.\\d+$");
-
     private static final int HOUSEKEEPING_SHUTDOWN_TIMEOUT = 5;
-
     public static final String MANAGEMENT_MODE_AUTHENTICATION = "MANAGEMENT_MODE_AUTHENTICATION";
 
     private final Thread _shutdownHook = new Thread(new ShutdownService(), "QpidBrokerShutdownHook");
@@ -112,8 +110,6 @@ public class BrokerImpl extends AbstractContainer<BrokerImpl> implements Broker<
 
     private final BrokerPrincipal _principal;
 
-    private AuthenticationProvider<?> _managementModeAuthenticationProvider;
-
     private final AtomicLong _messagesIn = new AtomicLong();
     private final AtomicLong _messagesOut = new AtomicLong();
     private final AtomicLong _transactedMessagesIn = new AtomicLong();
@@ -121,6 +117,11 @@ public class BrokerImpl extends AbstractContainer<BrokerImpl> implements Broker<
     private final AtomicLong _bytesIn = new AtomicLong();
     private final AtomicLong _bytesOut = new AtomicLong();
     private final AtomicLong _maximumMessageSize = new AtomicLong();
+    private final boolean _virtualHostPropertiesNodeEnabled;
+    private final AddressSpaceRegistry _addressSpaceRegistry = new AddressSpaceRegistry();
+    private final ConfigurationChangeListener _accessControlProviderListener = new AccessControlProviderListener();
+    private final AccessControl _accessControl;
+    private final AtomicBoolean _directMemoryExceedsThresholdReported = new AtomicBoolean();
 
     @ManagedAttributeField
     private int _shutdownTimeout;
@@ -129,14 +130,10 @@ public class BrokerImpl extends AbstractContainer<BrokerImpl> implements Broker<
     @ManagedAttributeField
     private boolean _messageCompressionEnabled;
 
+    private AuthenticationProvider<?> _managementModeAuthenticationProvider;
     private PreferenceStore _preferenceStore;
-
-    private final boolean _virtualHostPropertiesNodeEnabled;
     private Collection<BrokerLogger> _brokerLoggersToClose;
     private int _networkBufferSize = DEFAULT_NETWORK_BUFFER_SIZE;
-    private final AddressSpaceRegistry _addressSpaceRegistry = new AddressSpaceRegistry();
-    private ConfigurationChangeListener _accessControlProviderListener = new AccessControlProviderListener();
-    private final AccessControl _accessControl;
     private TaskExecutor _preferenceTaskExecutor;
     private String _documentationUrl;
     private long _compactMemoryThreshold;
@@ -148,8 +145,6 @@ public class BrokerImpl extends AbstractContainer<BrokerImpl> implements Broker<
     private volatile ScheduledFuture<?> _statisticsReportingFuture;
     private long _housekeepingCheckPeriod;
 
-    private final AtomicBoolean _directMemoryExceedsThresholdReported = new AtomicBoolean();
-
     @ManagedObjectFactoryConstructor
     public BrokerImpl(Map<String, Object> attributes,
                       SystemConfig parent)
@@ -577,7 +572,7 @@ public class BrokerImpl extends AbstractContainer<BrokerImpl> implements Broker<
     {
         reportDirectMemoryAboveThresholdIfExceeded();
         LOGGER.debug("Assigning target sizes based on total target {}", _flowToDiskThreshold);
-        long totalSize = 0l;
+        long totalSize = 0L;
         Collection<VirtualHostNode<?>> vhns = getVirtualHostNodes();
         Map<QueueManagingVirtualHost<?>, Long> vhs = new HashMap<>();
         for (VirtualHostNode<?> vhn : vhns)
@@ -991,6 +986,27 @@ public class BrokerImpl extends AbstractContainer<BrokerImpl> implements Broker<
         return _documentationUrl;
     }
 
+    @Override
+    public void resetStatistics()
+    {
+        _maximumMessageSize.set(0L);
+
+        _bytesIn.set(0L);
+        _bytesOut.set(0L);
+        _messagesIn.set(0L);
+        _messagesOut.set(0L);
+        _transactedMessagesIn.set(0L);
+        _transactedMessagesOut.set(0L);
+
+        getChildren(BrokerLogger.class).forEach(BrokerLogger::resetStatistics);
+        getChildren(Port.class).stream()
+                .filter(AmqpPort.class::isInstance).map(port -> (AmqpPort<?>) port)
+                .forEach(AmqpPort::resetStatistics);
+        getVirtualHostNodes().stream().map(VirtualHostNode::getVirtualHost)
+                .filter(QueueManagingVirtualHost.class::isInstance).map(vh -> (QueueManagingVirtualHost<?>) vh)
+                .forEach(QueueManagingVirtualHost::resetStatistics);
+    }
+
     @Override
     public void restart()
     {
@@ -1027,38 +1043,13 @@ public class BrokerImpl extends AbstractContainer<BrokerImpl> implements Broker<
     @Override
     public SocketConnectionMetaData getConnectionMetaData()
     {
-        Subject subject = Subject.getSubject(AccessController.getContext());
-        final SocketConnectionPrincipal principal;
-        if(subject != null)
-        {
-            Set<SocketConnectionPrincipal> principals = subject.getPrincipals(SocketConnectionPrincipal.class);
-            if(!principals.isEmpty())
-            {
-                principal = principals.iterator().next();
-            }
-            else
-            {
-                principal = null;
-            }
-        }
-        else
-        {
-            principal = null;
-        }
-        return principal == null ? null : principal.getConnectionMetaData();
+        return getConnectionMetaDataInternal();
     }
 
     @Override
     public Set<Principal> getGroups()
     {
-        Subject currentSubject = Subject.getSubject(AccessController.getContext());
-        if (currentSubject == null)
-        {
-            return Collections.emptySet();
-        }
-
-        final Set<Principal> currentPrincipals = Collections.<Principal>unmodifiableSet(currentSubject.getPrincipals(GroupPrincipal.class));
-        return currentPrincipals;
+        return getGroupsInternal();
     }
 
     @Override
@@ -1351,6 +1342,39 @@ public class BrokerImpl extends AbstractContainer<BrokerImpl> implements Broker<
         }
     }
 
+    private final SocketConnectionMetaData getConnectionMetaDataInternal()
+    {
+        final Subject subject = Subject.getSubject(AccessController.getContext());
+        final SocketConnectionPrincipal principal;
+        if (subject != null)
+        {
+            Set<SocketConnectionPrincipal> principals = subject.getPrincipals(SocketConnectionPrincipal.class);
+            if (!principals.isEmpty())
+            {
+                principal = principals.iterator().next();
+            }
+            else
+            {
+                principal = null;
+            }
+        }
+        else
+        {
+            principal = null;
+        }
+        return principal == null ? null : principal.getConnectionMetaData();
+    }
+
+    private final Set<Principal> getGroupsInternal()
+    {
+        final Subject currentSubject = Subject.getSubject(AccessController.getContext());
+        if (currentSubject == null)
+        {
+            return Collections.emptySet();
+        }
+        return Collections.<Principal>unmodifiableSet(currentSubject.getPrincipals(GroupPrincipal.class));
+    }
+
     private void reportDirectMemoryBelowThresholdIfReached()
     {
         if (DIRECT_MEMORY_USAGE_LOGGER.isDebugEnabled())
@@ -1380,5 +1404,4 @@ public class BrokerImpl extends AbstractContainer<BrokerImpl> implements Broker<
             }
         }
     }
-
 }
