@@ -80,8 +80,11 @@ public final class BrokerModel extends Model
      * 8.0
      *    Added new broker statistics: processCpuTime, processCpuLoad
      *    Added new context variables for queues and exchanges to configure behaviour on unknown declared arguments
+     *
+     * 9.0
+     *    Introduced PublishProducer as a child of Exchange and PointToPointProducer as child of Queue
      */
-    public static final int MODEL_MAJOR_VERSION = 8;
+    public static final int MODEL_MAJOR_VERSION = 9;
     public static final int MODEL_MINOR_VERSION = 0;
     public static final String MODEL_VERSION = MODEL_MAJOR_VERSION + "." + MODEL_MINOR_VERSION;
     private static final Model MODEL_INSTANCE = new BrokerModel();
@@ -113,6 +116,7 @@ public final class BrokerModel extends Model
         addRelationship(Broker.class, AuthenticationProvider.class);
         addRelationship(Broker.class, GroupProvider.class);
         addRelationship(Broker.class, Plugin.class);
+        addRelationship(Broker.class, BrokerConnectionLimitProvider.class);
 
         addRelationship(BrokerLogger.class, BrokerLogInclusionRule.class);
 
@@ -123,6 +127,7 @@ public final class BrokerModel extends Model
         addRelationship(VirtualHost.class, VirtualHostAccessControlProvider.class);
         addRelationship(VirtualHost.class, Exchange.class);
         addRelationship(VirtualHost.class, Queue.class);
+        addRelationship(VirtualHost.class, VirtualHostConnectionLimitProvider.class);
 
         addRelationship(VirtualHostLogger.class, VirtualHostLogInclusionRule.class);
 
@@ -136,6 +141,8 @@ public final class BrokerModel extends Model
 
         addRelationship(Connection.class, Session.class);
 
+        addRelationship(Session.class, Producer.class);
+
         addRelationship(Queue.class, Consumer.class);
 
         _objectFactory = new ConfiguredObjectFactoryImpl(this);
