@@ -511,6 +511,14 @@ class QueueConsumerImpl<T extends ConsumerTarget>
         return _deliveredCount.longValue();
     }
 
+    @Override
+    public void resetStatistics()
+    {
+        _deliveredBytes.set(0L);
+        _deliveredCount.set(0L);
+        _target.resetStatistics();
+    }
+
     @Override
     public void acquisitionRemoved(final QueueEntry node)
     {
