@@ -295,7 +295,7 @@ public class FileTrustStoreImpl extends AbstractTrustStore<FileTrustStoreImpl> i
         {
             final KeyStore ts = initializeKeyStore(this);
             trustManagers = createTrustManagers(ts);
-            certificates = Collections.unmodifiableMap(SSLUtil.getCertificatesAsMap(ts));
+            certificates = Collections.unmodifiableMap(SSLUtil.getCertificates(ts));
         }
         catch (Exception e)
         {
