@@ -32,9 +32,9 @@ import java.util.Collections;
 import java.util.HashSet;
 import java.util.Hashtable;
 import java.util.List;
+import java.util.Locale;
 import java.util.Map;
 import java.util.Set;
-import java.util.concurrent.Callable;
 
 import javax.naming.AuthenticationException;
 import javax.naming.Context;
@@ -46,14 +46,12 @@ import javax.naming.directory.DirContext;
 import javax.naming.directory.InitialDirContext;
 import javax.naming.directory.SearchControls;
 import javax.naming.directory.SearchResult;
-import javax.net.SocketFactory;
 import javax.net.ssl.SSLContext;
 import javax.net.ssl.SSLSocketFactory;
 import javax.security.auth.Subject;
 import javax.security.auth.login.LoginContext;
 import javax.security.auth.login.LoginException;
 
-import com.google.common.util.concurrent.ListenableFuture;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -68,8 +66,7 @@ import org.apache.qpid.server.model.TrustStore;
 import org.apache.qpid.server.security.auth.AuthenticationResult;
 import org.apache.qpid.server.security.auth.AuthenticationResult.AuthenticationStatus;
 import org.apache.qpid.server.security.auth.UsernamePrincipal;
-import org.apache.qpid.server.security.auth.manager.ldap.AbstractLDAPSSLSocketFactory;
-import org.apache.qpid.server.security.auth.manager.ldap.LDAPSSLSocketFactoryGenerator;
+import org.apache.qpid.server.security.auth.manager.ldap.ThreadLocalLdapSslSocketFactory;
 import org.apache.qpid.server.security.auth.sasl.SaslNegotiator;
 import org.apache.qpid.server.security.auth.sasl.SaslSettings;
 import org.apache.qpid.server.security.auth.sasl.plain.PlainNegotiator;
@@ -78,14 +75,22 @@ import org.apache.qpid.server.transport.network.security.ssl.SSLUtil;
 import org.apache.qpid.server.util.CipherSuiteAndProtocolRestrictingSSLSocketFactory;
 import org.apache.qpid.server.util.ParameterizedTypes;
 import org.apache.qpid.server.util.ServerScopedRuntimeException;
-import org.apache.qpid.server.util.StringUtil;
 
+/**
+ * Simple LDAP authentication manager.
+ * <p>
+ * Supports username / password authentication.
+ */
+// sonar complains about underscores in variable names
+@SuppressWarnings("java:S116")
 public class SimpleLDAPAuthenticationManagerImpl
         extends AbstractAuthenticationManager<SimpleLDAPAuthenticationManagerImpl>
         implements SimpleLDAPAuthenticationManager<SimpleLDAPAuthenticationManagerImpl>
 {
+    /** Logger */
     private static final Logger LOGGER = LoggerFactory.getLogger(SimpleLDAPAuthenticationManagerImpl.class);
 
+    /** LDAP connectivity attributes (used to validate configuration changes) */
     private static final List<String> CONNECTIVITY_ATTRS = unmodifiableList(Arrays.asList(PROVIDER_URL,
                                                                                           PROVIDER_AUTH_URL,
                                                                                           SEARCH_CONTEXT,
@@ -96,75 +101,100 @@ public class SimpleLDAPAuthenticationManagerImpl
                                                                                           LOGIN_CONFIG_SCOPE,
                                                                                           AUTHENTICATION_METHOD));
 
-    /**
-     * Environment key to instruct {@link InitialDirContext} to override the socket factory.
-     */
+    /** Environment key to instruct {@link InitialDirContext} to override the socket factory. */
     private static final String JAVA_NAMING_LDAP_FACTORY_SOCKET = "java.naming.ldap.factory.socket";
 
+    /** LDAP provider URL (used for search) */
     @ManagedAttributeField
     private String _providerUrl;
+
+    /** LDAP provider URL (used for authentication) */
     @ManagedAttributeField
     private String _providerAuthUrl;
+
+    /** LDAP search context */
     @ManagedAttributeField
     private String _searchContext;
+
+    /** LDAP search filter */
     @ManagedAttributeField
     private String _searchFilter;
+
+    /** LDAP context factory */
     @ManagedAttributeField
     private String _ldapContextFactory;
 
-
     /**
      * Trust store - typically used when the Directory has been secured with a certificate signed by a
      * private CA (or self-signed certificate).
      */
     @ManagedAttributeField
-    private TrustStore _trustStore;
+    private TrustStore<?> _trustStore;
 
+    /** Flag defining whether LDAP bind should be done without search or not */
     @ManagedAttributeField
     private boolean _bindWithoutSearch;
 
+    /** LDAP username used for search */
     @ManagedAttributeField
     private String _searchUsername;
+
+    /** LDAP password used for search */
     @ManagedAttributeField
     private String _searchPassword;
 
+    /** LDAP group attribute name */
     @ManagedAttributeField
     private String _groupAttributeName;
 
+    /** LDAP group search context */
     @ManagedAttributeField
     private String _groupSearchContext;
 
+    /** LDAP group search filter */
     @ManagedAttributeField
     private String _groupSearchFilter;
 
+    /** LDAP group subtree search scope */
     @ManagedAttributeField
     private boolean _groupSubtreeSearchScope;
 
+    /** LDAP authentication method */
     @ManagedAttributeField
     private LdapAuthenticationMethod _authenticationMethod;
 
+    /** Config login scope */
     @ManagedAttributeField
     private String _loginConfigScope;
 
-    private List<String> _tlsProtocolWhiteList;
-    private List<String>  _tlsProtocolBlackList;
+    /** TLS protocol allow list */
+    private List<String> _tlsProtocolAllowList;
 
-    private List<String> _tlsCipherSuiteWhiteList;
-    private List<String> _tlsCipherSuiteBlackList;
+    /** TLS protocol deny list */
+    private List<String> _tlsProtocolDenyList;
 
+    /** TLS cipher suite allow list */
+    private List<String> _tlsCipherSuiteAllowList;
+
+    /** TLS cipher suite deny list */
+    private List<String> _tlsCipherSuiteDenyList;
+
+    /** Authentication result cacher */
     private AuthenticationResultCacher _authenticationResultCacher;
 
     /**
-     * Dynamically created SSL Socket Factory implementation.
+     * Constructor creates configured object
+     *
+     * @param attributes Attributes
+     * @param container  Parent container
      */
-    private Class<? extends SocketFactory> _sslSocketFactoryOverrideClass;
-
     @ManagedObjectFactoryConstructor
     protected SimpleLDAPAuthenticationManagerImpl(final Map<String, Object> attributes, final Container<?> container)
     {
         super(attributes, container);
     }
 
+    /** Validates LDAP connectivity on creation */
     @Override
     protected void validateOnCreate()
     {
@@ -172,6 +202,12 @@ public class SimpleLDAPAuthenticationManagerImpl
         validateInitialDirContext(this);
     }
 
+    /**
+     * Validate changes
+     *
+     * @param proxyForValidation ConfiguredObject
+     * @param changedAttributes  Attribute names
+     */
     @Override
     protected void validateChange(final ConfiguredObject<?> proxyForValidation, final Set<String> changedAttributes)
     {
@@ -179,41 +215,44 @@ public class SimpleLDAPAuthenticationManagerImpl
 
         if (!disjoint(changedAttributes, CONNECTIVITY_ATTRS))
         {
-            SimpleLDAPAuthenticationManager changed = (SimpleLDAPAuthenticationManager) proxyForValidation;
+            final SimpleLDAPAuthenticationManager<?> changed = (SimpleLDAPAuthenticationManager<?>) proxyForValidation;
             validateInitialDirContext(changed);
         }
     }
 
+    /** Retrieves protocol / cipher allow and deny lists from context. Creates authentication result cacher. */
     @Override
     protected void onOpen()
     {
         super.onOpen();
 
-        _tlsProtocolWhiteList = getContextValue(List.class, ParameterizedTypes.LIST_OF_STRINGS, CommonProperties.QPID_SECURITY_TLS_PROTOCOL_ALLOW_LIST, CommonProperties.QPID_SECURITY_TLS_PROTOCOL_WHITE_LIST);
-        _tlsProtocolBlackList = getContextValue(List.class, ParameterizedTypes.LIST_OF_STRINGS, CommonProperties.QPID_SECURITY_TLS_PROTOCOL_DENY_LIST, CommonProperties.QPID_SECURITY_TLS_PROTOCOL_BLACK_LIST);
-        _tlsCipherSuiteWhiteList = getContextValue(List.class, ParameterizedTypes.LIST_OF_STRINGS, CommonProperties.QPID_SECURITY_TLS_CIPHER_SUITE_ALLOW_LIST, CommonProperties.QPID_SECURITY_TLS_CIPHER_SUITE_WHITE_LIST);
-        _tlsCipherSuiteBlackList = getContextValue(List.class, ParameterizedTypes.LIST_OF_STRINGS, CommonProperties.QPID_SECURITY_TLS_CIPHER_SUITE_DENY_LIST, CommonProperties.QPID_SECURITY_TLS_CIPHER_SUITE_BLACK_LIST);
+        _tlsProtocolAllowList = getContextValue(List.class,
+                                                ParameterizedTypes.LIST_OF_STRINGS,
+                                                CommonProperties.QPID_SECURITY_TLS_PROTOCOL_ALLOW_LIST);
+        _tlsProtocolDenyList = getContextValue(List.class,
+                                               ParameterizedTypes.LIST_OF_STRINGS,
+                                               CommonProperties.QPID_SECURITY_TLS_PROTOCOL_DENY_LIST);
+        _tlsCipherSuiteAllowList = getContextValue(List.class,
+                                                   ParameterizedTypes.LIST_OF_STRINGS,
+                                                   CommonProperties.QPID_SECURITY_TLS_CIPHER_SUITE_ALLOW_LIST);
+        _tlsCipherSuiteDenyList = getContextValue(List.class,
+                                                  ParameterizedTypes.LIST_OF_STRINGS,
+                                                  CommonProperties.QPID_SECURITY_TLS_CIPHER_SUITE_DENY_LIST);
 
         Integer cacheMaxSize = getContextValue(Integer.class, AUTHENTICATION_CACHE_MAX_SIZE);
         Long cacheExpirationTime = getContextValue(Long.class, AUTHENTICATION_CACHE_EXPIRATION_TIME);
         Integer cacheIterationCount = getContextValue(Integer.class, AUTHENTICATION_CACHE_ITERATION_COUNT);
-        if (cacheMaxSize == null || cacheMaxSize <= 0
-            || cacheExpirationTime == null || cacheExpirationTime <= 0
-            || cacheIterationCount == null || cacheIterationCount < 0)
+        if (cacheMaxSize == null || cacheMaxSize <= 0 ||
+                cacheExpirationTime == null || cacheExpirationTime <= 0 ||
+                cacheIterationCount == null || cacheIterationCount < 0)
         {
             LOGGER.debug("disabling authentication result caching");
             cacheMaxSize = 0;
             cacheExpirationTime = 1L;
             cacheIterationCount = 0;
         }
-        _authenticationResultCacher = new AuthenticationResultCacher(cacheMaxSize, cacheExpirationTime, cacheIterationCount);
-    }
-
-    @Override
-    protected ListenableFuture<Void> activate()
-    {
-        _sslSocketFactoryOverrideClass = createSslSocketFactoryOverrideClass(_trustStore);
-        return super.activate();
+        _authenticationResultCacher =
+                new AuthenticationResultCacher(cacheMaxSize, cacheExpirationTime, cacheIterationCount);
     }
 
     @Override
@@ -247,7 +286,7 @@ public class SimpleLDAPAuthenticationManagerImpl
     }
 
     @Override
-    public TrustStore getTrustStore()
+    public TrustStore<?> getTrustStore()
     {
         return _trustStore;
     }
@@ -306,40 +345,58 @@ public class SimpleLDAPAuthenticationManagerImpl
         return singletonList(PlainNegotiator.MECHANISM);
     }
 
+    /**
+     * Creates SASL negotiator based on available options
+     *
+     * @param mechanism    Mechanism name
+     * @param saslSettings SaslSettings
+     * @param addressSpace NamedAddressSpace
+     * @return SaslNegotiator
+     */
     @Override
     public SaslNegotiator createSaslNegotiator(final String mechanism,
                                                final SaslSettings saslSettings,
                                                final NamedAddressSpace addressSpace)
     {
-        if(PlainNegotiator.MECHANISM.equals(mechanism))
-        {
-            return new PlainNegotiator(this);
-        }
-        else
-        {
-            return null;
-        }
+        return PlainNegotiator.MECHANISM.equals(mechanism) ? new PlainNegotiator(this) : null;
     }
 
+    /**
+     * Authenticates username / password against LDAP
+     *
+     * @param username username
+     * @param password password
+     * @return AuthenticationResult
+     */
     @Override
-    public AuthenticationResult authenticate(String username, String password)
+    public AuthenticationResult authenticate(final String username, final String password)
     {
         return getOrLoadAuthenticationResult(username, password);
     }
 
+    /**
+     * Authenticates username / password against LDAP.
+     * <p>
+     * Tries to retrieve authentication result from cache, if result is absent, performs authentication against LDAP.
+     *
+     * @param userId   userId
+     * @param password password
+     * @return AuthenticationResult
+     */
     private AuthenticationResult getOrLoadAuthenticationResult(final String userId, final String password)
     {
-        return _authenticationResultCacher.getOrLoad(new String[]{userId, password}, new Callable<AuthenticationResult>()
-        {
-            @Override
-            public AuthenticationResult call()
-            {
-                return doLDAPNameAuthentication(userId, password);
-            }
-        });
+        return _authenticationResultCacher.getOrLoad(new String[]{userId, password},
+                                                     () -> doLDAPNameAuthentication(userId, password));
     }
 
-    private AuthenticationResult doLDAPNameAuthentication(String userId, String password)
+    /**
+     * Authenticates username / password against LDAP.
+     *
+     * @param userId   userId
+     * @param password password
+     * @return AuthenticationResult
+     */
+    private AuthenticationResult doLDAPNameAuthentication(final String userId, final String password)
     {
         Subject gssapiIdentity = null;
         if (LdapAuthenticationMethod.GSSAPI.equals(getAuthenticationMethod()))
@@ -366,14 +423,14 @@ public class SimpleLDAPAuthenticationManagerImpl
             return new AuthenticationResult(AuthenticationResult.AuthenticationStatus.ERROR, e);
         }
 
-        if(name == null)
+        if (name == null)
         {
             //The search didn't return anything, class as not-authenticated before it NPEs below
             return new AuthenticationResult(AuthenticationStatus.ERROR);
         }
 
-        String providerAuthUrl = isSpecified(getProviderAuthUrl()) ? getProviderAuthUrl() : getProviderUrl();
-        Hashtable<String, Object> env = createInitialDirContextEnvironment(providerAuthUrl);
+        final String providerAuthUrl = isSpecified(getProviderAuthUrl()) ? getProviderAuthUrl() : getProviderUrl();
+        final Hashtable<String, Object> env = createInitialDirContextEnvironment(providerAuthUrl);
 
         env.put(Context.SECURITY_AUTHENTICATION, "simple");
         env.put(Context.SECURITY_PRINCIPAL, name);
@@ -382,7 +439,7 @@ public class SimpleLDAPAuthenticationManagerImpl
         InitialDirContext ctx = null;
         try
         {
-            ctx = createInitialDirContext(env, _sslSocketFactoryOverrideClass, gssapiIdentity);
+            ctx = createInitialDirContext(env, gssapiIdentity);
 
             Set<Principal> groups = Collections.emptySet();
             if (isGroupSearchRequired())
@@ -398,7 +455,7 @@ public class SimpleLDAPAuthenticationManagerImpl
             //Authentication succeeded
             return new AuthenticationResult(new UsernamePrincipal(name, this), groups, null);
         }
-        catch(AuthenticationException ae)
+        catch (AuthenticationException ae)
         {
             //Authentication failed
             return new AuthenticationResult(AuthenticationStatus.ERROR);
@@ -411,10 +468,7 @@ public class SimpleLDAPAuthenticationManagerImpl
         }
         finally
         {
-            if(ctx != null)
-            {
-                closeSafely(ctx);
-            }
+            closeSafely(ctx);
         }
     }
 
@@ -424,7 +478,6 @@ public class SimpleLDAPAuthenticationManagerImpl
         {
             return true;
         }
-
         return (isSpecified(getGroupSearchContext()) && isSpecified(getGroupSearchFilter()));
     }
 
@@ -433,26 +486,26 @@ public class SimpleLDAPAuthenticationManagerImpl
         return (value != null && !value.isEmpty());
     }
 
-    private Set<Principal> findGroups(DirContext context, String userDN, final Subject gssapiIdentity)
+    private Set<Principal> findGroups(final DirContext context, final String userDN, final Subject gssapiIdentity)
             throws NamingException
     {
-        Set<Principal> groupPrincipals = new HashSet<>();
+        final Set<Principal> groupPrincipals = new HashSet<>();
         if (getGroupAttributeName() != null && !getGroupAttributeName().isEmpty())
         {
-            Attributes attributes = context.getAttributes(userDN, new String[]{getGroupAttributeName()});
-            NamingEnumeration<? extends Attribute> namingEnum = attributes.getAll();
+            final Attributes attributes = context.getAttributes(userDN, new String[]{getGroupAttributeName()});
+            final NamingEnumeration<? extends Attribute> namingEnum = attributes.getAll();
             while (namingEnum.hasMore())
             {
-                Attribute attribute = namingEnum.next();
+                final Attribute attribute = namingEnum.next();
                 if (attribute != null)
                 {
-                    NamingEnumeration<?> attributeValues = attribute.getAll();
+                    final NamingEnumeration<?> attributeValues = attribute.getAll();
                     while (attributeValues.hasMore())
                     {
-                        Object attributeValue = attributeValues.next();
+                        final Object attributeValue = attributeValues.next();
                         if (attributeValue != null)
                         {
-                            String groupDN = String.valueOf(attributeValue);
+                            final String groupDN = String.valueOf(attributeValue);
                             groupPrincipals.add(new GroupPrincipal(groupDN, this));
                         }
                     }
@@ -463,20 +516,21 @@ public class SimpleLDAPAuthenticationManagerImpl
         if (getGroupSearchContext() != null && !getGroupSearchContext().isEmpty() &&
                 getGroupSearchFilter() != null && !getGroupSearchFilter().isEmpty())
         {
-            SearchControls searchControls = new SearchControls();
+            final SearchControls searchControls = new SearchControls();
             searchControls.setReturningAttributes(new String[]{});
             searchControls.setSearchScope(isGroupSubtreeSearchScope()
                                                   ? SearchControls.SUBTREE_SCOPE
                                                   : SearchControls.ONELEVEL_SCOPE);
-            PrivilegedExceptionAction<NamingEnumeration<?>> search = () -> context.search(getGroupSearchContext(),
-                                                                                          getGroupSearchFilter(),
-                                                                                          new String[]{encode(userDN)},
-                                                                                          searchControls);
-            NamingEnumeration<?> groupEnumeration = invokeContextOperationAs(gssapiIdentity, search);
+            final PrivilegedExceptionAction<NamingEnumeration<?>> search = () -> context.search(getGroupSearchContext(),
+                                                                                                getGroupSearchFilter(),
+                                                                                                new String[]{encode(
+                                                                                                        userDN)},
+                                                                                                searchControls);
+            final NamingEnumeration<?> groupEnumeration = invokeContextOperationAs(gssapiIdentity, search);
             while (groupEnumeration.hasMore())
             {
-                SearchResult result = (SearchResult) groupEnumeration.next();
-                String groupDN = result.getNameInNamespace();
+                final SearchResult result = (SearchResult) groupEnumeration.next();
+                final String groupDN = result.getNameInNamespace();
                 groupPrincipals.add(new GroupPrincipal(groupDN, this));
             }
         }
@@ -484,12 +538,14 @@ public class SimpleLDAPAuthenticationManagerImpl
         return groupPrincipals;
     }
 
-    private String encode(String value)
+    private String encode(final String value)
     {
-        StringBuilder encoded = new StringBuilder(value.length());
-        char[] chars = value.toCharArray();
-        for (char ch : chars) {
-            switch (ch) {
+        final StringBuilder encoded = new StringBuilder(value.length());
+        final char[] chars = value.toCharArray();
+        for (final char ch : chars)
+        {
+            switch (ch)
+            {
                 case '\0':
                     encoded.append("\\00");
                     break;
@@ -513,99 +569,100 @@ public class SimpleLDAPAuthenticationManagerImpl
         return encoded.toString();
     }
 
-    private Hashtable<String, Object> createInitialDirContextEnvironment(String providerUrl)
+    @SuppressWarnings("java:S1149")
+    // Hashtable use if forced by JNDI API
+    private Hashtable<String, Object> createInitialDirContextEnvironment(final String providerUrl)
     {
-        Hashtable<String,Object> env = new Hashtable<>();
+        final Hashtable<String, Object> env = new Hashtable<>();
         env.put(Context.INITIAL_CONTEXT_FACTORY, _ldapContextFactory);
         env.put(Context.PROVIDER_URL, providerUrl);
         return env;
     }
 
-    private InitialDirContext createInitialDirContext(final Hashtable<String, Object> env,
-                                                      final Class<? extends SocketFactory> sslSocketFactoryOverrideClass,
-                                                      final Subject gssapiIdentity) throws NamingException
+    /**
+     * Creates InitialDirContext instance using supplied properties
+     *
+     * @param env            Hashtable containing properties for context creation
+     * @param gssapiIdentity Subject
+     * @return InitialDirContext
+     * @throws NamingException exception throws during LDAP context creation
+     */
+    @SuppressWarnings("java:S1149")
+    // Hashtable use if forced by JNDI API
+    private InitialDirContext createInitialDirContext(final Hashtable<String, Object> env, final Subject gssapiIdentity)
+            throws NamingException
     {
-        ClassLoader existingContextClassLoader = null;
-
-        boolean isLdaps = String.valueOf(env.get(Context.PROVIDER_URL)).trim().toLowerCase().startsWith("ldaps:");
-
-        boolean revertContentClassLoader = false;
-        try
+        final boolean isLdaps =
+                String.valueOf(env.get(Context.PROVIDER_URL)).trim().toLowerCase(Locale.US).startsWith("ldaps:");
+        if (isLdaps)
         {
-            if (isLdaps)
-            {
-                existingContextClassLoader = Thread.currentThread().getContextClassLoader();
-                env.put(JAVA_NAMING_LDAP_FACTORY_SOCKET, sslSocketFactoryOverrideClass.getName());
-                Thread.currentThread().setContextClassLoader(sslSocketFactoryOverrideClass.getClassLoader());
-                revertContentClassLoader = true;
-            }
-            return invokeContextOperationAs(gssapiIdentity, () -> new InitialDirContext(env));
-        }
-        finally
-        {
-            if (revertContentClassLoader)
-            {
-                Thread.currentThread().setContextClassLoader(existingContextClassLoader);
-            }
+            ThreadLocalLdapSslSocketFactory.set(createSslSocketFactory(_trustStore));
+            env.put(JAVA_NAMING_LDAP_FACTORY_SOCKET, ThreadLocalLdapSslSocketFactory.class.getCanonicalName());
         }
+        return invokeContextOperationAs(gssapiIdentity, () -> new InitialDirContext(env));
     }
 
-    private Class<? extends SocketFactory> createSslSocketFactoryOverrideClass(final TrustStore trustStore)
+    /**
+     * Creates SSLSocketFactory
+     *
+     * @param trustStore TrustStore instance
+     * @return SSLSocketFactory instance
+     */
+    private SSLSocketFactory createSslSocketFactory(final TrustStore<?> trustStore)
     {
-        String managerName = String.format("%s_%s_%s", getName(), getId(), trustStore == null ? "none" : trustStore.getName());
-        String clazzName = new StringUtil().createUniqueJavaName(managerName);
-        SSLContext sslContext = null;
+        final SSLContext sslContext;
         try
         {
             sslContext = SSLUtil.tryGetSSLContext();
-            sslContext.init(null,
-                            trustStore == null ? null : trustStore.getTrustManagers(),
-                            null);
+            sslContext.init(null, trustStore == null ? null : trustStore.getTrustManagers(), null);
         }
         catch (GeneralSecurityException e)
         {
             LOGGER.error("Exception creating SSLContext", e);
             if (trustStore != null)
             {
-                throw new IllegalConfigurationException("Error creating SSLContext with trust store : " +
-                                                        trustStore.getName() , e);
+                throw new IllegalConfigurationException("Error creating SSLContext with trust store : "
+                                                        + trustStore.getName(), e);
             }
             else
             {
                 throw new IllegalConfigurationException("Error creating SSLContext (no trust store)", e);
             }
         }
-
-        SSLSocketFactory sslSocketFactory = new CipherSuiteAndProtocolRestrictingSSLSocketFactory(sslContext.getSocketFactory(),
-                                                                                                 _tlsCipherSuiteWhiteList,
-                                                                                                 _tlsCipherSuiteBlackList,
-                                                                                                 _tlsProtocolWhiteList,
-                                                                                                 _tlsProtocolBlackList);
-        Class<? extends AbstractLDAPSSLSocketFactory> clazz = LDAPSSLSocketFactoryGenerator.createSubClass(clazzName,
-                                                                                                           sslSocketFactory);
-        LOGGER.debug("Connection to Directory will use custom SSL socket factory : {}",  clazz);
-        return clazz;
+        return new CipherSuiteAndProtocolRestrictingSSLSocketFactory(sslContext.getSocketFactory(),
+                                                                     _tlsCipherSuiteAllowList,
+                                                                     _tlsCipherSuiteDenyList,
+                                                                     _tlsProtocolAllowList,
+                                                                     _tlsProtocolDenyList);
     }
 
-
     @Override
     public String toString()
     {
-        return "SimpleLDAPAuthenticationManagerImpl [id=" + getId() + ", name=" + getName() +
-               ", providerUrl=" + _providerUrl + ", providerAuthUrl=" + _providerAuthUrl +
-               ", searchContext=" + _searchContext + ", state=" + getState() +
-               ", searchFilter=" + _searchFilter + ", ldapContextFactory=" + _ldapContextFactory +
-               ", bindWithoutSearch=" + _bindWithoutSearch + ", trustStore=" + _trustStore +
-               ", searchUsername=" + _searchUsername + ", loginConfigScope=" + _loginConfigScope +
-               ", authenticationMethod=" + _authenticationMethod + "]";
+        return "SimpleLDAPAuthenticationManagerImpl [id=" + getId() +
+                ", name=" + getName() +
+                ", providerUrl=" + _providerUrl +
+                ", providerAuthUrl=" + _providerAuthUrl +
+                ", searchContext=" + _searchContext +
+                ", state=" + getState() +
+                ", searchFilter=" + _searchFilter +
+                ", ldapContextFactory=" + _ldapContextFactory +
+                ", bindWithoutSearch=" + _bindWithoutSearch +
+                ", trustStore=" + _trustStore +
+                ", searchUsername=" + _searchUsername +
+                ", loginConfigScope=" + _loginConfigScope +
+                ", authenticationMethod=" + _authenticationMethod + "]";
     }
 
+    /**
+     * Validates LDAP InitialDirContext
+     *
+     * @param authenticationProvider SimpleLDAPAuthenticationManager instance
+     */
+    @SuppressWarnings("java:S1149")
+    // Hashtable use if forced by JNDI API
     private void validateInitialDirContext(final SimpleLDAPAuthenticationManager<?> authenticationProvider)
     {
-        final TrustStore truststore = authenticationProvider.getTrustStore();
-        final Class<? extends SocketFactory> sslSocketFactoryOverrideClass =
-                createSslSocketFactoryOverrideClass(truststore);
-
         final Hashtable<String, Object> env =
                 createInitialDirContextEnvironment(authenticationProvider.getProviderUrl());
         setAuthenticationProperties(env,
@@ -621,7 +678,7 @@ public class SimpleLDAPAuthenticationManagerImpl
             {
                 gssapiIdentity = doGssApiLogin(authenticationProvider.getLoginConfigScope());
             }
-            ctx = createInitialDirContext(env, sslSocketFactoryOverrideClass, gssapiIdentity);
+            ctx = createInitialDirContext(env, gssapiIdentity);
         }
         catch (NamingException e)
         {
@@ -641,6 +698,16 @@ public class SimpleLDAPAuthenticationManagerImpl
         }
     }
 
+    /**
+     * Sets authentication parameters into hashtable containing properties for context creation
+     *
+     * @param env                  Hashtable containing properties for context creation
+     * @param userName             LDAP username
+     * @param password             LDAP password
+     * @param authenticationMethod LDAP authentication method
+     */
+    @SuppressWarnings("java:S1149")
+    // Hashtable use if forced by JNDI API
     private void setAuthenticationProperties(final Hashtable<String, Object> env,
                                              final String userName,
                                              final String password,
@@ -668,32 +735,39 @@ public class SimpleLDAPAuthenticationManagerImpl
         }
     }
 
-    private String getNameFromId(final String id, final Subject gssapiIdentity)
-            throws NamingException
+    /**
+     * Searches userId in LDAP returning full LDAP username
+     *
+     * @param id             UserId
+     * @param gssapiIdentity Subject
+     * @return Full username in LDAP
+     * @throws NamingException exception thrown during LDAP search
+     */
+    private String getNameFromId(final String id, final Subject gssapiIdentity) throws NamingException
     {
         if (!isBindWithoutSearch())
         {
-            InitialDirContext ctx = createSearchInitialDirContext(gssapiIdentity);
+            final InitialDirContext ctx = createSearchInitialDirContext(gssapiIdentity);
 
             try
             {
-                SearchControls searchControls = new SearchControls();
+                final SearchControls searchControls = new SearchControls();
                 searchControls.setReturningAttributes(new String[]{});
                 searchControls.setCountLimit(1L);
                 searchControls.setSearchScope(SearchControls.SUBTREE_SCOPE);
 
                 LOGGER.debug("Searching for '{}'", id);
-                NamingEnumeration<?> namingEnum = invokeContextOperationAs(gssapiIdentity,
-                                                      (PrivilegedExceptionAction<NamingEnumeration<?>>) () -> ctx.search(
-                                                              _searchContext,
-                                                              _searchFilter,
-                                                              new String[]{id},
-                                                              searchControls));
+                final NamingEnumeration<?> namingEnum = invokeContextOperationAs(gssapiIdentity,
+                                                                                 (PrivilegedExceptionAction<NamingEnumeration<?>>) () -> ctx.search(
+                                                                                         _searchContext,
+                                                                                         _searchFilter,
+                                                                                         new String[]{id},
+                                                                                         searchControls));
 
                 if (namingEnum.hasMore())
                 {
-                    SearchResult result = (SearchResult) namingEnum.next();
-                    String name = result.getNameInNamespace();
+                    final SearchResult result = (SearchResult) namingEnum.next();
+                    final String name = result.getNameInNamespace();
                     LOGGER.debug("Found '{}' DN '{}'", id, name);
                     return name;
                 }
@@ -741,73 +815,62 @@ public class SimpleLDAPAuthenticationManagerImpl
 
     private Subject doGssApiLogin(final String configScope) throws LoginException
     {
-        LoginContext loginContext = new LoginContext(configScope);
+        final LoginContext loginContext = new LoginContext(configScope);
         loginContext.login();
         return loginContext.getSubject();
     }
 
+    /**
+     * Creates InitialDirContext instance for search
+     *
+     * @param gssapiIdentity Subject
+     * @return InitialDirContext instance
+     * @throws NamingException exception thrown during InitialDirContext creation
+     */
+    @SuppressWarnings("java:S1149")
+    // Hashtable use if forced by JNDI API
     private InitialDirContext createSearchInitialDirContext(final Subject gssapiIdentity) throws NamingException
     {
-        Hashtable<String, Object> env = createInitialDirContextEnvironment(_providerUrl);
+        final Hashtable<String, Object> env = createInitialDirContextEnvironment(_providerUrl);
         setAuthenticationProperties(env, _searchUsername, _searchPassword, _authenticationMethod);
-        return createInitialDirContext(env, _sslSocketFactoryOverrideClass, gssapiIdentity);
+        return createInitialDirContext(env, gssapiIdentity);
     }
 
-
     @Override
     public boolean isBindWithoutSearch()
     {
         return _bindWithoutSearch;
     }
 
-    @Override
-    public List<String> getTlsProtocolWhiteList()
-    {
-        return _tlsProtocolWhiteList;
-    }
-
-    @Override
-    public List<String> getTlsProtocolBlackList()
-    {
-        return _tlsProtocolBlackList;
-    }
-
-    @Override
-    public List<String> getTlsCipherSuiteWhiteList()
-    {
-        return _tlsCipherSuiteWhiteList;
-    }
-
-    @Override
-    public List<String> getTlsCipherSuiteBlackList()
-    {
-        return _tlsCipherSuiteBlackList;
-    }
-
     @Override
     public List<String> getTlsProtocolAllowList()
     {
-        return getTlsProtocolWhiteList();
+        return Collections.unmodifiableList(_tlsProtocolAllowList);
     }
 
     @Override
     public List<String> getTlsProtocolDenyList()
     {
-        return getTlsProtocolBlackList();
+        return Collections.unmodifiableList(_tlsProtocolDenyList);
     }
 
     @Override
     public List<String> getTlsCipherSuiteAllowList()
     {
-        return getTlsCipherSuiteWhiteList();
+        return Collections.unmodifiableList(_tlsCipherSuiteAllowList);
     }
 
     @Override
     public List<String> getTlsCipherSuiteDenyList()
     {
-        return getTlsCipherSuiteBlackList();
+        return Collections.unmodifiableList(_tlsCipherSuiteDenyList);
     }
 
+    /**
+     * Closes InitialDirContext
+     *
+     * @param ctx InitialDirContext instance
+     */
     private void closeSafely(InitialDirContext ctx)
     {
         try
@@ -817,10 +880,10 @@ public class SimpleLDAPAuthenticationManagerImpl
                 ctx.close();
             }
         }
-        catch (Exception e)
+        catch (NamingException e)
         {
             LOGGER.warn("Exception closing InitialDirContext", e);
         }
+        ThreadLocalLdapSslSocketFactory.remove();
     }
-
 }
