@@ -69,6 +69,7 @@ public class BrokerStoreUpgraderAndRecoverer extends AbstractConfigurationStoreU
         register(new Upgrader_6_1_to_7_0());
         register(new Upgrader_7_0_to_7_1());
         register(new Upgrader_7_1_to_8_0());
+        register(new Upgrader_8_0_to_9_0());
     }
 
     private static final class Upgrader_1_0_to_1_1 extends StoreUpgraderPhase
@@ -213,7 +214,7 @@ public class BrokerStoreUpgraderAndRecoverer extends AbstractConfigurationStoreU
         }
 
     }
-    private class Upgrader_2_0_to_3_0 extends StoreUpgraderPhase
+    private static class Upgrader_2_0_to_3_0 extends StoreUpgraderPhase
     {
         public Upgrader_2_0_to_3_0()
         {
@@ -301,7 +302,7 @@ public class BrokerStoreUpgraderAndRecoverer extends AbstractConfigurationStoreU
         }
 
     }
-    private class Upgrader_3_0_to_6_0 extends StoreUpgraderPhase
+    private static class Upgrader_3_0_to_6_0 extends StoreUpgraderPhase
     {
         private String _defaultVirtualHost;
         private final Set<ConfiguredObjectRecord> _knownBdbHaVirtualHostNode = new HashSet<>();
@@ -440,9 +441,9 @@ public class BrokerStoreUpgraderAndRecoverer extends AbstractConfigurationStoreU
 
     }
 
-    private class Upgrader_6_0_to_6_1 extends StoreUpgraderPhase
+    private static class Upgrader_6_0_to_6_1 extends StoreUpgraderPhase
     {
-        private boolean _hasAcl = false;
+        private final boolean _hasAcl = false;
         private UUID _rootRecordId;
 
         public Upgrader_6_0_to_6_1()
@@ -550,10 +551,10 @@ public class BrokerStoreUpgraderAndRecoverer extends AbstractConfigurationStoreU
 
     }
 
-    private class Upgrader_6_1_to_7_0 extends StoreUpgraderPhase
+    private static class Upgrader_6_1_to_7_0 extends StoreUpgraderPhase
     {
 
-        private Map<String,String> BROKER_ATTRIBUTES_MOVED_INTO_CONTEXT = new HashMap<>();
+        private final Map<String,String> BROKER_ATTRIBUTES_MOVED_INTO_CONTEXT = new HashMap<>();
         {
             BROKER_ATTRIBUTES_MOVED_INTO_CONTEXT.put("connection.sessionCountLimit", "qpid.port.sessionCountLimit");
             BROKER_ATTRIBUTES_MOVED_INTO_CONTEXT.put("connection.heartBeatDelay", "qpid.port.heartbeatDelay");
@@ -685,7 +686,7 @@ public class BrokerStoreUpgraderAndRecoverer extends AbstractConfigurationStoreU
         }
     }
 
-    private class Upgrader_7_0_to_7_1 extends StoreUpgraderPhase
+    private static class Upgrader_7_0_to_7_1 extends StoreUpgraderPhase
     {
 
         public Upgrader_7_0_to_7_1()
@@ -709,7 +710,7 @@ public class BrokerStoreUpgraderAndRecoverer extends AbstractConfigurationStoreU
         }
     }
 
-    private class Upgrader_7_1_to_8_0 extends StoreUpgraderPhase
+    private static class Upgrader_7_1_to_8_0 extends StoreUpgraderPhase
     {
 
         public Upgrader_7_1_to_8_0()
@@ -733,6 +734,33 @@ public class BrokerStoreUpgraderAndRecoverer extends AbstractConfigurationStoreU
         }
     }
 
+    private static class Upgrader_8_0_to_9_0 extends StoreUpgraderPhase
+    {
+
+        Upgrader_8_0_to_9_0()
+        {
+            super("modelVersion", "8.0", "9.0");
+        }
+
+        @Override
+        public void configuredObject(ConfiguredObjectRecord record)
+        {
+            if ("Broker".equals(record.getType()))
+            {
+                record = upgradeRootRecord(record);
+            }
+            renameContextVariables(record,
+                                   "context",
+                                   UpgraderHelper.MODEL9_MAPPING_FOR_RENAME_TO_ALLOW_DENY_CONTEXT_VARIABLES);
+        }
+
+        @Override
+        public void complete()
+        {
+
+        }
+    }
+
     private static class VirtualHostEntryUpgrader
     {
         @SuppressWarnings("serial")
@@ -974,8 +1002,8 @@ public class BrokerStoreUpgraderAndRecoverer extends AbstractConfigurationStoreU
 
     private static class MutableEntry
     {
+        private final Object _value;
         private String _key;
-        private Object _value;
 
         public MutableEntry(String key, Object value)
         {
