@@ -78,6 +78,7 @@ public class VirtualHostStoreUpgraderAndRecoverer extends AbstractConfigurationS
         register(new Upgrader_6_1_to_7_0());
         register(new Upgrader_7_0_to_7_1());
         register(new Upgrader_7_1_to_8_0());
+        register(new Upgrader_8_0_to_9_0());
 
         Map<String, UUID> defaultExchangeIds = new HashMap<String, UUID>();
         for (String exchangeName : DEFAULT_EXCHANGES.keySet())
@@ -247,7 +248,7 @@ public class VirtualHostStoreUpgraderAndRecoverer extends AbstractConfigurationS
      * Convert the storage of queue attributes to remove the separate "ARGUMENT" attribute, and flatten the
      * attributes into the map using the model attribute names rather than the wire attribute names
      */
-    private class Upgrader_0_2_to_0_3 extends StoreUpgraderPhase
+    private static class Upgrader_0_2_to_0_3 extends StoreUpgraderPhase
     {
         private static final String ARGUMENTS = "arguments";
 
@@ -353,7 +354,7 @@ public class VirtualHostStoreUpgraderAndRecoverer extends AbstractConfigurationS
      * where exclusive was false it will now be "NONE", and where true it will now be "CONTAINER"
      * ensure OWNER is null unless the exclusivity policy is CONTAINER
      */
-    private class Upgrader_0_3_to_0_4 extends StoreUpgraderPhase
+    private static class Upgrader_0_3_to_0_4 extends StoreUpgraderPhase
     {
         private static final String EXCLUSIVE = "exclusive";
 
@@ -409,11 +410,11 @@ public class VirtualHostStoreUpgraderAndRecoverer extends AbstractConfigurationS
         private static final String DLQ_ENABLED_ARGUMENT = "x-qpid-dlq-enabled";
         private static final String  DEFAULT_DLE_NAME_SUFFIX = "_DLE";
 
-        private Map<String, String> _missingAmqpExchanges = new HashMap<String, String>(DEFAULT_EXCHANGES);
-        private ConfiguredObjectRecord _virtualHostRecord;
+        private final Map<String, String> _missingAmqpExchanges = new HashMap<String, String>(DEFAULT_EXCHANGES);
+        private final Map<UUID, String> _queuesMissingAlternateExchange = new HashMap<>();
+        private final Map<String, ConfiguredObjectRecord> _exchanges = new HashMap<>();
 
-        private Map<UUID, String> _queuesMissingAlternateExchange = new HashMap<>();
-        private Map<String, ConfiguredObjectRecord> _exchanges = new HashMap<>();
+        private ConfiguredObjectRecord _virtualHostRecord;
 
         public Upgrader_0_4_to_2_0()
         {
@@ -536,7 +537,7 @@ public class VirtualHostStoreUpgraderAndRecoverer extends AbstractConfigurationS
 
     }
 
-    private class Upgrader_2_0_to_3_0 extends StoreUpgraderPhase
+    private static class Upgrader_2_0_to_3_0 extends StoreUpgraderPhase
     {
         public Upgrader_2_0_to_3_0()
         {
@@ -559,7 +560,7 @@ public class VirtualHostStoreUpgraderAndRecoverer extends AbstractConfigurationS
         }
 
     }
-    private class Upgrader_3_0_to_6_0 extends StoreUpgraderPhase
+    private static class Upgrader_3_0_to_6_0 extends StoreUpgraderPhase
     {
         public Upgrader_3_0_to_6_0()
         {
@@ -583,7 +584,7 @@ public class VirtualHostStoreUpgraderAndRecoverer extends AbstractConfigurationS
 
     }
 
-    private class Upgrader_6_0_to_6_1 extends StoreUpgraderPhase
+    private static class Upgrader_6_0_to_6_1 extends StoreUpgraderPhase
     {
         public Upgrader_6_0_to_6_1()
         {
@@ -616,7 +617,7 @@ public class VirtualHostStoreUpgraderAndRecoverer extends AbstractConfigurationS
         private final Map<UUID, ConfiguredObjectRecord> _exchanges = new HashMap<>();
         private final Map<UUID, String> _queues = new HashMap<>();
         private final Map<String, List<Map<String,Object>>> _queueBindings = new HashMap<>();
-        private Set<UUID> _destinationsWithAlternateExchange = new HashSet<>();
+        private final Set<UUID> _destinationsWithAlternateExchange = new HashSet<>();
 
 
         public Upgrader_6_1_to_7_0()
@@ -1039,7 +1040,7 @@ public class VirtualHostStoreUpgraderAndRecoverer extends AbstractConfigurationS
     }
 
 
-    private class Upgrader_7_0_to_7_1 extends StoreUpgraderPhase
+    private static class Upgrader_7_0_to_7_1 extends StoreUpgraderPhase
     {
 
         public Upgrader_7_0_to_7_1()
@@ -1063,7 +1064,7 @@ public class VirtualHostStoreUpgraderAndRecoverer extends AbstractConfigurationS
         }
     }
 
-    private class Upgrader_7_1_to_8_0 extends StoreUpgraderPhase
+    private static class Upgrader_7_1_to_8_0 extends StoreUpgraderPhase
     {
 
         public Upgrader_7_1_to_8_0()
@@ -1087,6 +1088,32 @@ public class VirtualHostStoreUpgraderAndRecoverer extends AbstractConfigurationS
         }
     }
 
+    private static class Upgrader_8_0_to_9_0 extends StoreUpgraderPhase
+    {
+        Upgrader_8_0_to_9_0()
+        {
+            super("modelVersion", "8.0", "9.0");
+        }
+
+        @Override
+        public void configuredObject(ConfiguredObjectRecord record)
+        {
+            if ("VirtualHost".equals(record.getType()))
+            {
+                record = upgradeRootRecord(record);
+            }
+            renameContextVariables(record,
+                                   "context",
+                                   UpgraderHelper.MODEL9_MAPPING_FOR_RENAME_TO_ALLOW_DENY_CONTEXT_VARIABLES);
+        }
+
+        @Override
+        public void complete()
+        {
+
+        }
+    }
+
     public boolean upgradeAndRecover(final DurableConfigurationStore durableConfigurationStore,
                                      final ConfiguredObjectRecord... initialRecords)
     {
