@@ -72,6 +72,7 @@ import org.apache.qpid.server.model.Transport;
 import org.apache.qpid.server.model.port.AmqpPort;
 import org.apache.qpid.server.security.auth.AuthenticatedPrincipal;
 import org.apache.qpid.server.security.auth.sasl.SaslSettings;
+import org.apache.qpid.server.session.AbstractAMQPSession;
 import org.apache.qpid.server.stats.StatisticsGatherer;
 import org.apache.qpid.server.store.StoreException;
 import org.apache.qpid.server.transport.network.NetworkConnection;
@@ -84,7 +85,6 @@ import org.apache.qpid.server.util.Action;
 import org.apache.qpid.server.util.ConnectionScopedRuntimeException;
 import org.apache.qpid.server.util.FixedKeyMapCreator;
 import org.apache.qpid.server.util.ServerScopedRuntimeException;
-import org.apache.qpid.server.virtualhost.ConnectionPrincipalStatistics;
 import org.apache.qpid.server.virtualhost.QueueManagingVirtualHost;
 
 public abstract class AbstractAMQPConnection<C extends AbstractAMQPConnection<C,T>, T>
@@ -150,7 +150,6 @@ public abstract class AbstractAMQPConnection<C extends AbstractAMQPConnection<C,
     private long _maxUncommittedInMemorySize;
 
     private final Map<ServerTransaction, Set<Ticker>> _transactionTickers = new ConcurrentHashMap<>();
-    private volatile ConnectionPrincipalStatistics _connectionPrincipalStatistics;
 
     public AbstractAMQPConnection(Broker<?> broker,
                                   ServerNetworkConnection network,
@@ -371,7 +370,7 @@ public abstract class AbstractAMQPConnection<C extends AbstractAMQPConnection<C,
     @Override
     public void pushScheduler(final NetworkConnectionScheduler networkConnectionScheduler)
     {
-        if(_network instanceof NonBlockingConnection)
+        if (_network instanceof NonBlockingConnection)
         {
             ((NonBlockingConnection) _network).pushScheduler(networkConnectionScheduler);
         }
@@ -380,7 +379,7 @@ public abstract class AbstractAMQPConnection<C extends AbstractAMQPConnection<C,
     @Override
     public NetworkConnectionScheduler popScheduler()
     {
-        if(_network instanceof NonBlockingConnection)
+        if (_network instanceof NonBlockingConnection)
         {
             return ((NonBlockingConnection) _network).popScheduler();
         }
@@ -744,6 +743,26 @@ public abstract class AbstractAMQPConnection<C extends AbstractAMQPConnection<C,
         return _transactedMessagesOut.get();
     }
 
+    @Override
+    public void resetStatistics()
+    {
+        _lastMessageInboundTime = System.currentTimeMillis();
+        _lastMessageOutboundTime = System.currentTimeMillis();
+
+        _bytesIn.set(0L);
+        _bytesOut.set(0L);
+        _messagesIn.set(0L);
+        _messagesOut.set(0L);
+        _transactedMessagesIn.set(0L);
+        _transactedMessagesOut.set(0L);
+        _localTransactionBegins.set(0L);
+        _localTransactionRollbacks.set(0L);
+
+        getChildren(Session.class).stream()
+                .filter(AbstractAMQPSession.class::isInstance).map(session -> (AbstractAMQPSession<?, ?>) session)
+                .forEach(AbstractAMQPSession::resetStatistics);
+    }
+
     public AccessControlContext getAccessControllerContext()
     {
         return _accessControllerContext;
@@ -1158,32 +1177,6 @@ public abstract class AbstractAMQPConnection<C extends AbstractAMQPConnection<C,
         _localTransactionBegins.incrementAndGet();
     }
 
-    @Override
-    public void registered(final ConnectionPrincipalStatistics connectionPrincipalStatistics)
-    {
-        _connectionPrincipalStatistics = connectionPrincipalStatistics;
-    }
-
-    @Override
-    public int getAuthenticatedPrincipalConnectionCount()
-    {
-        if (_connectionPrincipalStatistics == null)
-        {
-            return 0;
-        }
-        return _connectionPrincipalStatistics.getConnectionCount();
-    }
-
-    @Override
-    public int getAuthenticatedPrincipalConnectionFrequency()
-    {
-        if (_connectionPrincipalStatistics == null)
-        {
-            return 0;
-        }
-        return _connectionPrincipalStatistics.getConnectionFrequency();
-    }
-
     @Override
     protected void logCreated(final Map<String, Object> attributes,
                               final Outcome outcome)
