@@ -77,7 +77,7 @@ import java.util.regex.Pattern;
 public class CommandLineParser
 {
     /** Holds a mapping from command line option names to detailed information about those options. */
-    private Map<String, CommandLineOption> optionMap = new HashMap<String, CommandLineOption>();
+    private final Map<String, CommandLineOption> optionMap = new HashMap<String, CommandLineOption>();
 
     /** Holds a list of parsing errors. */
     private List<String> parsingErrors = new ArrayList<String>();
@@ -533,16 +533,11 @@ public class CommandLineParser
      * are numbered from 1, such that the parsed properties contain values for the keys "1", "2", ... This method
      * converts any free arguments declared using the 'name=value' syntax into properties with key 'name', value
      * 'value'.
-     *
-     * <p/>For example the comand line:
-     * <pre>
-     * ... debug=true
-     * </pre>
-     *
-     * <p/>After parsing has properties:
+     * <br><br>For example the command line:
+     * <pre>... debug=true</pre>
+     * <br>After parsing has properties:
      * <pre>[[1, debug=true]]</pre>
-     *
-     * <p/>After applying this method the properties are:
+     * <br>After applying this method the properties are:
      * <pre>[[1, debug=true], [debug, true]]</pre>
      *
      * @param properties The parsed command line properties.
@@ -604,7 +599,7 @@ public class CommandLineParser
      *
      * @param args        The command line.
      * @param commandLine The command line parser.
-     * @param properties  The properties object to inject all parsed properties into (optional may be <tt>null</tt>).
+     * @param properties  The properties object to inject all parsed properties into (optional may be <code>null</code>).
      *
      * @return A set of properties containing all name=value pairs from the command line.
      */
