@@ -77,9 +77,7 @@ import org.apache.qpid.server.store.handler.ConfiguredObjectRecordHandler;
 import org.apache.qpid.server.store.preferences.PreferenceStore;
 import org.apache.qpid.server.store.preferences.PreferenceStoreUpdater;
 import org.apache.qpid.server.transport.AMQPConnection;
-import org.apache.qpid.server.virtualhost.ConnectionPrincipalStatistics;
 import org.apache.qpid.server.virtualhost.NodeAutoCreationPolicy;
-import org.apache.qpid.server.virtualhost.NoopConnectionEstablishmentPolicy;
 import org.apache.qpid.server.virtualhost.QueueManagingVirtualHost;
 import org.apache.qpid.server.virtualhost.TestMemoryVirtualHost;
 import org.apache.qpid.server.virtualhost.VirtualHostUnavailableException;
@@ -339,7 +337,7 @@ public class VirtualHostTest extends UnitTestBase
                             virtualHost.getConnectionCount());
 
         AMQPConnection modelConnection = getMockConnection();
-        virtualHost.registerConnection(modelConnection, new NoopConnectionEstablishmentPolicy());
+        virtualHost.registerConnection(modelConnection);
 
         assertEquals("Unexpected number of connections after connection registered",
                             (long) 1,
@@ -368,7 +366,7 @@ public class VirtualHostTest extends UnitTestBase
                             virtualHost.getConnectionCount());
 
         AMQPConnection modelConnection = getMockConnection();
-        virtualHost.registerConnection(modelConnection, new NoopConnectionEstablishmentPolicy());
+        virtualHost.registerConnection(modelConnection);
 
         assertEquals("Unexpected number of connections after connection registered",
                             (long) 1,
@@ -500,7 +498,7 @@ public class VirtualHostTest extends UnitTestBase
     {
         VirtualHost<?> host = createVirtualHost(getTestName());
         AMQPConnection connection = getMockConnection();
-        host.registerConnection(connection, new NoopConnectionEstablishmentPolicy());
+        host.registerConnection(connection);
         ((EventListener) host).event(Event.PERSISTENT_MESSAGE_SIZE_OVERFULL);
         verify(connection).block();
     }
@@ -579,60 +577,20 @@ public class VirtualHostTest extends UnitTestBase
         AMQPConnection<?> connection = getMockConnection();
 
         assertEquals("unexpected number of connections before test", (long) 0, vhost.getConnectionCount());
-        vhost.registerConnection(connection, new NoopConnectionEstablishmentPolicy());
+        vhost.registerConnection(connection);
         assertEquals("unexpected number of connections after registerConnection",
                             (long) 1,
                             vhost.getConnectionCount());
         assertEquals("unexpected connection object", Collections.singleton(connection), vhost.getConnections());
     }
 
-    @Test
-    public void testRegisterConnectionCausesUpdateOfAuthenticatedPrincipalConnectionCountAndFrequency()
-    {
-        final NoopConnectionEstablishmentPolicy policy = new NoopConnectionEstablishmentPolicy();
-        final QueueManagingVirtualHost<?> vhost = createVirtualHost(getTestName());
-        final Principal principal = mockAuthenticatedPrincipal(getTestName());
-        final Principal principal2 = mockAuthenticatedPrincipal(getTestName() + "_2");
-        final AMQPConnection<?> connection1 = mockAmqpConnection(principal);
-        final AMQPConnection<?> connection2 = mockAmqpConnection(principal);
-        final AMQPConnection<?> connection3 = mockAmqpConnection(principal2);
-
-        vhost.registerConnection(connection1, policy);
-        verify(connection1).registered(argThat(new ConnectionPrincipalStatisticsArgumentMatcher(1, 1)));
-
-        vhost.registerConnection(connection2, policy);
-        verify(connection2).registered(argThat(new ConnectionPrincipalStatisticsArgumentMatcher(2, 2)));
-
-        vhost.registerConnection(connection3, policy);
-        verify(connection3).registered(argThat(new ConnectionPrincipalStatisticsArgumentMatcher(1, 1)));
-    }
-
-    @Test
-    public void testDeregisterConnectionAffectsAuthenticatedPrincipalConnectionCountAndFrequency()
-    {
-        final Principal principal = mockAuthenticatedPrincipal(getTestName());
-        final NoopConnectionEstablishmentPolicy policy = new NoopConnectionEstablishmentPolicy();
-        final QueueManagingVirtualHost<?> vhost = createVirtualHost(getTestName());
-
-        final AMQPConnection<?> connection1 = mockAmqpConnection(principal);
-        final AMQPConnection<?> connection2 = mockAmqpConnection(principal);
-
-        vhost.registerConnection(connection1, policy);
-        verify(connection1).registered(argThat(new ConnectionPrincipalStatisticsArgumentMatcher(1, 1)));
-
-        vhost.deregisterConnection(connection1);
-        vhost.registerConnection(connection2, policy);
-
-        verify(connection2).registered(argThat(new ConnectionPrincipalStatisticsArgumentMatcher(1, 2)));
-    }
-
     @Test
     public void testStopVirtualhostClosesConnections()
     {
         QueueManagingVirtualHost<?> vhost = createVirtualHost("sdf");
         AMQPConnection<?> connection = getMockConnection();
 
-        vhost.registerConnection(connection, new NoopConnectionEstablishmentPolicy());
+        vhost.registerConnection(connection);
         assertEquals("unexpected number of connections after registerConnection",
                             (long) 1,
                             vhost.getConnectionCount());
@@ -651,7 +609,7 @@ public class VirtualHostTest extends UnitTestBase
         ((AbstractConfiguredObject<?>)vhost).stop();
         try
         {
-            vhost.registerConnection(connection, new NoopConnectionEstablishmentPolicy());
+            vhost.registerConnection(connection);
             fail("exception not thrown");
         }
         catch (VirtualHostUnavailableException e)
@@ -660,7 +618,7 @@ public class VirtualHostTest extends UnitTestBase
         }
         assertEquals("unexpected number of connections", (long) 0, vhost.getConnectionCount());
         ((AbstractConfiguredObject<?>)vhost).start();
-        vhost.registerConnection(connection, new NoopConnectionEstablishmentPolicy());
+        vhost.registerConnection(connection);
         assertEquals("unexpected number of connections", (long) 1, vhost.getConnectionCount());
     }
 
@@ -879,25 +837,4 @@ public class VirtualHostTest extends UnitTestBase
             return (_id.equals(rhs.getId()) || _type.equals(rhs.getType()));
         }
     }
-
-    private static class ConnectionPrincipalStatisticsArgumentMatcher implements ArgumentMatcher<ConnectionPrincipalStatistics>
-    {
-
-        private final int _expectedConnectionCount;
-        private final int _expectedConnectionFrequency;
-
-        ConnectionPrincipalStatisticsArgumentMatcher(final int expectedConnectionCount,
-                                                     final int expectedConnectionFrequency)
-        {
-            _expectedConnectionCount = expectedConnectionCount;
-            _expectedConnectionFrequency = expectedConnectionFrequency;
-        }
-
-        @Override
-        public boolean matches(final ConnectionPrincipalStatistics connectionPrincipalStatistics)
-        {
-            return connectionPrincipalStatistics.getConnectionFrequency() == _expectedConnectionFrequency
-                    && connectionPrincipalStatistics.getConnectionCount() == _expectedConnectionCount;
-        }
-    }
 }
