@@ -19,9 +19,6 @@
 
 package org.apache.qpid.server.model.port;
 
-import static org.hamcrest.CoreMatchers.equalTo;
-import static org.hamcrest.CoreMatchers.is;
-import static org.hamcrest.MatcherAssert.assertThat;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
@@ -40,7 +37,6 @@ import java.security.Principal;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.HashMap;
-import java.util.List;
 import java.util.Map;
 import java.util.UUID;
 
@@ -48,7 +44,6 @@ import org.junit.After;
 import org.junit.Before;
 import org.junit.Test;
 
-import org.apache.qpid.server.configuration.CommonProperties;
 import org.apache.qpid.server.configuration.IllegalConfigurationException;
 import org.apache.qpid.server.configuration.updater.CurrentThreadTaskExecutor;
 import org.apache.qpid.server.configuration.updater.TaskExecutor;
@@ -65,6 +60,7 @@ import org.apache.qpid.server.model.Port;
 import org.apache.qpid.server.model.SystemConfig;
 import org.apache.qpid.server.model.Transport;
 import org.apache.qpid.server.model.TrustStore;
+import org.apache.qpid.server.security.SiteSpecificTrustStore;
 import org.apache.qpid.test.utils.UnitTestBase;
 
 public class AmqpPortImplTest extends UnitTestBase
@@ -170,6 +166,32 @@ public class AmqpPortImplTest extends UnitTestBase
         _port = createPort(getTestName(), attributes);
     }
 
+    @Test
+    public void testCreateTlsClientAuthUsingSiteTrustStore()
+    {
+        final String trustStoreName = "siteSpecificTrustStore";
+        final SiteSpecificTrustStore<?> trustStore = mock(SiteSpecificTrustStore.class);
+        when(trustStore.getName()).thenReturn(trustStoreName);
+        when(trustStore.getParent()).thenReturn(_broker);
+        when(_broker.getChildren(TrustStore.class)).thenReturn(Collections.singleton(trustStore));
+
+        Map<String, Object> attributes = new HashMap<>();
+        attributes.put(AmqpPort.TRANSPORTS, Collections.singletonList(Transport.SSL));
+        attributes.put(AmqpPort.KEY_STORE, KEYSTORE_NAME);
+        attributes.put(AmqpPort.TRUST_STORES, Collections.singletonList(trustStoreName));
+        attributes.put(AmqpPort.NEED_CLIENT_AUTH, "true");
+
+        try
+        {
+            createPort(getTestName(), attributes);
+            fail("Exception not thrown");
+        }
+        catch (IllegalConfigurationException e)
+        {
+            // pass
+        }
+    }
+
     @Test
     public void testTlsWithoutKeyStore()
     {
@@ -313,105 +335,43 @@ public class AmqpPortImplTest extends UnitTestBase
 
         for(int i = 0; i < 8; i++)
         {
-            assertTrue(_port.canAcceptNewConnection(new InetSocketAddress("example.org", 0)));
-            _port.incrementConnectionCount();
-            assertEquals((long) (i + 1), (long) _port.getConnectionCount());
+            assertTrue(_port.acceptNewConnectionAndIncrementCount(new InetSocketAddress("example.org", 0)));
+            assertEquals(i + 1L, _port.getConnectionCount());
             verify(mockLogger, never()).message(any(LogSubject.class), any(LogMessage.class));
         }
 
-        assertTrue(_port.canAcceptNewConnection(new InetSocketAddress("example.org", 0)));
-        _port.incrementConnectionCount();
-        assertEquals((long) 9, (long) _port.getConnectionCount());
+        assertTrue(_port.acceptNewConnectionAndIncrementCount(new InetSocketAddress("example.org", 0)));
+        assertEquals(9, _port.getConnectionCount());
         verify(mockLogger, times(1)).message(any(LogSubject.class), any(LogMessage.class));
 
-        assertTrue(_port.canAcceptNewConnection(new InetSocketAddress("example.org", 0)));
-        _port.incrementConnectionCount();
-        assertEquals((long) 10, (long) _port.getConnectionCount());
+        assertTrue(_port.acceptNewConnectionAndIncrementCount(new InetSocketAddress("example.org", 0)));
+        assertEquals(10, _port.getConnectionCount());
         verify(mockLogger, times(1)).message(any(LogSubject.class), any(LogMessage.class));
 
-        assertFalse(_port.canAcceptNewConnection(new InetSocketAddress("example.org", 0)));
+        assertFalse(_port.acceptNewConnectionAndIncrementCount(new InetSocketAddress("example.org", 0)));
     }
 
     @Test
-    public void testTlProtocolsAndCypherSuitesUsingAllowDenyListContextVariable()
+    public void resetStatistics()
     {
-        final Map<String, String> brokerContext = new HashMap<>();
-        brokerContext.put(CommonProperties.QPID_SECURITY_TLS_PROTOCOL_ALLOW_LIST, "[\"TLSv1.3\"]");
-        brokerContext.put(CommonProperties.QPID_SECURITY_TLS_PROTOCOL_DENY_LIST, "[\"Ssl.*\",\"TLSv1\",\"TLSv1.1\",\"TLSv1.2\"]");
-        brokerContext.put(CommonProperties.QPID_SECURITY_TLS_CIPHER_SUITE_ALLOW_LIST, "[\"(TLS|SSL)_AES_128_GCM_SHA256\", \"(TLS|SSL)_AES_256_GCM_SHA384\"]");
-        brokerContext.put(CommonProperties.QPID_SECURITY_TLS_CIPHER_SUITE_DENY_LIST, "[\".*CBC.*\"]");
+        final Map<String, Object> attributes = Map.of(
+                AmqpPort.PORT, 0,
+                AmqpPort.NAME, getTestName(),
+                AmqpPort.AUTHENTICATION_PROVIDER, AUTHENTICATION_PROVIDER_NAME,
+                AmqpPort.MAX_OPEN_CONNECTIONS, 10,
+                AmqpPort.CONTEXT, Map.of(AmqpPort.OPEN_CONNECTIONS_WARN_PERCENT, "80"));
+        _port = new AmqpPortImpl(attributes, _broker);
+        _port.create();
 
-        when(_broker.getContext()).thenReturn(brokerContext);
+        _port.acceptNewConnectionAndIncrementCount(new InetSocketAddress("example.org", 0));
 
-        _port = createPort(getTestName());
-        final List<String> expectedAllowedTlsProtocols = Collections.singletonList("TLSv1.3");
-        final List<String> expectedDeniedTlsProtocols = Arrays.asList("Ssl.*","TLSv1","TLSv1.1","TLSv1.2");
-        final List<String> expectedAllowedTlsCypherSuites = Arrays.asList("(TLS|SSL)_AES_128_GCM_SHA256", "(TLS|SSL)_AES_256_GCM_SHA384");
-        final List<String> expectedDeniedTlsCypherSuites = Collections.singletonList(".*CBC.*");
-        assertThat(_port.getTlsProtocolAllowList(), is(equalTo(expectedAllowedTlsProtocols)));
-        assertThat(_port.getTlsProtocolWhiteList(), is(equalTo(expectedAllowedTlsProtocols)));
-        assertThat(_port.getTlsProtocolDenyList(), is(equalTo(expectedDeniedTlsProtocols)));
-        assertThat(_port.getTlsProtocolBlackList(), is(equalTo(expectedDeniedTlsProtocols)));
-        assertThat(_port.getTlsCipherSuiteAllowList(), is(equalTo(expectedAllowedTlsCypherSuites)));
-        assertThat(_port.getTlsCipherSuiteWhiteList(), is(equalTo(expectedAllowedTlsCypherSuites)));
-        assertThat(_port.getTlsCipherSuiteDenyList(), is(equalTo(expectedDeniedTlsCypherSuites)));
-        assertThat(_port.getTlsCipherSuiteBlackList(), is(equalTo(expectedDeniedTlsCypherSuites)));
-    }
+        final Map<String, Object> statisticsBeforeReset = _port.getStatistics();
+        assertEquals(1L, statisticsBeforeReset.get("totalConnectionCount"));
 
-    @Test
-    public void testTlProtocolsAndCypherSuitesUsingWhiteBlackListContextVariable()
-    {
-        final Map<String, String> brokerContext = new HashMap<>();
-        brokerContext.put(CommonProperties.QPID_SECURITY_TLS_PROTOCOL_WHITE_LIST, "[\"TLSv1.3\"]");
-        brokerContext.put(CommonProperties.QPID_SECURITY_TLS_PROTOCOL_BLACK_LIST, "[\"Ssl.*\",\"TLSv1\",\"TLSv1.1\",\"TLSv1.2\"]");
-        brokerContext.put(CommonProperties.QPID_SECURITY_TLS_CIPHER_SUITE_WHITE_LIST, "[\"(TLS|SSL)_AES_128_GCM_SHA256\", \"(TLS|SSL)_AES_256_GCM_SHA384\"]");
-        brokerContext.put(CommonProperties.QPID_SECURITY_TLS_CIPHER_SUITE_BLACK_LIST, "[\".*CBC.*\"]");
+        _port.resetStatistics();
 
-        when(_broker.getContext()).thenReturn(brokerContext);
-
-        _port = createPort(getTestName());
-        final List<String> expectedAllowedTlsProtocols = Collections.singletonList("TLSv1.3");
-        final List<String> expectedDeniedTlsProtocols = Arrays.asList("Ssl.*","TLSv1","TLSv1.1","TLSv1.2");
-        final List<String> expectedAllowedTlsCypherSuites = Arrays.asList("(TLS|SSL)_AES_128_GCM_SHA256", "(TLS|SSL)_AES_256_GCM_SHA384");
-        final List<String> expectedDeniedTlsCypherSuites = Collections.singletonList(".*CBC.*");
-        assertThat(_port.getTlsProtocolAllowList(), is(equalTo(expectedAllowedTlsProtocols)));
-        assertThat(_port.getTlsProtocolWhiteList(), is(equalTo(expectedAllowedTlsProtocols)));
-        assertThat(_port.getTlsProtocolDenyList(), is(equalTo(expectedDeniedTlsProtocols)));
-        assertThat(_port.getTlsProtocolBlackList(), is(equalTo(expectedDeniedTlsProtocols)));
-        assertThat(_port.getTlsCipherSuiteAllowList(), is(equalTo(expectedAllowedTlsCypherSuites)));
-        assertThat(_port.getTlsCipherSuiteWhiteList(), is(equalTo(expectedAllowedTlsCypherSuites)));
-        assertThat(_port.getTlsCipherSuiteDenyList(), is(equalTo(expectedDeniedTlsCypherSuites)));
-        assertThat(_port.getTlsCipherSuiteBlackList(), is(equalTo(expectedDeniedTlsCypherSuites)));
-    }
-
-    @Test
-    public void testTlProtocolsAndCypherSuitesUsingAllowDenyAndWhiteBlackListContextVariable()
-    {
-        final Map<String, String> brokerContext = new HashMap<>();
-        brokerContext.put(CommonProperties.QPID_SECURITY_TLS_PROTOCOL_ALLOW_LIST, "[\"TLSv1.3\"]");
-        brokerContext.put(CommonProperties.QPID_SECURITY_TLS_PROTOCOL_DENY_LIST, "[\"Ssl.*\",\"TLSv1\",\"TLSv1.1\",\"TLSv1.2\"]");
-        brokerContext.put(CommonProperties.QPID_SECURITY_TLS_CIPHER_SUITE_ALLOW_LIST, "[\"(TLS|SSL)_AES_128_GCM_SHA256\", \"(TLS|SSL)_AES_256_GCM_SHA384\"]");
-        brokerContext.put(CommonProperties.QPID_SECURITY_TLS_CIPHER_SUITE_DENY_LIST, "[\".*CBC.*\"]");
-        brokerContext.put(CommonProperties.QPID_SECURITY_TLS_PROTOCOL_WHITE_LIST, "[\"TLSv1.2\"]");
-        brokerContext.put(CommonProperties.QPID_SECURITY_TLS_PROTOCOL_BLACK_LIST, "[\"Ssl.*\",\"TLSv1\",\"TLSv1.1\",\"TLSv1.3\"]");
-        brokerContext.put(CommonProperties.QPID_SECURITY_TLS_CIPHER_SUITE_WHITE_LIST, "[\".*CBC.*\"]");
-        brokerContext.put(CommonProperties.QPID_SECURITY_TLS_CIPHER_SUITE_BLACK_LIST, "[\".*GCM.*\"]");
-
-        when(_broker.getContext()).thenReturn(brokerContext);
-
-        _port = createPort(getTestName());
-        final List<String> expectedAllowedTlsProtocols = Collections.singletonList("TLSv1.3");
-        final List<String> expectedDeniedTlsProtocols = Arrays.asList("Ssl.*","TLSv1","TLSv1.1","TLSv1.2");
-        final List<String> expectedAllowedTlsCypherSuites = Arrays.asList("(TLS|SSL)_AES_128_GCM_SHA256", "(TLS|SSL)_AES_256_GCM_SHA384");
-        final List<String> expectedDeniedTlsCypherSuites = Collections.singletonList(".*CBC.*");
-        assertThat(_port.getTlsProtocolAllowList(), is(equalTo(expectedAllowedTlsProtocols)));
-        assertThat(_port.getTlsProtocolWhiteList(), is(equalTo(expectedAllowedTlsProtocols)));
-        assertThat(_port.getTlsProtocolDenyList(), is(equalTo(expectedDeniedTlsProtocols)));
-        assertThat(_port.getTlsProtocolBlackList(), is(equalTo(expectedDeniedTlsProtocols)));
-        assertThat(_port.getTlsCipherSuiteAllowList(), is(equalTo(expectedAllowedTlsCypherSuites)));
-        assertThat(_port.getTlsCipherSuiteWhiteList(), is(equalTo(expectedAllowedTlsCypherSuites)));
-        assertThat(_port.getTlsCipherSuiteDenyList(), is(equalTo(expectedDeniedTlsCypherSuites)));
-        assertThat(_port.getTlsCipherSuiteBlackList(), is(equalTo(expectedDeniedTlsCypherSuites)));
+        final Map<String, Object> statisticsAfterReset = _port.getStatistics();
+        assertEquals(0L, statisticsAfterReset.get("totalConnectionCount"));
     }
 
     private AmqpPortImpl createPort(final String portName)
