@@ -35,6 +35,7 @@ import java.util.List;
 import java.util.Map;
 import java.util.UUID;
 
+import org.apache.qpid.server.configuration.CommonProperties;
 import org.junit.Before;
 import org.junit.Test;
 
@@ -50,10 +51,10 @@ import org.apache.qpid.test.utils.UnitTestBase;
 
 public class BrokerStoreUpgraderAndRecovererTest extends UnitTestBase
 {
-    private static final long BROKER_CREATE_TIME = 1401385808828l;
+    private static final long BROKER_CREATE_TIME = 1401385808828L;
     private static final String BROKER_NAME = "Broker";
     private static final String VIRTUALHOST_NAME = "test";
-    private static final long VIRTUALHOST_CREATE_TIME = 1401385905260l;
+    private static final long VIRTUALHOST_CREATE_TIME = 1401385905260L;
     private static final String VIRTUALHOST_CREATED_BY = "webadmin";
 
     private ConfiguredObjectRecord _brokerRecord;
@@ -741,7 +742,8 @@ public class BrokerStoreUpgraderAndRecovererTest extends UnitTestBase
                                                                             trustStoreAttributes3,
                                                                             parents);
 
-        DurableConfigurationStore dcs = new DurableConfigurationStoreStub(_brokerRecord, trustStore1, trustStore2, trustStore3);
+        DurableConfigurationStore dcs =
+                new DurableConfigurationStoreStub(_brokerRecord, trustStore1, trustStore2, trustStore3);
         BrokerStoreUpgraderAndRecoverer recoverer = new BrokerStoreUpgraderAndRecoverer(_systemConfig);
         List<ConfiguredObjectRecord> records = upgrade(dcs, recoverer);
 
@@ -801,7 +803,8 @@ public class BrokerStoreUpgraderAndRecovererTest extends UnitTestBase
                                                                            jmxPluginAttributes,
                                                                            parents);
 
-        DurableConfigurationStore dcs = new DurableConfigurationStoreStub(_brokerRecord, jmxPort, rmiPort, jmxManagement);
+        DurableConfigurationStore dcs =
+                new DurableConfigurationStoreStub(_brokerRecord, jmxPort, rmiPort, jmxManagement);
 
         BrokerStoreUpgraderAndRecoverer recoverer = new BrokerStoreUpgraderAndRecoverer(_systemConfig);
         List<ConfiguredObjectRecord> records = upgrade(dcs, recoverer);
@@ -888,6 +891,121 @@ public class BrokerStoreUpgraderAndRecovererTest extends UnitTestBase
                            upgradedAttributes.containsKey("conection.closeWhenNoRoute"));
     }
 
+    @Test
+    public void testContextVariableUpgradeForTLSProtocolsSetOnBroker()
+    {
+        final Map<String, String> context = new HashMap<>();
+        context.put("qpid.security.tls.protocolWhiteList", ".*");
+        context.put("qpid.security.tls.protocolBlackList", "Ssl.*");
+
+        _brokerRecord.getAttributes().put("modelVersion", "8.0");
+        _brokerRecord.getAttributes().put("context", context);
+
+        final DurableConfigurationStore dcs = new DurableConfigurationStoreStub(_brokerRecord);
+        final BrokerStoreUpgraderAndRecoverer recoverer = new BrokerStoreUpgraderAndRecoverer(_systemConfig);
+        final List<ConfiguredObjectRecord> records = upgrade(dcs, recoverer);
+
+        final Map<String, String> contextMap = findCategoryRecordAndGetContext("Broker", records);
+
+        assertEquals(".*", contextMap.get(CommonProperties.QPID_SECURITY_TLS_PROTOCOL_ALLOW_LIST));
+        assertEquals("Ssl.*", contextMap.get(CommonProperties.QPID_SECURITY_TLS_PROTOCOL_DENY_LIST));
+    }
+
+
+    @Test
+    public void testContextVariableUpgradeForTLSCipherSuitesSetOnBroker()
+    {
+        final Map<String, String> context = new HashMap<>();
+        context.put("qpid.security.tls.cipherSuiteWhiteList", ".*");
+        context.put("qpid.security.tls.cipherSuiteBlackList", "Ssl.*");
+
+        _brokerRecord.getAttributes().put("modelVersion", "8.0");
+        _brokerRecord.getAttributes().put("context", context);
+
+        final DurableConfigurationStore dcs = new DurableConfigurationStoreStub(_brokerRecord);
+        final BrokerStoreUpgraderAndRecoverer recoverer = new BrokerStoreUpgraderAndRecoverer(_systemConfig);
+        final List<ConfiguredObjectRecord> records = upgrade(dcs, recoverer);
+
+        final Map<String, String> contextMap = findCategoryRecordAndGetContext("Broker", records);
+
+        assertEquals(".*", contextMap.get(CommonProperties.QPID_SECURITY_TLS_CIPHER_SUITE_ALLOW_LIST));
+        assertEquals("Ssl.*", contextMap.get(CommonProperties.QPID_SECURITY_TLS_CIPHER_SUITE_DENY_LIST));
+    }
+
+    @Test
+    public void testContextVariableUpgradeForTLSProtocolsSetOnPort()
+    {
+        _brokerRecord.getAttributes().put("modelVersion", "8.0");
+
+        final Map<String, String> context = new HashMap<>();
+        context.put("qpid.security.tls.protocolWhiteList", ".*");
+        context.put("qpid.security.tls.protocolBlackList", "Ssl.*");
+
+        final ConfiguredObjectRecord portRecord =
+                createMockRecordForGivenCategoryTypeAndContext("Port", "AMQP", context);
+
+        final DurableConfigurationStore dcs = new DurableConfigurationStoreStub(portRecord, _brokerRecord);
+        final BrokerStoreUpgraderAndRecoverer recoverer = new BrokerStoreUpgraderAndRecoverer(_systemConfig);
+
+        final List<ConfiguredObjectRecord> records = upgrade(dcs, recoverer);
+
+        final Map<String, String> contextMap = findCategoryRecordAndGetContext("Port", records);
+
+        assertEquals(".*", contextMap.get(CommonProperties.QPID_SECURITY_TLS_PROTOCOL_ALLOW_LIST));
+        assertEquals("Ssl.*", contextMap.get(CommonProperties.QPID_SECURITY_TLS_PROTOCOL_DENY_LIST));
+    }
+
+    @Test
+    public void testContextVariableUpgradeForTLSCipherSuitesSetOnAuthenticationProvider()
+    {
+        _brokerRecord.getAttributes().put("modelVersion", "8.0");
+
+        final Map<String, String> context = new HashMap<>();
+        context.put("qpid.security.tls.cipherSuiteWhiteList", ".*");
+        context.put("qpid.security.tls.cipherSuiteBlackList", "Ssl.*");
+        final ConfiguredObjectRecord authenticationProviderRecord =
+                createMockRecordForGivenCategoryTypeAndContext("AuthenticationProvider", "OAuth2", context);
+
+        final DurableConfigurationStore dcs =
+                new DurableConfigurationStoreStub(authenticationProviderRecord, _brokerRecord);
+        final BrokerStoreUpgraderAndRecoverer recoverer = new BrokerStoreUpgraderAndRecoverer(_systemConfig);
+
+        final List<ConfiguredObjectRecord> records = upgrade(dcs, recoverer);
+
+        final Map<String, String> contextMap = findCategoryRecordAndGetContext("AuthenticationProvider", records);
+
+        assertEquals(".*", contextMap.get(CommonProperties.QPID_SECURITY_TLS_CIPHER_SUITE_ALLOW_LIST));
+        assertEquals("Ssl.*", contextMap.get(CommonProperties.QPID_SECURITY_TLS_CIPHER_SUITE_DENY_LIST));
+    }
+
+    private ConfiguredObjectRecord createMockRecordForGivenCategoryTypeAndContext(final String category,
+                                                                                  final String type,
+                                                                                  final Map<String, String> context)
+    {
+        final ConfiguredObjectRecord record = mock(ConfiguredObjectRecord.class);
+        when(record.getId()).thenReturn(UUID.randomUUID());
+        when(record.getType()).thenReturn(category);
+        final Map<String, Object> attributes = new HashMap<>();
+        attributes.put("name", getTestName());
+        attributes.put("type", type);
+        attributes.put("context", context);
+        when(record.getAttributes()).thenReturn(attributes);
+        return record;
+    }
+
+    @SuppressWarnings("unchecked")
+    private Map<String, String> findCategoryRecordAndGetContext(final String category,
+                                                                final List<ConfiguredObjectRecord> records)
+    {
+        final List<ConfiguredObjectRecord> foundRecords = findRecordByType(category, records);
+        assertEquals("Unexpected number of records", 1, foundRecords.size());
+        final Map<String, Object> attributes = foundRecords.get(0).getAttributes();
+        assertNotNull(attributes);
+        final Object context = attributes.get("context");
+        assertTrue(context instanceof Map);
+        return (Map<String, String>) context;
+    }
+
     private void assertModelVersionUpgraded(final List<ConfiguredObjectRecord> records)
     {
         ConfiguredObjectRecord upgradedBrokerRecord = findRecordById(_brokerRecord.getId(), records);
@@ -925,7 +1043,7 @@ public class BrokerStoreUpgraderAndRecovererTest extends UnitTestBase
         Map<String,Object> expectedAttributes = new HashMap<>();
         expectedAttributes.put("name", "Broker");
         expectedAttributes.put("modelVersion", BrokerModel.MODEL_VERSION);
-        expectedAttributes.put("createdTime", 1401385808828l);
+        expectedAttributes.put("createdTime", 1401385808828L);
         assertEquals("Unexpected broker attributes", expectedAttributes, upgradedBrokerRecord.getAttributes());
     }
 
@@ -955,9 +1073,9 @@ public class BrokerStoreUpgraderAndRecovererTest extends UnitTestBase
         return results;
     }
 
-    class DurableConfigurationStoreStub implements DurableConfigurationStore
+    static class DurableConfigurationStoreStub implements DurableConfigurationStore
     {
-        private ConfiguredObjectRecord[] records;
+        private final ConfiguredObjectRecord[] records;
 
         public DurableConfigurationStoreStub(ConfiguredObjectRecord... records)
         {
@@ -1024,9 +1142,9 @@ public class BrokerStoreUpgraderAndRecovererTest extends UnitTestBase
         }
     }
 
-    private class RecordRetrievingConfiguredObjectRecordHandler implements ConfiguredObjectRecordHandler
+    private static class RecordRetrievingConfiguredObjectRecordHandler implements ConfiguredObjectRecordHandler
     {
-        private List<ConfiguredObjectRecord> _records = new ArrayList<>();
+        private final List<ConfiguredObjectRecord> _records = new ArrayList<>();
 
         @Override
         public void handle(final ConfiguredObjectRecord record)
