@@ -20,12 +20,6 @@
  */
 package org.apache.qpid.server.security.access.config;
 
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertTrue;
-import static org.mockito.Mockito.mock;
-import static org.mockito.Mockito.verify;
-import static org.mockito.Mockito.when;
-
 import java.net.InetAddress;
 import java.net.InetSocketAddress;
 import java.security.PrivilegedAction;
@@ -33,9 +27,6 @@ import java.security.PrivilegedExceptionAction;
 
 import javax.security.auth.Subject;
 
-import org.junit.Before;
-import org.junit.Test;
-
 import org.apache.qpid.server.connection.ConnectionPrincipal;
 import org.apache.qpid.server.logging.EventLogger;
 import org.apache.qpid.server.logging.EventLoggerProvider;
@@ -47,6 +38,15 @@ import org.apache.qpid.server.security.auth.TestPrincipalUtils;
 import org.apache.qpid.server.transport.AMQPConnection;
 import org.apache.qpid.test.utils.UnitTestBase;
 
+import org.junit.Before;
+import org.junit.Test;
+
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertTrue;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
+
 
 /**
  * In these tests, the ruleset is configured programmatically rather than from an external file.
@@ -58,6 +58,8 @@ public class RuleBasedAccessControlTest extends UnitTestBase
     private static final String ALLOWED_GROUP = "allowed_group";
     private static final String DENIED_GROUP = "denied_group";
 
+    private static final ObjectProperties EMPTY = new ObjectProperties();
+
     private RuleBasedAccessControl _plugin = null;  // Class under test
     private UnitTestMessageLogger _messageLogger;
     private EventLogger _eventLogger;
@@ -84,15 +86,35 @@ public class RuleBasedAccessControlTest extends UnitTestBase
     {
         final EventLoggerProvider provider = mock(EventLoggerProvider.class);
         when(provider.getEventLogger()).thenReturn(_eventLogger);
-        RuleSetCreator rsc = new RuleSetCreator();
+        RuleCollector rsc = new RuleCollector();
 
         // Rule expressed with username
-        rsc.addRule(0, "user1", RuleOutcome.ALLOW, LegacyOperation.ACCESS, ObjectType.VIRTUALHOST, ObjectProperties.EMPTY);
+        rsc.addRule(0, new Rule.Builder()
+                .withIdentity("user1")
+                .withOutcome(RuleOutcome.ALLOW)
+                .withOperation(LegacyOperation.ACCESS)
+                .withObject(ObjectType.VIRTUALHOST)
+                .build());
         // Rules expressed with groups
-        rsc.addRule(1, ALLOWED_GROUP, RuleOutcome.ALLOW, LegacyOperation.ACCESS, ObjectType.VIRTUALHOST, ObjectProperties.EMPTY);
-        rsc.addRule(2, DENIED_GROUP, RuleOutcome.DENY, LegacyOperation.ACCESS, ObjectType.VIRTUALHOST, ObjectProperties.EMPTY);
+        rsc.addRule(1, new Rule.Builder()
+                .withIdentity(ALLOWED_GROUP)
+                .withOutcome(RuleOutcome.ALLOW)
+                .withOperation(LegacyOperation.ACCESS)
+                .withObject(ObjectType.VIRTUALHOST)
+                .build());
+        rsc.addRule(2, new Rule.Builder()
+                .withIdentity(DENIED_GROUP)
+                .withOutcome(RuleOutcome.DENY)
+                .withOperation(LegacyOperation.ACCESS)
+                .withObject(ObjectType.VIRTUALHOST)
+                .build());
         // Catch all rule
-        rsc.addRule(3, Rule.ALL, RuleOutcome.DENY_LOG, LegacyOperation.ACCESS, ObjectType.VIRTUALHOST, ObjectProperties.EMPTY);
+        rsc.addRule(3, new Rule.Builder()
+                .withIdentity(Rule.ALL)
+                .withOutcome(RuleOutcome.DENY_LOG)
+                .withOperation(LegacyOperation.ACCESS)
+                .withObject(ObjectType.VIRTUALHOST)
+                .build());
 
         return rsc.createRuleSet(provider);
     }
@@ -104,7 +126,7 @@ public class RuleBasedAccessControlTest extends UnitTestBase
     public void testNoSubjectAlwaysDefers()
     {
         setUpGroupAccessControl();
-        final Result result = _plugin.authorise(LegacyOperation.ACCESS, ObjectType.VIRTUALHOST, ObjectProperties.EMPTY);
+        final Result result = _plugin.authorise(LegacyOperation.ACCESS, ObjectType.VIRTUALHOST, EMPTY);
         assertEquals(Result.DEFER, result);
     }
 
@@ -121,7 +143,7 @@ public class RuleBasedAccessControlTest extends UnitTestBase
             @Override
             public Object run()
             {
-                final Result result = _plugin.authorise(LegacyOperation.ACCESS, ObjectType.VIRTUALHOST, ObjectProperties.EMPTY);
+                final Result result = _plugin.authorise(LegacyOperation.ACCESS, ObjectType.VIRTUALHOST, EMPTY);
 
                 assertEquals(Result.ALLOWED, result);
                 return null;
@@ -172,7 +194,7 @@ public class RuleBasedAccessControlTest extends UnitTestBase
                                                  (long) _messageLogger.getLogMessages().size());
 
                              final Result result = _plugin.authorise(LegacyOperation.ACCESS, ObjectType.VIRTUALHOST,
-                                                                     ObjectProperties.EMPTY);
+                                                                     EMPTY);
                              assertEquals(Result.DENIED, result);
 
                              assertEquals("Expecting one message before test",
@@ -192,10 +214,15 @@ public class RuleBasedAccessControlTest extends UnitTestBase
     @Test
     public void testAuthoriseAccessMethodWhenAllAccessOperationsAllowedOnAllComponents()
     {
-        final RuleSetCreator rs = new RuleSetCreator();
-
+        final RuleCollector rs = new RuleCollector();
         // grant user4 access right on any method in any component
-        rs.addRule(1, "user4", RuleOutcome.ALLOW, LegacyOperation.ACCESS, ObjectType.METHOD, new ObjectProperties(ObjectProperties.WILD_CARD));
+        rs.addRule(1, new Rule.Builder()
+                .withPredicate(Property.NAME, AclRulePredicatesBuilder.WILD_CARD)
+                .withIdentity("user4")
+                .withOutcome(RuleOutcome.ALLOW)
+                .withOperation(LegacyOperation.ACCESS)
+                .withObject(ObjectType.METHOD)
+                .build());
         configureAccessControl(rs.createRuleSet(mock(EventLoggerProvider.class)));
         Subject.doAs(TestPrincipalUtils.createTestSubject("user4"), new PrivilegedAction<Object>()
         {
@@ -203,7 +230,7 @@ public class RuleBasedAccessControlTest extends UnitTestBase
             public Object run()
             {
                 ObjectProperties actionProperties = new ObjectProperties("getName");
-                actionProperties.put(ObjectProperties.Property.COMPONENT, "Test");
+                actionProperties.put(Property.COMPONENT, "Test");
 
                 final Result result = _plugin.authorise(LegacyOperation.ACCESS, ObjectType.METHOD, actionProperties);
                 assertEquals(Result.ALLOWED, result);
@@ -219,12 +246,17 @@ public class RuleBasedAccessControlTest extends UnitTestBase
     @Test
     public void testAuthoriseAccessMethodWhenAllAccessOperationsAllowedOnSpecifiedComponent()
     {
-        final RuleSetCreator rs = new RuleSetCreator();
+        final RuleCollector rs = new RuleCollector();
 
         // grant user5 access right on any methods in "Test" component
-        ObjectProperties ruleProperties = new ObjectProperties(ObjectProperties.WILD_CARD);
-        ruleProperties.put(ObjectProperties.Property.COMPONENT, "Test");
-        rs.addRule(1, "user5", RuleOutcome.ALLOW, LegacyOperation.ACCESS, ObjectType.METHOD, ruleProperties);
+        rs.addRule(1, new Rule.Builder()
+                .withPredicate(Property.NAME, AclRulePredicatesBuilder.WILD_CARD)
+                .withPredicate(Property.COMPONENT, "Test")
+                .withIdentity("user5")
+                .withOutcome(RuleOutcome.ALLOW)
+                .withOperation(LegacyOperation.ACCESS)
+                .withObject(ObjectType.METHOD)
+                .build());
         configureAccessControl(rs.createRuleSet(mock(EventLoggerProvider.class)));
         Subject.doAs(TestPrincipalUtils.createTestSubject("user5"), new PrivilegedAction<Object>()
         {
@@ -232,11 +264,11 @@ public class RuleBasedAccessControlTest extends UnitTestBase
             public Object run()
             {
                 ObjectProperties actionProperties = new ObjectProperties("getName");
-                actionProperties.put(ObjectProperties.Property.COMPONENT, "Test");
+                actionProperties.put(Property.COMPONENT, "Test");
                 Result result = _plugin.authorise(LegacyOperation.ACCESS, ObjectType.METHOD, actionProperties);
                 assertEquals(Result.ALLOWED, result);
 
-                actionProperties.put(ObjectProperties.Property.COMPONENT, "Test2");
+                actionProperties.put(Property.COMPONENT, "Test2");
                 result = _plugin.authorise(LegacyOperation.ACCESS, ObjectType.METHOD, actionProperties);
                 assertEquals(Result.DEFER, result);
                 return null;
@@ -303,11 +335,11 @@ public class RuleBasedAccessControlTest extends UnitTestBase
                         subject,
                         LegacyOperation.ACCESS,
                         ObjectType.VIRTUALHOST,
-                        ObjectProperties.EMPTY)).thenThrow(new RuntimeException());
+                        EMPTY)).thenThrow(new RuntimeException());
 
                 RuleBasedAccessControl accessControl = new RuleBasedAccessControl(mockRuleSet,
                                                                                   BrokerModel.getInstance());
-                Result result = accessControl.authorise(LegacyOperation.ACCESS, ObjectType.VIRTUALHOST, ObjectProperties.EMPTY);
+                Result result = accessControl.authorise(LegacyOperation.ACCESS, ObjectType.VIRTUALHOST, EMPTY);
 
                 assertEquals(Result.DENIED, result);
                 return null;
@@ -323,12 +355,17 @@ public class RuleBasedAccessControlTest extends UnitTestBase
     @Test
     public void testAuthoriseAccessMethodWhenSpecifiedAccessOperationsAllowedOnSpecifiedComponent()
     {
-        final RuleSetCreator rs = new RuleSetCreator();
+        final RuleCollector rs = new RuleCollector();
 
         // grant user6 access right on "getAttribute" method in "Test" component
-        ObjectProperties ruleProperties = new ObjectProperties("getAttribute");
-        ruleProperties.put(ObjectProperties.Property.COMPONENT, "Test");
-        rs.addRule(1, "user6", RuleOutcome.ALLOW, LegacyOperation.ACCESS, ObjectType.METHOD, ruleProperties);
+        rs.addRule(1, new Rule.Builder()
+                .withPredicate(Property.NAME, "getAttribute")
+                .withPredicate(Property.COMPONENT, "Test")
+                .withIdentity("user6")
+                .withOutcome(RuleOutcome.ALLOW)
+                .withOperation(LegacyOperation.ACCESS)
+                .withObject(ObjectType.METHOD)
+                .build());
         configureAccessControl(rs.createRuleSet(mock(EventLoggerProvider.class)));
         Subject.doAs(TestPrincipalUtils.createTestSubject("user6"), new PrivilegedAction<Object>()
         {
@@ -336,16 +373,16 @@ public class RuleBasedAccessControlTest extends UnitTestBase
             public Object run()
             {
                 ObjectProperties properties = new ObjectProperties("getAttribute");
-                properties.put(ObjectProperties.Property.COMPONENT, "Test");
+                properties.put(Property.COMPONENT, "Test");
                 Result result = _plugin.authorise(LegacyOperation.ACCESS, ObjectType.METHOD, properties);
                 assertEquals(Result.ALLOWED, result);
 
-                properties.put(ObjectProperties.Property.COMPONENT, "Test2");
+                properties.put(Property.COMPONENT, "Test2");
                 result = _plugin.authorise(LegacyOperation.ACCESS, ObjectType.METHOD, properties);
                 assertEquals(Result.DEFER, result);
 
                 properties = new ObjectProperties("getAttribute2");
-                properties.put(ObjectProperties.Property.COMPONENT, "Test");
+                properties.put(Property.COMPONENT, "Test");
                 result = _plugin.authorise(LegacyOperation.ACCESS, ObjectType.METHOD, properties);
                 assertEquals(Result.DEFER, result);
 
@@ -361,10 +398,15 @@ public class RuleBasedAccessControlTest extends UnitTestBase
     @Test
     public void testAuthoriseAccessUpdateMethodWhenAllRightsGrantedOnSpecifiedMethodForAllComponents()
     {
-        final RuleSetCreator rs = new RuleSetCreator();
-
+        final RuleCollector rs = new RuleCollector();
         // grant user8 all rights on method queryNames in all component
-        rs.addRule(1, "user8", RuleOutcome.ALLOW, LegacyOperation.ALL, ObjectType.METHOD, new ObjectProperties("queryNames"));
+        rs.addRule(1, new Rule.Builder()
+                .withPredicate(Property.NAME, "queryNames")
+                .withIdentity("user8")
+                .withOutcome(RuleOutcome.ALLOW)
+                .withOperation(LegacyOperation.ALL)
+                .withObject(ObjectType.METHOD)
+                .build());
         configureAccessControl(rs.createRuleSet(mock(EventLoggerProvider.class)));
         Subject.doAs(TestPrincipalUtils.createTestSubject("user8"), new PrivilegedAction<Object>()
         {
@@ -372,8 +414,8 @@ public class RuleBasedAccessControlTest extends UnitTestBase
             public Object run()
             {
                 ObjectProperties properties = new ObjectProperties();
-                properties.put(ObjectProperties.Property.COMPONENT, "Test");
-                properties.put(ObjectProperties.Property.NAME, "queryNames");
+                properties.put(Property.COMPONENT, "Test");
+                properties.put(Property.NAME, "queryNames");
 
                 Result result = _plugin.authorise(LegacyOperation.ACCESS, ObjectType.METHOD, properties);
                 assertEquals(Result.ALLOWED, result);
@@ -382,7 +424,7 @@ public class RuleBasedAccessControlTest extends UnitTestBase
                 assertEquals(Result.ALLOWED, result);
 
                 properties = new ObjectProperties("getAttribute");
-                properties.put(ObjectProperties.Property.COMPONENT, "Test");
+                properties.put(Property.COMPONENT, "Test");
                 result = _plugin.authorise(LegacyOperation.UPDATE, ObjectType.METHOD, properties);
                 assertEquals(Result.DEFER, result);
 
@@ -401,10 +443,15 @@ public class RuleBasedAccessControlTest extends UnitTestBase
     @Test
     public void testAuthoriseAccessUpdateMethodWhenAllRightsGrantedOnAllMethodsInAllComponents()
     {
-        final RuleSetCreator rs = new RuleSetCreator();
+        final RuleCollector rs = new RuleCollector();
 
         // grant user9 all rights on any method in all component
-        rs.addRule(1, "user9", RuleOutcome.ALLOW, LegacyOperation.ALL, ObjectType.METHOD, new ObjectProperties());
+        rs.addRule(1, new Rule.Builder()
+                .withIdentity("user9")
+                .withOutcome(RuleOutcome.ALLOW)
+                .withOperation(LegacyOperation.ALL)
+                .withObject(ObjectType.METHOD)
+                .build());
         configureAccessControl(rs.createRuleSet(mock(EventLoggerProvider.class)));
         Subject.doAs(TestPrincipalUtils.createTestSubject("user9"), new PrivilegedAction<Object>()
         {
@@ -412,7 +459,7 @@ public class RuleBasedAccessControlTest extends UnitTestBase
             public Object run()
             {
                 ObjectProperties properties = new ObjectProperties("queryNames");
-                properties.put(ObjectProperties.Property.COMPONENT, "Test");
+                properties.put(Property.COMPONENT, "Test");
 
                 Result result = _plugin.authorise(LegacyOperation.ACCESS, ObjectType.METHOD, properties);
                 assertEquals(Result.ALLOWED, result);
@@ -421,7 +468,7 @@ public class RuleBasedAccessControlTest extends UnitTestBase
                 assertEquals(Result.ALLOWED, result);
 
                 properties = new ObjectProperties("getAttribute");
-                properties.put(ObjectProperties.Property.COMPONENT, "Test");
+                properties.put(Property.COMPONENT, "Test");
                 result = _plugin.authorise(LegacyOperation.UPDATE, ObjectType.METHOD, properties);
                 assertEquals(Result.ALLOWED, result);
 
@@ -440,14 +487,19 @@ public class RuleBasedAccessControlTest extends UnitTestBase
     @Test
     public void testAuthoriseAccessMethodWhenMatchingAccessOperationsAllowedOnSpecifiedComponent()
     {
-        final RuleSetCreator rs = new RuleSetCreator();
+        final RuleCollector rs = new RuleCollector();
 
         // grant user9 all rights on "getAttribute*" methods in Test component
-        ObjectProperties ruleProperties = new ObjectProperties();
-        ruleProperties.put(ObjectProperties.Property.COMPONENT, "Test");
-        ruleProperties.put(ObjectProperties.Property.NAME, "getAttribute*");
+        final Rule rule = new Rule.Builder()
+                .withPredicate(Property.COMPONENT, "Test")
+                .withPredicate(Property.NAME, "getAttribute*")
+                .withIdentity("user9")
+                .withOutcome(RuleOutcome.ALLOW)
+                .withOperation(LegacyOperation.ACCESS)
+                .withObject(ObjectType.METHOD)
+                .build();
 
-        rs.addRule(1, "user9", RuleOutcome.ALLOW, LegacyOperation.ACCESS, ObjectType.METHOD, ruleProperties);
+        rs.addRule(1, rule);
         configureAccessControl(rs.createRuleSet(mock(EventLoggerProvider.class)));
         Subject.doAs(TestPrincipalUtils.createTestSubject("user9"), new PrivilegedAction<Object>()
         {
@@ -455,17 +507,17 @@ public class RuleBasedAccessControlTest extends UnitTestBase
             public Object run()
             {
                 ObjectProperties properties = new ObjectProperties("getAttributes");
-                properties.put(ObjectProperties.Property.COMPONENT, "Test");
+                properties.put(Property.COMPONENT, "Test");
                 Result result = _plugin.authorise(LegacyOperation.ACCESS, ObjectType.METHOD, properties);
                 assertEquals(Result.ALLOWED, result);
 
                 properties = new ObjectProperties("getAttribute");
-                properties.put(ObjectProperties.Property.COMPONENT, "Test");
+                properties.put(Property.COMPONENT, "Test");
                 result = _plugin.authorise(LegacyOperation.ACCESS, ObjectType.METHOD, properties);
                 assertEquals(Result.ALLOWED, result);
 
                 properties = new ObjectProperties("getAttribut");
-                properties.put(ObjectProperties.Property.COMPONENT, "Test");
+                properties.put(Property.COMPONENT, "Test");
                 result = _plugin.authorise(LegacyOperation.ACCESS, ObjectType.METHOD, properties);
                 assertEquals(Result.DEFER, result);
                 return null;
@@ -481,7 +533,7 @@ public class RuleBasedAccessControlTest extends UnitTestBase
             @Override
             public Object run()
             {
-                Result result = _plugin.authorise(LegacyOperation.ACCESS, ObjectType.VIRTUALHOST, ObjectProperties.EMPTY);
+                Result result = _plugin.authorise(LegacyOperation.ACCESS, ObjectType.VIRTUALHOST, EMPTY);
                 assertEquals(expectedResult, result);
                 return null;
             }
