@@ -50,6 +50,7 @@ import org.apache.qpid.server.security.auth.AuthenticationResult.AuthenticationS
 import org.apache.qpid.server.security.auth.SubjectAuthenticationResult;
 import org.apache.qpid.server.security.auth.sasl.SaslNegotiator;
 import org.apache.qpid.server.security.auth.sasl.SaslSettings;
+import org.apache.qpid.server.security.limit.ConnectionLimitException;
 import org.apache.qpid.server.transport.AMQPConnection;
 import org.apache.qpid.server.util.ConnectionScopedRuntimeException;
 import org.apache.qpid.server.virtualhost.VirtualHostUnavailableException;
@@ -59,17 +60,16 @@ public class ServerConnectionDelegate extends MethodDelegate<ServerConnection> i
     private static final Logger LOGGER = LoggerFactory.getLogger(ServerConnectionDelegate.class);
     static final String MESSAGE_DIGEST_SHA1 = "SHA-1";
     static final int BASE64_LIMIT = 64;
+
     private final AmqpPort<?> _port;
+    private final List<Object> _mechanisms;
+    private final Broker<?> _broker;
+    private final int _maxNoOfChannels;
+    private final SubjectCreator _subjectCreator;
+    private final int _maximumFrameSize;
 
     private List<Object> _locales;
-    private List<Object> _mechanisms;
-
-    private final Broker<?> _broker;
-    private int _maxNoOfChannels;
     private Map<String,Object> _clientProperties;
-    private final SubjectCreator _subjectCreator;
-    private int _maximumFrameSize;
-
     private boolean _compressionSupported;
     private volatile SaslNegotiator _saslNegotiator;
 
@@ -86,7 +86,6 @@ public class ServerConnectionDelegate extends MethodDelegate<ServerConnection> i
     private volatile ConnectionState _state = ConnectionState.INIT;
     private volatile SubjectAuthenticationResult _successfulAuthenticationResult;
 
-
     public ServerConnectionDelegate(AmqpPort<?> port, boolean secure, final String selectedHost)
     {
         _port = port;
@@ -269,8 +268,10 @@ public class ServerConnectionDelegate extends MethodDelegate<ServerConnection> i
 
             try
             {
+                final AMQPConnection_0_10 amqpConnection = sconn.getAmqpConnection();
+
                 sconn.setVirtualHost(addressSpace);
-                if(!addressSpace.authoriseCreateConnection(sconn.getAmqpConnection()))
+                if(!addressSpace.authoriseCreateConnection(amqpConnection))
                 {
                     sconn.setState(ServerConnection.State.CLOSING);
                     sconn.sendConnectionClose(ConnectionCloseCode.CONNECTION_FORCED, "Connection not authorized");
@@ -283,6 +284,12 @@ public class ServerConnectionDelegate extends MethodDelegate<ServerConnection> i
                 sconn.sendConnectionClose(ConnectionCloseCode.CONNECTION_FORCED, e.getMessage());
                 return;
             }
+            catch (ConnectionLimitException e)
+            {
+                LOGGER.debug("User connection limit exceeded", e);
+                sconn.setState(ServerConnection.State.CLOSING);
+                sconn.sendConnectionClose(ConnectionCloseCode.CONNECTION_FORCED, e.getMessage());
+            }
 
             sconn.setState(ServerConnection.State.OPEN);
             _state = ConnectionState.OPEN;
