@@ -78,7 +78,7 @@ public class OAuth2InteractiveAuthenticator implements HttpRequestInteractiveAut
         ERROR_RESPONSES = Collections.unmodifiableMap(errorResponses);
     }
 
-    private SecureRandom _random = new SecureRandom();
+    private final SecureRandom _random = new SecureRandom();
 
     @Override
     public String getType()
@@ -103,7 +103,9 @@ public class OAuth2InteractiveAuthenticator implements HttpRequestInteractiveAut
             }
             catch (IllegalArgumentException e)
             {
-                return new FailedAuthenticationHandler(400, "Some request parameters are included more than once " + request, e);
+                return new FailedAuthenticationHandler(400,
+                                                       "Some request parameters are included more than once " + request,
+                                                       e);
             }
 
             String error = requestParameters.get("error");
@@ -121,7 +123,8 @@ public class OAuth2InteractiveAuthenticator implements HttpRequestInteractiveAut
                 {
                     LOGGER.warn("Authorization endpoint failed, error : '{}', error description '{}'",
                                 error, errorDescription);
-                    return new FailedAuthenticationHandler(responseCode, String.format("Authorization request failed :'%s'", error));
+                    return new FailedAuthenticationHandler(responseCode,
+                                                           String.format("Authorization request failed :'%s'", error));
                 }
             }
 
@@ -145,7 +148,8 @@ public class OAuth2InteractiveAuthenticator implements HttpRequestInteractiveAut
                 if (state == null)
                 {
                     LOGGER.warn("Deny login attempt with wrong state: {}", state);
-                    return new FailedAuthenticationHandler(400, "No state set on request with authorization code grant: "
+                    return new FailedAuthenticationHandler(400,
+                                                           "No state set on request with authorization code grant: "
                                                            + request);
                 }
                 if (!checkState(request, state))
@@ -170,9 +174,17 @@ public class OAuth2InteractiveAuthenticator implements HttpRequestInteractiveAut
                         AuthenticationResult authenticationResult = oauth2Provider.authenticateViaAuthorizationCode(authorizationCode, redirectUri, addressSpace);
                         try
                         {
-                            Subject subject = createSubject(authenticationResult);
-                            authoriseManagement(subject);
-                            HttpManagementUtil.saveAuthorisedSubject(request, subject);
+                            SubjectCreator subjectCreator = port.getSubjectCreator(request.isSecure(), request.getServerName());
+                            SubjectAuthenticationResult result = subjectCreator.createResultWithGroups(authenticationResult);
+                            Subject original = result.getSubject();
+
+                            if (original == null)
+                            {
+                                throw new SecurityException("Only authenticated users can access the management interface");
+                            }
+
+                            Broker broker = (Broker) oauth2Provider.getParent();
+                            HttpManagementUtil.createServletConnectionSubjectAssertManagementAccessAndSave(broker, request, original);
 
                             LOGGER.debug("Successful login. Redirect to original resource {}", originalRequestUri);
                             response.sendRedirect(originalRequestUri);
@@ -191,27 +203,6 @@ public class OAuth2InteractiveAuthenticator implements HttpRequestInteractiveAut
                             }
                         }
                     }
-
-                    private Subject createSubject(final AuthenticationResult authenticationResult)
-                    {
-                        SubjectCreator subjectCreator = port.getSubjectCreator(request.isSecure(), request.getServerName());
-                        SubjectAuthenticationResult result = subjectCreator.createResultWithGroups(authenticationResult);
-                        Subject original = result.getSubject();
-
-                        if (original == null)
-                        {
-                            throw new SecurityException("Only authenticated users can access the management interface");
-                        }
-
-                        Subject subject = HttpManagementUtil.createServletConnectionSubject(request, original);
-                        return subject;
-                    }
-
-                    private void authoriseManagement(final Subject subject)
-                    {
-                        Broker broker = (Broker) oauth2Provider.getParent();
-                        HttpManagementUtil.assertManagementAccess(broker, subject);
-                    }
                 };
             }
         }
@@ -372,7 +363,7 @@ public class OAuth2InteractiveAuthenticator implements HttpRequestInteractiveAut
         return ERROR_RESPONSES.containsKey(error) ? ERROR_RESPONSES.get(error) : 500;
     }
 
-    class FailedAuthenticationHandler implements AuthenticationHandler
+    static class FailedAuthenticationHandler implements AuthenticationHandler
     {
         private final int _errorCode;
         private final Throwable _throwable;
