@@ -25,7 +25,7 @@ import static org.hamcrest.CoreMatchers.equalTo;
 import static org.hamcrest.CoreMatchers.instanceOf;
 import static org.hamcrest.CoreMatchers.is;
 import static org.hamcrest.CoreMatchers.notNullValue;
-import static org.junit.Assert.assertThat;
+import static org.hamcrest.MatcherAssert.assertThat;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.when;
@@ -67,8 +67,8 @@ public class LatestManagementControllerAdapterTest extends UnitTestBase
     {
         final HttpManagementConfiguration<?> httpManagement = mock(HttpManagementConfiguration.class);
         when(httpManagement.getContextValue(Long.class, PREFERENCE_OPERTAION_TIMEOUT_CONTEXT_NAME)).thenReturn(1000L);
+        when(httpManagement.getModel()).thenReturn(BrokerModel.getInstance());
         final ManagementController managementController = new LatestManagementController(httpManagement);
-        when(managementController.getVersion()).thenReturn(BrokerModel.MODEL_VERSION);
         _adapter = new LatestManagementControllerAdapter(managementController);
     }
 
