@@ -27,7 +27,6 @@ import static org.hamcrest.CoreMatchers.nullValue;
 import static org.hamcrest.MatcherAssert.assertThat;
 import static org.junit.Assume.assumeThat;
 
-import java.net.InetSocketAddress;
 import java.nio.charset.StandardCharsets;
 import java.util.Collections;
 import java.util.HashMap;
@@ -61,12 +60,10 @@ import org.apache.qpid.tests.utils.BrokerAdminUsingTestBase;
 
 public class BasicTest extends BrokerAdminUsingTestBase
 {
-    private InetSocketAddress _brokerAddress;
 
     @Before
     public void setUp()
     {
-        _brokerAddress = getBrokerAdmin().getBrokerAddress(BrokerAdmin.PortType.ANONYMOUS_AMQP);
         getBrokerAdmin().createQueue(BrokerAdmin.TEST_QUEUE_NAME);
     }
 
@@ -74,10 +71,10 @@ public class BasicTest extends BrokerAdminUsingTestBase
     @SpecificationTest(section = "1.8.3.7", description = "publish a message")
     public void publishMessage() throws Exception
     {
-        try(FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try(FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             final Interaction interaction = transport.newInteraction();
-            interaction.openAnonymousConnection()
+            interaction.negotiateOpen()
                        .channel().open().consumeResponse(ChannelOpenOkBody.class)
                        .basic().contentHeaderPropertiesContentType("text/plain")
                                .contentHeaderPropertiesHeaders(Collections.singletonMap("test", "testValue"))
@@ -98,10 +95,10 @@ public class BasicTest extends BrokerAdminUsingTestBase
     @SpecificationTest(section = "1.8.3.7", description = "indicate mandatory routing")
     public void publishMandatoryMessage() throws Exception
     {
-        try(FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try(FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             final Interaction interaction = transport.newInteraction();
-            interaction.openAnonymousConnection()
+            interaction.negotiateOpen()
                        .channel().open().consumeResponse(ChannelOpenOkBody.class)
                        .basic().publishExchange("")
                                .publishRoutingKey(BrokerAdmin.TEST_QUEUE_NAME)
@@ -122,11 +119,11 @@ public class BasicTest extends BrokerAdminUsingTestBase
                           + "Return method.")
     public void publishUnrouteableMandatoryMessage() throws Exception
     {
-        try(FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try(FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             final Interaction interaction = transport.newInteraction();
             String messageContent = "Test";
-            BasicReturnBody returned = interaction.openAnonymousConnection()
+            BasicReturnBody returned = interaction.negotiateOpen()
                                                   .channel().open().consumeResponse(ChannelOpenOkBody.class)
                                                   .basic().publishExchange("")
                                                   .publishRoutingKey("unrouteable")
@@ -151,10 +148,10 @@ public class BasicTest extends BrokerAdminUsingTestBase
                           + "queue. If this flag is zero, the server silently drops the message.")
     public void publishUnrouteableMessage() throws Exception
     {
-        try(FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try(FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             final Interaction interaction = transport.newInteraction();
-            interaction.openAnonymousConnection()
+            interaction.negotiateOpen()
                        .channel().open().consumeResponse(ChannelOpenOkBody.class)
                        .basic().publishExchange("")
                        .publishRoutingKey("unrouteable")
@@ -177,10 +174,10 @@ public class BasicTest extends BrokerAdminUsingTestBase
         byte deliveryMode = (byte) 2;
         Map<String, Object> messageHeaders = Collections.singletonMap("test", "testValue");
 
-        try(FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try(FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             final Interaction interaction = transport.newInteraction();
-            interaction.openAnonymousConnection()
+            interaction.negotiateOpen()
                        .channel().open().consumeResponse(ChannelOpenOkBody.class)
                        .queue().declareName(queueName).declareDurable(true).declare()
                        .consumeResponse(QueueDeclareOkBody.class)
@@ -201,11 +198,11 @@ public class BasicTest extends BrokerAdminUsingTestBase
         getBrokerAdmin().restart();
         assertThat(getBrokerAdmin().getQueueDepthMessages(queueName), is(equalTo(1)));
 
-        try(FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try(FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             final Interaction interaction = transport.newInteraction();
 
-            interaction.openAnonymousConnection()
+            interaction.negotiateOpen()
                        .channel().open()
                        .consumeResponse(ChannelOpenOkBody.class)
                        .basic().getQueueName(queueName).getNoAck(true).get()
@@ -234,7 +231,7 @@ public class BasicTest extends BrokerAdminUsingTestBase
     @SpecificationTest(section = "1.8.3.3", description = "start a queue consumer")
     public void consumeMessage() throws Exception
     {
-        try(FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try(FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             final Interaction interaction = transport.newInteraction();
             String messageContent = "Test";
@@ -244,7 +241,7 @@ public class BasicTest extends BrokerAdminUsingTestBase
             String messageContentType = "text/plain";
             byte deliveryMode = (byte) 1;
             byte priority = (byte) 2;
-            interaction.openAnonymousConnection()
+            interaction.negotiateOpen()
                        .channel().open()
                        .consumeResponse(ChannelOpenOkBody.class)
                        .basic().qosPrefetchCount(1)
@@ -308,13 +305,13 @@ public class BasicTest extends BrokerAdminUsingTestBase
                           + "Note current broker behaviour is spec incompliant: broker ignores not valid delivery tags")
     public void ackWithInvalidDeliveryTag() throws Exception
     {
-        try(FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try(FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             final Interaction interaction = transport.newInteraction();
             String consumerTag = "A";
             final long deliveryTag = 12345L;
             String queueName = BrokerAdmin.TEST_QUEUE_NAME;
-            interaction.openAnonymousConnection()
+            interaction.negotiateOpen()
                        .channel().open()
                        .consumeResponse(ChannelOpenOkBody.class)
                        .basic().qosPrefetchCount(1)
@@ -338,10 +335,10 @@ public class BasicTest extends BrokerAdminUsingTestBase
         String messageContent = "message";
         getBrokerAdmin().putMessageOnQueue(BrokerAdmin.TEST_QUEUE_NAME, messageContent);
 
-        try(FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try(FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             final Interaction interaction = transport.newInteraction();
-            BasicGetOkBody response = interaction.openAnonymousConnection()
+            BasicGetOkBody response = interaction.negotiateOpen()
                                                  .channel().open()
                                                  .consumeResponse(ChannelOpenOkBody.class)
                                                  .basic().getQueueName(BrokerAdmin.TEST_QUEUE_NAME).get()
@@ -370,10 +367,10 @@ public class BasicTest extends BrokerAdminUsingTestBase
         String messageContent = "message";
         getBrokerAdmin().putMessageOnQueue(BrokerAdmin.TEST_QUEUE_NAME, messageContent);
 
-        try(FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try(FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             final Interaction interaction = transport.newInteraction();
-            interaction.openAnonymousConnection()
+            interaction.negotiateOpen()
                        .channel().open()
                        .consumeResponse(ChannelOpenOkBody.class)
                        .basic().getQueueName(BrokerAdmin.TEST_QUEUE_NAME).getNoAck(true).get()
@@ -395,10 +392,10 @@ public class BasicTest extends BrokerAdminUsingTestBase
     @SpecificationTest(section = "1.8.3.10", description = "direct access to a queue")
     public void getEmptyQueue() throws Exception
     {
-        try(FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try(FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             final Interaction interaction = transport.newInteraction();
-            interaction.openAnonymousConnection()
+            interaction.negotiateOpen()
                        .channel().open()
                        .consumeResponse(ChannelOpenOkBody.class)
                        .basic().getQueueName(BrokerAdmin.TEST_QUEUE_NAME).get()
@@ -417,12 +414,12 @@ public class BasicTest extends BrokerAdminUsingTestBase
         String messageContent2 = String.join("", Collections.nCopies(128, "2"));
         String messageContent3 = String.join("", Collections.nCopies(256, "3"));
 
-        try(FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try(FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             final Interaction interaction = transport.newInteraction();
             String consumerTag = "A";
 
-            interaction.openAnonymousConnection()
+            interaction.negotiateOpen()
                        .channel().open()
                        .consumeResponse(ChannelOpenOkBody.class)
                        .basic()
@@ -487,12 +484,12 @@ public class BasicTest extends BrokerAdminUsingTestBase
         String messageContent = String.join("", Collections.nCopies(1024, "*"));
         getBrokerAdmin().putMessageOnQueue(BrokerAdmin.TEST_QUEUE_NAME, messageContent);
 
-        try(FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try(FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             final Interaction interaction = transport.newInteraction();
             String consumerTag = "A";
 
-            interaction.openAnonymousConnection()
+            interaction.negotiateOpen()
                        .channel().open()
                        .consumeResponse(ChannelOpenOkBody.class)
                        .channel().flow(true)
@@ -537,12 +534,12 @@ public class BasicTest extends BrokerAdminUsingTestBase
     {
         getBrokerAdmin().putMessageOnQueue(BrokerAdmin.TEST_QUEUE_NAME, "A", "B", "C", "D", "E", "F");
 
-        try(FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try(FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             final Interaction interaction = transport.newInteraction();
             String consumerTag = "A";
 
-            interaction.openAnonymousConnection()
+            interaction.negotiateOpen()
                        .channel().open()
                        .consumeResponse(ChannelOpenOkBody.class)
                        .channel().flow(true)
@@ -605,12 +602,12 @@ public class BasicTest extends BrokerAdminUsingTestBase
     {
         getBrokerAdmin().putMessageOnQueue(BrokerAdmin.TEST_QUEUE_NAME, "A", "B", "C");
 
-        try(FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try(FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             final Interaction interaction = transport.newInteraction();
             String consumerTag = "A";
 
-            interaction.openAnonymousConnection()
+            interaction.negotiateOpen()
                        .channel().open()
                        .consumeResponse(ChannelOpenOkBody.class)
                        .basic().qosPrefetchCount(1)
