@@ -20,24 +20,23 @@
  */
 package org.apache.qpid.tests.protocol.v1_0.extensions.anonymousterminus;
 
-
-import static org.hamcrest.CoreMatchers.hasItem;
+import static org.hamcrest.CoreMatchers.anyOf;
 import static org.hamcrest.CoreMatchers.instanceOf;
 import static org.hamcrest.CoreMatchers.notNullValue;
 import static org.hamcrest.MatcherAssert.assertThat;
 import static org.hamcrest.Matchers.equalTo;
+import static org.hamcrest.Matchers.greaterThan;
+import static org.hamcrest.Matchers.hasItemInArray;
 import static org.hamcrest.Matchers.is;
+import static org.hamcrest.Matchers.oneOf;
 import static org.junit.Assume.assumeThat;
 
-import java.net.InetSocketAddress;
 import java.nio.charset.StandardCharsets;
-import java.util.Arrays;
 
 import org.junit.Before;
 import org.junit.Test;
 
 import org.apache.qpid.server.bytebuffer.QpidByteBuffer;
-import org.apache.qpid.server.protocol.v1_0.SequenceNumber;
 import org.apache.qpid.server.protocol.v1_0.type.Binary;
 import org.apache.qpid.server.protocol.v1_0.type.DeliveryState;
 import org.apache.qpid.server.protocol.v1_0.type.Symbol;
@@ -46,8 +45,6 @@ import org.apache.qpid.server.protocol.v1_0.type.messaging.Accepted;
 import org.apache.qpid.server.protocol.v1_0.type.messaging.Properties;
 import org.apache.qpid.server.protocol.v1_0.type.messaging.Rejected;
 import org.apache.qpid.server.protocol.v1_0.type.messaging.Target;
-import org.apache.qpid.server.protocol.v1_0.type.transaction.Coordinator;
-import org.apache.qpid.server.protocol.v1_0.type.transaction.Discharge;
 import org.apache.qpid.server.protocol.v1_0.type.transaction.TransactionError;
 import org.apache.qpid.server.protocol.v1_0.type.transaction.TransactionalState;
 import org.apache.qpid.server.protocol.v1_0.type.transport.AmqpError;
@@ -59,11 +56,11 @@ import org.apache.qpid.server.protocol.v1_0.type.transport.Error;
 import org.apache.qpid.server.protocol.v1_0.type.transport.Flow;
 import org.apache.qpid.server.protocol.v1_0.type.transport.Open;
 import org.apache.qpid.server.protocol.v1_0.type.transport.Role;
+import org.apache.qpid.server.util.StringUtil;
 import org.apache.qpid.tests.protocol.Response;
 import org.apache.qpid.tests.protocol.SpecificationTest;
 import org.apache.qpid.tests.protocol.v1_0.FrameTransport;
 import org.apache.qpid.tests.protocol.v1_0.Interaction;
-import org.apache.qpid.tests.protocol.v1_0.InteractionTransactionalState;
 import org.apache.qpid.tests.protocol.v1_0.MessageEncoder;
 import org.apache.qpid.tests.protocol.v1_0.Utils;
 import org.apache.qpid.tests.utils.BrokerAdmin;
@@ -73,16 +70,13 @@ public class AnonymousTerminusTest extends BrokerAdminUsingTestBase
 {
     private static final Symbol ANONYMOUS_RELAY = Symbol.valueOf("ANONYMOUS-RELAY");
     private static final Symbol DELIVERY_TAG = Symbol.valueOf("delivery-tag");
-    private static final String TEST_MESSAGE_CONTENT = "test";
-    private InetSocketAddress _brokerAddress;
+
     private Binary _deliveryTag;
 
     @Before
     public void setUp()
     {
-        final BrokerAdmin brokerAdmin = getBrokerAdmin();
-        brokerAdmin.createQueue(BrokerAdmin.TEST_QUEUE_NAME);
-        _brokerAddress = brokerAdmin.getBrokerAddress(BrokerAdmin.PortType.ANONYMOUS_AMQP);
+        getBrokerAdmin().createQueue(BrokerAdmin.TEST_QUEUE_NAME);
         _deliveryTag = new Binary("testTag".getBytes(StandardCharsets.UTF_8));
     }
 
@@ -93,7 +87,7 @@ public class AnonymousTerminusTest extends BrokerAdminUsingTestBase
     @Test
     public void transferPreSettledToKnownDestination() throws Exception
     {
-        try (FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try (FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             final Interaction interaction = openInteractionWithAnonymousRelayCapability(transport);
 
@@ -103,15 +97,16 @@ public class AnonymousTerminusTest extends BrokerAdminUsingTestBase
                        .attachRole(Role.SENDER)
                        .attach().consumeResponse(Attach.class)
                        .consumeResponse(Flow.class)
-
+                       .assertLatestResponse(Flow.class, this::assumeSufficientCredits)
+                       .transferDeliveryId()
                        .transferPayload(generateMessagePayloadToDestination(BrokerAdmin.TEST_QUEUE_NAME))
                        .transferSettled(Boolean.TRUE)
                        .transferDeliveryTag(_deliveryTag)
                        .transfer()
-                       .sync();
+                       .detachEndCloseUnconditionally();
 
-            Object receivedMessage = Utils.receiveMessage(_brokerAddress, BrokerAdmin.TEST_QUEUE_NAME);
-            assertThat(receivedMessage, is(equalTo(TEST_MESSAGE_CONTENT)));
+            assertThat(Utils.receiveMessage(getBrokerAdmin(), BrokerAdmin.TEST_QUEUE_NAME),
+                       is(equalTo(getTestName())));
         }
     }
 
@@ -128,7 +123,7 @@ public class AnonymousTerminusTest extends BrokerAdminUsingTestBase
     @Test
     public void transferPreSettledToUnknownDestination() throws Exception
     {
-        try (FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try (FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             final Interaction interaction = openInteractionWithAnonymousRelayCapability(transport);
 
@@ -138,13 +133,14 @@ public class AnonymousTerminusTest extends BrokerAdminUsingTestBase
                        .attachRole(Role.SENDER)
                        .attach().consumeResponse(Attach.class)
                        .consumeResponse(Flow.class)
-
-                       .transferPayload(generateMessagePayloadToDestination("Unknown"))
+                       .assertLatestResponse(Flow.class, this::assumeSufficientCredits)
+                       .transferDeliveryId()
+                       .transferPayload(generateMessagePayloadToDestination(getNonExistingDestinationName()))
                        .transferSettled(Boolean.TRUE)
                        .transferDeliveryTag(_deliveryTag)
                        .transfer();
 
-            Detach detach = interaction.consumeResponse().getLatestResponse(Detach.class);
+            final Detach detach = interaction.consume(Detach.class, Flow.class);
             Error error = detach.getError();
             assertThat(error, is(notNullValue()));
             assertThat(error.getCondition(), is(equalTo(AmqpError.NOT_FOUND)));
@@ -167,7 +163,7 @@ public class AnonymousTerminusTest extends BrokerAdminUsingTestBase
     @Test
     public void transferUnsettledToUnknownDestinationWhenRejectedOutcomeSupportedBySource() throws Exception
     {
-        try (FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try (FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             final Interaction interaction = openInteractionWithAnonymousRelayCapability(transport);
 
@@ -178,13 +174,13 @@ public class AnonymousTerminusTest extends BrokerAdminUsingTestBase
                        .attachSourceOutcomes(Accepted.ACCEPTED_SYMBOL, Rejected.REJECTED_SYMBOL)
                        .attach().consumeResponse(Attach.class)
                        .consumeResponse(Flow.class)
-
-                       .transferPayload(generateMessagePayloadToDestination("Unknown"))
+                       .assertLatestResponse(Flow.class, this::assumeSufficientCredits)
+                       .transferDeliveryId()
+                       .transferPayload(generateMessagePayloadToDestination(getNonExistingDestinationName()))
                        .transferDeliveryTag(_deliveryTag)
-                       .transfer()
-                       .consumeResponse();
+                       .transfer();
 
-            Disposition disposition = interaction.getLatestResponse(Disposition.class);
+            final Disposition disposition = interaction.consume(Disposition.class, Flow.class);
 
             assertThat(disposition.getSettled(), is(true));
 
@@ -194,7 +190,7 @@ public class AnonymousTerminusTest extends BrokerAdminUsingTestBase
             Rejected rejected = (Rejected)dispositionState;
             Error error = rejected.getError();
             assertThat(error, is(notNullValue()));
-            assertThat(error.getCondition(), is(equalTo(AmqpError.NOT_FOUND)));
+            assertThat(error.getCondition(), is(oneOf(AmqpError.NOT_FOUND, AmqpError.NOT_ALLOWED)));
             assertThat(error.getInfo(), is(notNullValue()));
             assertThat(error.getInfo().get(DELIVERY_TAG), is(equalTo(_deliveryTag)));
         }
@@ -214,7 +210,7 @@ public class AnonymousTerminusTest extends BrokerAdminUsingTestBase
     @Test
     public void transferUnsettledToUnknownDestinationWhenRejectedOutcomeNotSupportedBySource() throws Exception
     {
-        try (FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try (FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             final Interaction interaction = openInteractionWithAnonymousRelayCapability(transport);
 
@@ -225,12 +221,13 @@ public class AnonymousTerminusTest extends BrokerAdminUsingTestBase
                        .attachSourceOutcomes(Accepted.ACCEPTED_SYMBOL)
                        .attach().consumeResponse(Attach.class)
                        .consumeResponse(Flow.class)
-
-                       .transferPayload(generateMessagePayloadToDestination("Unknown"))
+                       .assertLatestResponse(Flow.class, this::assumeSufficientCredits)
+                       .transferDeliveryId()
+                       .transferPayload(generateMessagePayloadToDestination(getNonExistingDestinationName()))
                        .transferDeliveryTag(_deliveryTag)
                        .transfer();
 
-            Detach detach = interaction.consumeResponse().getLatestResponse(Detach.class);
+            final Detach detach = interaction.consume(Detach.class, Flow.class);
             Error error = detach.getError();
             assertThat(error, is(notNullValue()));
             assertThat(error.getCondition(), is(equalTo(AmqpError.NOT_FOUND)));
@@ -246,63 +243,64 @@ public class AnonymousTerminusTest extends BrokerAdminUsingTestBase
     @Test
     public void transferPreSettledInTransactionToKnownDestination() throws Exception
     {
-        try (FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try (FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             final Interaction interaction = openInteractionWithAnonymousRelayCapability(transport);
             final UnsignedInteger linkHandle = UnsignedInteger.ONE;
-            final InteractionTransactionalState txnState = interaction.createTransactionalState(UnsignedInteger.ZERO);
             interaction.begin()
                        .consumeResponse(Begin.class)
 
-                       .txnAttachCoordinatorLink(txnState)
-                       .txnDeclare(txnState)
+                       .txnAttachCoordinatorLink(UnsignedInteger.ZERO, this::coordinatorAttachExpected)
+                       .txnDeclare()
 
                        .attachRole(Role.SENDER)
                        .attachHandle(linkHandle)
                        .attach().consumeResponse(Attach.class)
                        .consumeResponse(Flow.class)
-
+                       .assertLatestResponse(Flow.class, this::assumeSufficientCredits)
+                       .transferDeliveryId()
                        .transferHandle(linkHandle)
                        .transferPayload(generateMessagePayloadToDestination(BrokerAdmin.TEST_QUEUE_NAME))
                        .transferDeliveryTag(_deliveryTag)
-                       .transferTransactionalState(txnState.getCurrentTransactionId())
+                       .transferTransactionalStateFromCurrentTransaction()
                        .transferSettled(Boolean.TRUE)
-                       .transfer()
+                       .transfer().txnDischarge(false)
+                       .detachEndCloseUnconditionally();
 
-                       .txnDischarge(txnState, false);
+            assertThat(interaction.getCoordinatorLatestDeliveryState(), is(instanceOf(Accepted.class)));
 
-            Object receivedMessage = Utils.receiveMessage(_brokerAddress, BrokerAdmin.TEST_QUEUE_NAME);
-            assertThat(receivedMessage, is(equalTo(TEST_MESSAGE_CONTENT)));
+            Object receivedMessage = Utils.receiveMessage(getBrokerAdmin(), BrokerAdmin.TEST_QUEUE_NAME);
+            assertThat(receivedMessage, is(equalTo(getTestName())));
         }
     }
 
     @Test
     public void transferUnsettledInTransactionToKnownDestination() throws Exception
     {
-        try (FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try (FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             final Interaction interaction = openInteractionWithAnonymousRelayCapability(transport);
             final UnsignedInteger linkHandle = UnsignedInteger.ONE;
-            final InteractionTransactionalState txnState = interaction.createTransactionalState(UnsignedInteger.ZERO);
             interaction.begin()
                        .consumeResponse(Begin.class)
 
-                       .txnAttachCoordinatorLink(txnState)
-                       .txnDeclare(txnState)
+                       .txnAttachCoordinatorLink(UnsignedInteger.ZERO, this::coordinatorAttachExpected)
+                       .txnDeclare()
 
                        .attachRole(Role.SENDER)
                        .attachHandle(linkHandle)
                        .attach().consumeResponse(Attach.class)
                        .consumeResponse(Flow.class)
-
+                       .assertLatestResponse(Flow.class, this::assumeSufficientCredits)
+                       .transferDeliveryId()
                        .transferHandle(linkHandle)
                        .transferPayload(generateMessagePayloadToDestination(BrokerAdmin.TEST_QUEUE_NAME))
                        .transferDeliveryTag(_deliveryTag)
-                       .transferTransactionalState(txnState.getCurrentTransactionId())
+                       .transferTransactionalStateFromCurrentTransaction()
                        .transferSettled(Boolean.FALSE)
                        .transfer();
 
-            Disposition disposition = interaction.consumeResponse().getLatestResponse(Disposition.class);
+            final Disposition disposition = interaction.consume(Disposition.class, Flow.class);
 
             assertThat(disposition.getSettled(), is(true));
 
@@ -312,41 +310,43 @@ public class AnonymousTerminusTest extends BrokerAdminUsingTestBase
             final TransactionalState receivedTxnState = (TransactionalState) dispositionState;
             assertThat(receivedTxnState.getOutcome(), is(instanceOf(Accepted.class)));
 
-            interaction.txnDischarge(txnState, false);
+            interaction.txnDischarge(false);
 
-            Object receivedMessage = Utils.receiveMessage(_brokerAddress, BrokerAdmin.TEST_QUEUE_NAME);
-            assertThat(receivedMessage, is(equalTo(TEST_MESSAGE_CONTENT)));
+            assertThat(interaction.getCoordinatorLatestDeliveryState(), is(instanceOf(Accepted.class)));
+
+            Object receivedMessage = Utils.receiveMessage(getBrokerAdmin(), BrokerAdmin.TEST_QUEUE_NAME);
+            assertThat(receivedMessage, is(equalTo(getTestName())));
         }
     }
 
     @Test
     public void transferUnsettledInTransactionToUnknownDestinationWhenRejectedOutcomeSupportedBySource() throws Exception
     {
-        try (FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try (FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             final Interaction interaction = openInteractionWithAnonymousRelayCapability(transport);
             final UnsignedInteger linkHandle = UnsignedInteger.ONE;
-            final InteractionTransactionalState txnState = interaction.createTransactionalState(UnsignedInteger.ZERO);
             interaction.begin()
                        .consumeResponse(Begin.class)
 
-                       .txnAttachCoordinatorLink(txnState)
-                       .txnDeclare(txnState)
+                       .txnAttachCoordinatorLink(UnsignedInteger.ZERO, this::coordinatorAttachExpected)
+                       .txnDeclare()
 
                        .attachRole(Role.SENDER)
                        .attachSourceOutcomes(Accepted.ACCEPTED_SYMBOL, Rejected.REJECTED_SYMBOL)
                        .attachHandle(linkHandle)
                        .attach().consumeResponse(Attach.class)
                        .consumeResponse(Flow.class)
-
+                       .assertLatestResponse(Flow.class, this::assumeSufficientCredits)
+                       .transferDeliveryId()
                        .transferHandle(linkHandle)
-                       .transferPayload(generateMessagePayloadToDestination("Unknown"))
+                       .transferPayload(generateMessagePayloadToDestination(getNonExistingDestinationName()))
                        .transferDeliveryTag(_deliveryTag)
-                       .transferTransactionalState(txnState.getCurrentTransactionId())
+                       .transferTransactionalStateFromCurrentTransaction()
                        .transferSettled(Boolean.FALSE)
                        .transfer();
 
-            Disposition disposition = interaction.consumeResponse().getLatestResponse(Disposition.class);
+            final Disposition disposition = interaction.consume(Disposition.class, Flow.class);
 
             assertThat(disposition.getSettled(), is(true));
 
@@ -361,62 +361,52 @@ public class AnonymousTerminusTest extends BrokerAdminUsingTestBase
             assertThat(rejectedError.getInfo(), is(notNullValue()));
             assertThat(rejectedError.getInfo().get(DELIVERY_TAG), is(equalTo(_deliveryTag)));
 
-            interaction.txnDischarge(txnState, false);
+            interaction.txnDischarge(false);
+
+            assertThat(interaction.getCoordinatorLatestDeliveryState(), is(instanceOf(Accepted.class)));
         }
     }
 
     @Test
     public void transferUnsettledInTransactionToUnknownDestinationWhenRejectedOutcomeNotSupportedBySource() throws Exception
     {
-        try (FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try (FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             final Interaction interaction = openInteractionWithAnonymousRelayCapability(transport);
             final UnsignedInteger linkHandle = UnsignedInteger.ONE;
-            final InteractionTransactionalState txnState = interaction.createTransactionalState(UnsignedInteger.ZERO);
             interaction.begin()
                        .consumeResponse(Begin.class)
 
-                       .txnAttachCoordinatorLink(txnState)
-                       .txnDeclare(txnState)
+                       .txnAttachCoordinatorLink(UnsignedInteger.ZERO, this::coordinatorAttachExpected)
+                       .txnDeclare()
 
                        .attachRole(Role.SENDER)
                        .attachSourceOutcomes(Accepted.ACCEPTED_SYMBOL)
                        .attachHandle(linkHandle)
                        .attach().consumeResponse(Attach.class)
                        .consumeResponse(Flow.class)
-
+                       .assertLatestResponse(Flow.class, this::assumeSufficientCredits)
+                       .transferDeliveryId()
                        .transferHandle(linkHandle)
-                       .transferPayload(generateMessagePayloadToDestination("Unknown"))
+                       .transferPayload(generateMessagePayloadToDestination(getNonExistingDestinationName()))
                        .transferDeliveryId(UnsignedInteger.valueOf(1))
                        .transferDeliveryTag(_deliveryTag)
-                       .transferTransactionalState(txnState.getCurrentTransactionId())
+                       .transferTransactionalStateFromCurrentTransaction()
                        .transferSettled(Boolean.FALSE)
                        .transfer();
 
-            Detach senderLinkDetach = interaction.consumeResponse().getLatestResponse(Detach.class);
+            final Detach senderLinkDetach = interaction.consume(Detach.class, Flow.class);
             Error senderLinkDetachError = senderLinkDetach.getError();
             assertThat(senderLinkDetachError, is(notNullValue()));
             assertThat(senderLinkDetachError.getCondition(), is(equalTo(AmqpError.NOT_FOUND)));
             assertThat(senderLinkDetachError.getInfo(), is(notNullValue()));
             assertThat(senderLinkDetachError.getInfo().get(DELIVERY_TAG), is(equalTo(_deliveryTag)));
 
-            final Discharge discharge = new Discharge();
-            discharge.setTxnId(txnState.getCurrentTransactionId());
-            discharge.setFail(false);
+            interaction.txnDischarge(false);
 
-            interaction.transferHandle(txnState.getHandle())
-                       .transferSettled(Boolean.FALSE)
-                       .transferDeliveryId(UnsignedInteger.valueOf(2))
-                       .transferDeliveryTag(new Binary(("transaction-" + 2).getBytes(StandardCharsets.UTF_8)))
-                       .transferPayloadData(discharge).transfer();
-
-            Disposition dischargeTransactionDisposition =
-                    getDispositionForDeliveryId(interaction, UnsignedInteger.valueOf(2));
-
-            assertThat(dischargeTransactionDisposition.getSettled(), is(equalTo(true)));
-            assertThat(dischargeTransactionDisposition.getState(), is(instanceOf(Rejected.class)));
-
-            Rejected rejected = (Rejected) dischargeTransactionDisposition.getState();
+            DeliveryState txnDischargeDeliveryState = interaction.getCoordinatorLatestDeliveryState();
+            assertThat(txnDischargeDeliveryState, is(instanceOf(Rejected.class)));
+            Rejected rejected = (Rejected) txnDischargeDeliveryState;
             Error error = rejected.getError();
 
             assertThat(error, is(notNullValue()));
@@ -448,50 +438,39 @@ public class AnonymousTerminusTest extends BrokerAdminUsingTestBase
     public void transferPreSettledInTransactionToUnknownDestinationWhenRejectOutcomeSupportedByTxController()
             throws Exception
     {
-        try (FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try (FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             final UnsignedInteger linkHandle = UnsignedInteger.ONE;
             final Interaction interaction =
                     openInteractionWithAnonymousRelayCapability(transport);
 
-            final InteractionTransactionalState txnState = interaction.createTransactionalState(UnsignedInteger.ZERO);
             interaction.begin()
                        .consumeResponse(Begin.class)
 
                        // attaching coordinator link with supported outcomes Accepted and Rejected
-                       .txnAttachCoordinatorLink(txnState)
-                       .txnDeclare(txnState)
+                       .txnAttachCoordinatorLink(UnsignedInteger.ZERO, this::coordinatorAttachExpected)
+                       .txnDeclare()
 
                        .attachRole(Role.SENDER)
                        .attachHandle(linkHandle)
                        .attachSourceOutcomes(Accepted.ACCEPTED_SYMBOL, Rejected.REJECTED_SYMBOL)
                        .attach().consumeResponse(Attach.class)
                        .consumeResponse(Flow.class)
-
+                       .assertLatestResponse(Flow.class, this::assumeSufficientCredits)
+                       .transferDeliveryId()
                        .transferHandle(linkHandle)
-                       .transferPayload(generateMessagePayloadToDestination("Unknown"))
+                       .transferPayload(generateMessagePayloadToDestination(getNonExistingDestinationName()))
                        .transferDeliveryTag(_deliveryTag)
-                       .transferTransactionalState(txnState.getCurrentTransactionId())
+                       .transferTransactionalStateFromCurrentTransaction()
                        .transferSettled(Boolean.TRUE)
-                       .transferDeliveryId(UnsignedInteger.valueOf(1))
                        .transfer();
 
-            final Discharge discharge = new Discharge();
-            discharge.setTxnId(txnState.getCurrentTransactionId());
-            discharge.setFail(false);
-            interaction.transferHandle(txnState.getHandle())
-                       .transferDeliveryId(UnsignedInteger.valueOf(2))
-                       .transferSettled(Boolean.FALSE)
-                       .transferDeliveryTag(new Binary(("transaction-" + 2).getBytes(StandardCharsets.UTF_8)))
-                       .transferPayloadData(discharge).transfer();
+            interaction.txnDischarge(false);
 
-            Disposition dischargeTransactionDisposition =
-                    getDispositionForDeliveryId(interaction, UnsignedInteger.valueOf(2));
+            DeliveryState txDischargeDeliveryState = interaction.getCoordinatorLatestDeliveryState();
+            assertThat(txDischargeDeliveryState, is(instanceOf(Rejected.class)));
 
-            assertThat(dischargeTransactionDisposition.getSettled(), is(equalTo(true)));
-            assertThat(dischargeTransactionDisposition.getState(), is(instanceOf(Rejected.class)));
-
-            Rejected rejected = (Rejected) dischargeTransactionDisposition.getState();
+            Rejected rejected = (Rejected) txDischargeDeliveryState;
             Error error = rejected.getError();
 
             assertThat(error, is(notNullValue()));
@@ -525,26 +504,17 @@ public class AnonymousTerminusTest extends BrokerAdminUsingTestBase
     public void transferPreSettledInTransactionToUnknownDestinationWhenRejectOutcomeNotSupportedByTxController()
             throws Exception
     {
-        try (FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try (FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             final UnsignedInteger linkHandle = UnsignedInteger.ONE;
             final Interaction interaction =
                     openInteractionWithAnonymousRelayCapability(transport);
 
-            final InteractionTransactionalState txnState = interaction.createTransactionalState(UnsignedInteger.ZERO);
-
             interaction.begin()
                        .consumeResponse(Begin.class)
 
-                       .attachRole(Role.SENDER)
-                       .attachName("testTransactionCoordinator-" + txnState.getHandle())
-                       .attachHandle(txnState.getHandle())
-                       .attachInitialDeliveryCount(UnsignedInteger.ZERO)
-                       .attachTarget(new Coordinator())
-                       .attachSourceOutcomes(Accepted.ACCEPTED_SYMBOL)
-                       .attach().consumeResponse(Attach.class)
-                       .consumeResponse(Flow.class)
-                       .txnDeclare(txnState)
+                       .txnAttachCoordinatorLink(UnsignedInteger.ZERO, this::coordinatorAttachExpected, Accepted.ACCEPTED_SYMBOL)
+                       .txnDeclare()
 
                        .attachRole(Role.SENDER)
                        .attachHandle(linkHandle)
@@ -553,63 +523,34 @@ public class AnonymousTerminusTest extends BrokerAdminUsingTestBase
                        .attachSourceOutcomes(Accepted.ACCEPTED_SYMBOL, Rejected.REJECTED_SYMBOL)
                        .attach().consumeResponse(Attach.class)
                        .consumeResponse(Flow.class)
-
+                       .assertLatestResponse(Flow.class, this::assumeSufficientCredits)
+                       .transferDeliveryId()
                        .transferHandle(linkHandle)
-                       .transferPayload(generateMessagePayloadToDestination("Unknown"))
+                       .transferPayload(generateMessagePayloadToDestination(getNonExistingDestinationName()))
                        .transferDeliveryTag(_deliveryTag)
-                       .transferTransactionalState(txnState.getCurrentTransactionId())
+                       .transferTransactionalStateFromCurrentTransaction()
                        .transferSettled(Boolean.TRUE)
-                       .transfer();
+                       .transfer().txnSendDischarge(false);
 
-            final Discharge discharge = new Discharge();
-            discharge.setTxnId(txnState.getCurrentTransactionId());
-            discharge.setFail(false);
-
-            interaction.transferHandle(txnState.getHandle())
-                       .transferSettled(Boolean.FALSE)
-                       .transferDeliveryId(UnsignedInteger.valueOf(4))
-                       .transferDeliveryTag(new Binary(("transaction-" + 4).getBytes(StandardCharsets.UTF_8)))
-                       .transferPayloadData(discharge).transfer();
-
-            Detach transactionCoordinatorDetach = interaction.consumeResponse().getLatestResponse(Detach.class);
+            final Detach transactionCoordinatorDetach = interaction.consume(Detach.class, Flow.class);
             Error transactionCoordinatorDetachError = transactionCoordinatorDetach.getError();
             assertThat(transactionCoordinatorDetachError, is(notNullValue()));
             assertThat(transactionCoordinatorDetachError.getCondition(), is(equalTo(TransactionError.TRANSACTION_ROLLBACK)));
         }
     }
 
-    private Disposition getDispositionForDeliveryId(final Interaction interaction,
-                                                    final UnsignedInteger deliveryId) throws Exception
+    private String getNonExistingDestinationName()
     {
-        Disposition dischargeTransactionDisposition = null;
-
-        SequenceNumber id = new SequenceNumber(deliveryId.intValue());
-        do
-        {
-            Response<?> response = interaction.consumeResponse(Disposition.class, Flow.class).getLatestResponse();
-            if (response.getBody() instanceof Disposition)
-            {
-                Disposition disposition = (Disposition) response.getBody();
-                UnsignedInteger first = disposition.getFirst();
-                UnsignedInteger last = disposition.getLast() == null ? disposition.getFirst() : disposition.getLast();
-                if (new SequenceNumber(first.intValue()).compareTo(id) >= 0 && new SequenceNumber(last.intValue()).compareTo(id) <=0)
-                {
-                    dischargeTransactionDisposition = disposition;
-                }
-            }
-        } while (dischargeTransactionDisposition == null);
-        return dischargeTransactionDisposition;
+        return String.format("%sNonExisting%s", getTestName(), new StringUtil().randomAlphaNumericString(10));
     }
 
     private Interaction openInteractionWithAnonymousRelayCapability(final FrameTransport transport) throws Exception
     {
         final Interaction interaction = transport.newInteraction();
-        interaction.negotiateProtocol().consumeResponse()
-                   .openDesiredCapabilities(ANONYMOUS_RELAY)
-                   .open().consumeResponse(Open.class);
+        interaction.openDesiredCapabilities(ANONYMOUS_RELAY).negotiateOpen();
 
         Open open = interaction.getLatestResponse(Open.class);
-        assumeThat(Arrays.asList(open.getOfferedCapabilities()), hasItem(ANONYMOUS_RELAY));
+        assumeThat(open.getOfferedCapabilities(), hasItemInArray((ANONYMOUS_RELAY)));
         return interaction;
     }
 
@@ -619,7 +560,18 @@ public class AnonymousTerminusTest extends BrokerAdminUsingTestBase
         final Properties properties = new Properties();
         properties.setTo(destinationName);
         messageEncoder.setProperties(properties);
-        messageEncoder.addData(TEST_MESSAGE_CONTENT);
+        messageEncoder.addData(getTestName());
         return messageEncoder.getPayload();
     }
+
+    private void assumeSufficientCredits(final Flow flow)
+    {
+        assumeThat(flow.getLinkCredit(), is(greaterThan(UnsignedInteger.ZERO)));
+    }
+
+    private void coordinatorAttachExpected(final Response<?> response)
+    {
+        assertThat(response, is(notNullValue()));
+        assumeThat(response.getBody(), anyOf(instanceOf(Attach.class), instanceOf(Flow.class)));
+    }
 }
