@@ -32,9 +32,6 @@ import static org.hamcrest.Matchers.lessThan;
 import static org.hamcrest.Matchers.notNullValue;
 import static org.hamcrest.Matchers.nullValue;
 
-import java.net.InetSocketAddress;
-
-import org.junit.Before;
 import org.junit.Test;
 
 import org.apache.qpid.server.protocol.v1_0.type.Symbol;
@@ -46,12 +43,10 @@ import org.apache.qpid.server.protocol.v1_0.type.transport.AmqpError;
 import org.apache.qpid.server.protocol.v1_0.type.transport.Attach;
 import org.apache.qpid.server.protocol.v1_0.type.transport.Begin;
 import org.apache.qpid.server.protocol.v1_0.type.transport.Detach;
-import org.apache.qpid.server.protocol.v1_0.type.transport.Open;
 import org.apache.qpid.server.protocol.v1_0.type.transport.Role;
 import org.apache.qpid.tests.protocol.SpecificationTest;
 import org.apache.qpid.tests.protocol.v1_0.FrameTransport;
 import org.apache.qpid.tests.protocol.v1_0.Interaction;
-import org.apache.qpid.tests.utils.BrokerAdmin;
 import org.apache.qpid.tests.utils.BrokerAdminUsingTestBase;
 import org.apache.qpid.tests.utils.BrokerSpecific;
 
@@ -61,13 +56,6 @@ public class TopicDestinationTest extends BrokerAdminUsingTestBase
     private static final Symbol TOPIC = Symbol.valueOf("topic");
     private static final Symbol GLOBAL = Symbol.valueOf("global");
     private static final Symbol SHARED = Symbol.valueOf("shared");
-    private InetSocketAddress _brokerAddress;
-
-    @Before
-    public void setUp()
-    {
-        _brokerAddress = getBrokerAdmin().getBrokerAddress(BrokerAdmin.PortType.ANONYMOUS_AMQP);
-    }
 
     @Test
     @SpecificationTest(section = "5.2",
@@ -78,7 +66,7 @@ public class TopicDestinationTest extends BrokerAdminUsingTestBase
                           + " Destination Type = Topic, terminus capability (type) = topic")
     public void nonSharedVolatileSubscriptionLinkAttachDetach() throws Exception
     {
-        try (FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try (FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             final Source source = new Source();
             source.setExpiryPolicy(TerminusExpiryPolicy.LINK_DETACH);
@@ -87,8 +75,7 @@ public class TopicDestinationTest extends BrokerAdminUsingTestBase
             source.setDurable(TerminusDurability.NONE);
 
             final Interaction interaction = transport.newInteraction();
-            final Attach responseAttach = interaction.negotiateProtocol().consumeResponse()
-                                                     .open().consumeResponse(Open.class)
+            final Attach responseAttach = interaction.negotiateOpen()
                                                      .begin().consumeResponse(Begin.class)
                                                      .attachRole(Role.RECEIVER)
                                                      .attachSource(source)
@@ -113,7 +100,7 @@ public class TopicDestinationTest extends BrokerAdminUsingTestBase
     @Test
     public void nonSharedDurableSubscriptionLinkAttachDetach() throws Exception
     {
-        try (FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try (FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             final Source source = new Source();
             source.setExpiryPolicy(TerminusExpiryPolicy.NEVER);
@@ -122,8 +109,7 @@ public class TopicDestinationTest extends BrokerAdminUsingTestBase
             source.setDurable(TerminusDurability.UNSETTLED_STATE);
 
             final Interaction interaction = transport.newInteraction();
-            final Attach responseAttach = interaction.negotiateProtocol().consumeResponse()
-                                                     .open().consumeResponse(Open.class)
+            final Attach responseAttach = interaction.negotiateOpen()
                                                      .begin().consumeResponse(Begin.class)
                                                      .attachRole(Role.RECEIVER)
                                                      .attachSource(source)
@@ -149,7 +135,7 @@ public class TopicDestinationTest extends BrokerAdminUsingTestBase
     public void sharedGlobalVolatileSubscriptionLinkAttachDetach() throws Exception
     {
         String subscriptionName = "foo";
-        try (FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try (FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             final Source source = new Source();
             source.setExpiryPolicy(TerminusExpiryPolicy.LINK_DETACH);
@@ -158,8 +144,7 @@ public class TopicDestinationTest extends BrokerAdminUsingTestBase
             source.setDurable(TerminusDurability.NONE);
 
             final Interaction interaction = transport.newInteraction();
-            final Attach responseAttach1 = interaction.negotiateProtocol().consumeResponse()
-                                                      .open().consumeResponse(Open.class)
+            final Attach responseAttach1 = interaction.negotiateOpen()
                                                       .begin().consumeResponse(Begin.class)
                                                       .attachName(subscriptionName + "|global-volatile")
                                                       .attachHandle(UnsignedInteger.ZERO)
@@ -208,7 +193,7 @@ public class TopicDestinationTest extends BrokerAdminUsingTestBase
     public void sharedGlobalDurableSubscriptionLinkAttachDetach() throws Exception
     {
         String subscriptionName = "foo";
-        try (FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try (FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             final Source source = new Source();
             source.setExpiryPolicy(TerminusExpiryPolicy.NEVER);
@@ -217,8 +202,7 @@ public class TopicDestinationTest extends BrokerAdminUsingTestBase
             source.setDurable(TerminusDurability.CONFIGURATION);
 
             final Interaction interaction = transport.newInteraction();
-            final Attach responseAttach1 = interaction.negotiateProtocol().consumeResponse()
-                                                      .open().consumeResponse(Open.class)
+            final Attach responseAttach1 = interaction.negotiateOpen()
                                                       .begin().consumeResponse(Begin.class)
                                                       .attachName(subscriptionName + "|global")
                                                       .attachHandle(UnsignedInteger.ZERO)
@@ -291,7 +275,7 @@ public class TopicDestinationTest extends BrokerAdminUsingTestBase
     public void sharedGlobalDurableSubscriptionCloseWithActiveLink() throws Exception
     {
         String subscriptionName = "foo";
-        try (FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try (FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             final Source source = new Source();
             source.setExpiryPolicy(TerminusExpiryPolicy.NEVER);
@@ -300,8 +284,7 @@ public class TopicDestinationTest extends BrokerAdminUsingTestBase
             source.setDurable(TerminusDurability.CONFIGURATION);
 
             final Interaction interaction = transport.newInteraction();
-            final Attach responseAttach1 = interaction.negotiateProtocol().consumeResponse()
-                                                      .open().consumeResponse(Open.class)
+            final Attach responseAttach1 = interaction.negotiateOpen()
                                                       .begin().consumeResponse(Begin.class)
                                                       .attachName(subscriptionName + "|global")
                                                       .attachHandle(UnsignedInteger.ZERO)
