@@ -36,7 +36,6 @@ import static org.junit.Assert.fail;
 import static org.junit.Assume.assumeThat;
 import static org.junit.Assume.assumeTrue;
 
-import java.net.InetSocketAddress;
 import java.nio.charset.StandardCharsets;
 import java.util.Collections;
 import java.util.HashMap;
@@ -44,7 +43,6 @@ import java.util.List;
 import java.util.Map;
 
 import org.hamcrest.Matchers;
-import org.junit.After;
 import org.junit.Before;
 import org.junit.Ignore;
 import org.junit.Test;
@@ -67,42 +65,24 @@ import org.apache.qpid.server.protocol.v1_0.type.transport.ReceiverSettleMode;
 import org.apache.qpid.server.protocol.v1_0.type.transport.Role;
 import org.apache.qpid.server.protocol.v1_0.type.transport.SenderSettleMode;
 import org.apache.qpid.server.protocol.v1_0.type.transport.Transfer;
+import org.apache.qpid.tests.protocol.Response;
+import org.apache.qpid.tests.protocol.SpecificationTest;
 import org.apache.qpid.tests.protocol.v1_0.FrameTransport;
 import org.apache.qpid.tests.protocol.v1_0.Interaction;
-import org.apache.qpid.tests.protocol.SpecificationTest;
 import org.apache.qpid.tests.protocol.v1_0.Utils;
-import org.apache.qpid.tests.protocol.Response;
 import org.apache.qpid.tests.utils.BrokerAdmin;
 import org.apache.qpid.tests.utils.BrokerAdminUsingTestBase;
+import org.apache.qpid.tests.utils.ConfigItem;
 
+@ConfigItem(name = "qpid.tests.mms.messagestore.persistence", value = "false", jvm = true)
 public class ResumeDeliveriesTest extends BrokerAdminUsingTestBase
 {
     private static final int MIN_MAX_FRAME_SIZE = 512;
-    private static final String TEST_MESSAGE_CONTENT = "foo";
-    private InetSocketAddress _brokerAddress;
-    private String _originalMmsMessageStorePersistence;
 
     @Before
     public void setUp()
     {
-        _originalMmsMessageStorePersistence = System.getProperty("qpid.tests.mms.messagestore.persistence");
-        System.setProperty("qpid.tests.mms.messagestore.persistence", "false");
-
         getBrokerAdmin().createQueue(BrokerAdmin.TEST_QUEUE_NAME);
-        _brokerAddress = getBrokerAdmin().getBrokerAddress(BrokerAdmin.PortType.ANONYMOUS_AMQP);
-    }
-
-    @After
-    public void tearDown()
-    {
-        if (_originalMmsMessageStorePersistence != null)
-        {
-            System.setProperty("qpid.tests.mms.messagestore.persistence", _originalMmsMessageStorePersistence);
-        }
-        else
-        {
-            System.clearProperty("qpid.tests.mms.messagestore.persistence");
-        }
     }
 
     @Ignore("QPID-7845")
@@ -115,13 +95,12 @@ public class ResumeDeliveriesTest extends BrokerAdminUsingTestBase
     {
         final String destination = BrokerAdmin.TEST_QUEUE_NAME;
         final Binary deliveryTag = new Binary("testDeliveryTag".getBytes(StandardCharsets.UTF_8));
-        try (FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try (FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
 
             final UnsignedInteger linkHandle1 = UnsignedInteger.ZERO;
             final Interaction interaction = transport.newInteraction();
-            interaction.negotiateProtocol().consumeResponse()
-                       .open().consumeResponse(Open.class)
+            interaction.negotiateOpen()
                        .begin().consumeResponse(Begin.class);
 
             // 1. attach with ReceiverSettleMode.SECOND
@@ -130,13 +109,14 @@ public class ResumeDeliveriesTest extends BrokerAdminUsingTestBase
                        .attachRcvSettleMode(ReceiverSettleMode.SECOND)
                        .attachTargetAddress(destination)
                        .attach().consumeResponse(Attach.class)
+                       .assertLatestResponse(Attach.class, this::assumeReceiverSettlesSecond)
                        .consumeResponse(Flow.class);
 
             // 2. send a unsettled delivery
             final Disposition responseDisposition = interaction.transferHandle(linkHandle1)
                                                                .transferDeliveryId(UnsignedInteger.ZERO)
                                                                .transferDeliveryTag(deliveryTag)
-                                                               .transferPayloadData(TEST_MESSAGE_CONTENT)
+                                                               .transferPayloadData(getTestName())
                                                                .transfer()
                                                                .consumeResponse()
                                                                .getLatestResponse(Disposition.class);
@@ -174,14 +154,13 @@ public class ResumeDeliveriesTest extends BrokerAdminUsingTestBase
     public void resumeSendingLinkWithIncompleteUnsettled() throws Exception
     {
         final String destination = BrokerAdmin.TEST_QUEUE_NAME;
-        try (FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try (FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             final Interaction interaction = transport.newInteraction();
-            interaction.negotiateProtocol().consumeResponse();
 
             // 0. Open connection with small max-frame-size
             final Open open = interaction.openMaxFrameSize(UnsignedInteger.valueOf(MIN_MAX_FRAME_SIZE))
-                                         .open().consumeResponse()
+                                         .negotiateOpen()
                                          .getLatestResponse(Open.class);
             interaction.begin().consumeResponse(Begin.class);
 
@@ -192,12 +171,13 @@ public class ResumeDeliveriesTest extends BrokerAdminUsingTestBase
                        .attachRcvSettleMode(ReceiverSettleMode.SECOND)
                        .attachTargetAddress(destination)
                        .attach().consumeResponse(Attach.class)
+                       .assertLatestResponse(Attach.class, this::assumeReceiverSettlesSecond)
                        .consumeResponse(Flow.class);
 
             // 2. send enough unsettled deliveries to cause incomplete-unsettled to be true
             //    assume each delivery requires at least 1 byte, therefore max-frame-size deliveries should be enough
             interaction.transferHandle(linkHandle1)
-                       .transferPayloadData(TEST_MESSAGE_CONTENT);
+                       .transferPayloadData(getTestName());
             Map<Binary, DeliveryState> localUnsettled = new HashMap<>(open.getMaxFrameSize().intValue());
             for (int i = 0; i < open.getMaxFrameSize().intValue(); ++i)
             {
@@ -268,14 +248,13 @@ public class ResumeDeliveriesTest extends BrokerAdminUsingTestBase
     public void rejectNewDeliveryWhilstUnsettledIncomplete() throws Exception
     {
         final String destination = BrokerAdmin.TEST_QUEUE_NAME;
-        try (FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try (FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             final Interaction interaction = transport.newInteraction();
-            interaction.negotiateProtocol().consumeResponse();
 
             // 0. Open connection with small max-frame-size
             final Open open = interaction.openMaxFrameSize(UnsignedInteger.valueOf(MIN_MAX_FRAME_SIZE))
-                                         .open().consumeResponse()
+                                         .negotiateOpen()
                                          .getLatestResponse(Open.class);
             interaction.begin().consumeResponse(Begin.class);
 
@@ -286,12 +265,13 @@ public class ResumeDeliveriesTest extends BrokerAdminUsingTestBase
                        .attachRcvSettleMode(ReceiverSettleMode.SECOND)
                        .attachTargetAddress(destination)
                        .attach().consumeResponse(Attach.class)
+                       .assertLatestResponse(Attach.class, this::assumeReceiverSettlesSecond)
                        .consumeResponse(Flow.class);
 
             // 2. send enough unsettled deliverys to cause incomplete-unsettled to be true
             //    assume each delivery requires at least 1 byte, therefore max-frame-size deliveries should be enough
             interaction.transferHandle(linkHandle1)
-                       .transferPayloadData(TEST_MESSAGE_CONTENT);
+                       .transferPayloadData(getTestName());
             Map<Binary, DeliveryState> localUnsettled = new HashMap<>(open.getMaxFrameSize().intValue());
             for (int i = 0; i < open.getMaxFrameSize().intValue(); ++i)
             {
@@ -351,21 +331,17 @@ public class ResumeDeliveriesTest extends BrokerAdminUsingTestBase
     {
         for (int i = 0; i < MIN_MAX_FRAME_SIZE; i++)
         {
-            getBrokerAdmin().putMessageOnQueue(BrokerAdmin.TEST_QUEUE_NAME, TEST_MESSAGE_CONTENT + "-" + i);
+            Utils.putMessageOnQueue(getBrokerAdmin(), BrokerAdmin.TEST_QUEUE_NAME, getTestName() + "-" + i);
         }
 
-        final InetSocketAddress addr = getBrokerAdmin().getBrokerAddress(BrokerAdmin.PortType.ANONYMOUS_AMQP);
-        try (FrameTransport transport = new FrameTransport(addr).connect())
+        try (FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             // 1. open with small max-frame=512, begin, attach receiver with
             //    with rcv-settle-mode=second, snd-settle-mode=unsettled,
             //    flow with incoming-window=MAX_INTEGER and link-credit=MAX_INTEGER
             final Interaction interaction = transport.newInteraction();
-            interaction.negotiateProtocol()
-                       .consumeResponse()
-                       .openMaxFrameSize(UnsignedInteger.valueOf(MIN_MAX_FRAME_SIZE))
-                       .open()
-                       .consumeResponse()
+            interaction.openMaxFrameSize(UnsignedInteger.valueOf(MIN_MAX_FRAME_SIZE))
+                       .negotiateOpen()
                        .begin()
                        .consumeResponse(Begin.class)
                        .attachRole(Role.RECEIVER)
@@ -373,7 +349,8 @@ public class ResumeDeliveriesTest extends BrokerAdminUsingTestBase
                        .attachSndSettleMode(SenderSettleMode.UNSETTLED)
                        .attachSourceAddress(BrokerAdmin.TEST_QUEUE_NAME)
                        .attach()
-                       .consumeResponse(Attach.class);
+                       .consumeResponse(Attach.class)
+                       .assertLatestResponse(Attach.class, this::assumeReceiverSettlesSecond);
 
             Attach attach = interaction.getLatestResponse(Attach.class);
             assumeThat(attach.getSndSettleMode(), is(equalTo(SenderSettleMode.UNSETTLED)));
@@ -470,13 +447,12 @@ public class ResumeDeliveriesTest extends BrokerAdminUsingTestBase
                                                          + " considered unsettled by the issuing link endpoint.")
     public void resumeReceivingLinkEmptyUnsettled() throws Exception
     {
-        getBrokerAdmin().putMessageOnQueue(BrokerAdmin.TEST_QUEUE_NAME, TEST_MESSAGE_CONTENT);
+        Utils.putMessageOnQueue(getBrokerAdmin(), BrokerAdmin.TEST_QUEUE_NAME, getTestName());
 
-        try (FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try (FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             final Interaction interaction = transport.newInteraction()
-                                                     .negotiateProtocol().consumeResponse()
-                                                     .open().consumeResponse()
+                                                     .negotiateOpen()
                                                      .begin().consumeResponse()
                                                      .attachRole(Role.RECEIVER)
                                                      .attachSourceAddress(BrokerAdmin.TEST_QUEUE_NAME)
@@ -485,18 +461,21 @@ public class ResumeDeliveriesTest extends BrokerAdminUsingTestBase
                                                      .flowIncomingWindow(UnsignedInteger.ONE)
                                                      .flowLinkCredit(UnsignedInteger.ONE)
                                                      .flowHandleFromLinkHandle()
+                                                     .flowNextIncomingIdFromPeerLatestSessionBeginAndDeliveryCount()
                                                      .flow()
                                                      .receiveDelivery()
                                                      .decodeLatestDelivery();
 
             Object data = interaction.getDecodedLatestDelivery();
-            assertThat(data, is(equalTo(TEST_MESSAGE_CONTENT)));
+            assertThat(data, is(equalTo(getTestName())));
 
             interaction.dispositionSettled(true)
+                       .dispositionState(new Accepted())
+                       .dispositionFirstFromLatestDelivery()
                        .dispositionRole(Role.RECEIVER)
                        .disposition();
 
-            Detach detach = interaction.detach().consumeResponse().getLatestResponse(Detach.class);
+            Detach detach = interaction.detach().consume(Detach.class, Flow.class);
             assertThat(detach.getClosed(), anyOf(nullValue(), equalTo(false)));
 
             interaction.attachUnsettled(new HashMap<>())
@@ -506,6 +485,7 @@ public class ResumeDeliveriesTest extends BrokerAdminUsingTestBase
             Attach attach = interaction.getLatestResponse(Attach.class);
 
             Map<Binary, DeliveryState> unsettled = attach.getUnsettled();
+            assumeThat(unsettled, notNullValue());
             assertThat(unsettled.entrySet(), empty());
         }
     }
@@ -518,13 +498,13 @@ public class ResumeDeliveriesTest extends BrokerAdminUsingTestBase
                                                          + " considered unsettled by the issuing link endpoint.")
     public void resumeReceivingLinkWithSingleUnsettledAccepted() throws Exception
     {
-        getBrokerAdmin().putMessageOnQueue(BrokerAdmin.TEST_QUEUE_NAME, TEST_MESSAGE_CONTENT);
+        Utils.putMessageOnQueue(getBrokerAdmin(), BrokerAdmin.TEST_QUEUE_NAME, getTestName());
 
-        try (FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try (FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             final Interaction interaction = transport.newInteraction()
-                                                     .negotiateProtocol().consumeResponse()
-                                                     .open().consumeResponse()
+                                                     .negotiateOpen(
+                                                                   )
                                                      .begin().consumeResponse()
                                                      .attachRole(Role.RECEIVER)
                                                      .attachSourceAddress(BrokerAdmin.TEST_QUEUE_NAME)
@@ -549,7 +529,7 @@ public class ResumeDeliveriesTest extends BrokerAdminUsingTestBase
             assertThat(deliveryTag, is(notNullValue()));
             assertThat(transfer.getSettled(), is(not(equalTo(true))));
             Object data = interaction.decodeLatestDelivery().getDecodedLatestDelivery();
-            assertThat(data, is(equalTo(TEST_MESSAGE_CONTENT)));
+            assertThat(data, is(equalTo(getTestName())));
 
             Detach detach = interaction.detach().consumeResponse().getLatestResponse(Detach.class);
             assertThat(detach.getClosed(), anyOf(nullValue(), equalTo(false)));
@@ -590,11 +570,9 @@ public class ResumeDeliveriesTest extends BrokerAdminUsingTestBase
 
             interaction.doCloseConnection();
 
-            if (getBrokerAdmin().isQueueDepthSupported())
-            {
-                assertThat(getBrokerAdmin().getQueueDepthMessages(BrokerAdmin.TEST_QUEUE_NAME),
-                           is(equalTo(0)));
-            }
+            final String content = getTestName() + "_2";
+            Utils.putMessageOnQueue(getBrokerAdmin(), BrokerAdmin.TEST_QUEUE_NAME, content);
+            assertThat(Utils.receiveMessage(getBrokerAdmin(), BrokerAdmin.TEST_QUEUE_NAME), Matchers.is(Matchers.equalTo(content)));
         }
     }
 
@@ -606,13 +584,12 @@ public class ResumeDeliveriesTest extends BrokerAdminUsingTestBase
                                                          + " considered unsettled by the issuing link endpoint.")
     public void resumeReceivingLinkOneUnsettledWithNoOutcome() throws Exception
     {
-        getBrokerAdmin().putMessageOnQueue(BrokerAdmin.TEST_QUEUE_NAME, TEST_MESSAGE_CONTENT);
+        Utils.putMessageOnQueue(getBrokerAdmin(), BrokerAdmin.TEST_QUEUE_NAME, getTestName());
 
-        try (FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try (FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             final Interaction interaction = transport.newInteraction()
-                                                     .negotiateProtocol().consumeResponse()
-                                                     .open().consumeResponse()
+                                                     .negotiateOpen()
                                                      .begin().consumeResponse()
                                                      .attachRole(Role.RECEIVER)
                                                      .attachSourceAddress(BrokerAdmin.TEST_QUEUE_NAME)
@@ -636,7 +613,7 @@ public class ResumeDeliveriesTest extends BrokerAdminUsingTestBase
             Binary deliveryTag = transfer.getDeliveryTag();
             assertThat(deliveryTag, is(notNullValue()));
             Object data = interaction.decodeLatestDelivery().getDecodedLatestDelivery();
-            assertThat(data, is(equalTo(TEST_MESSAGE_CONTENT)));
+            assertThat(data, is(equalTo(getTestName())));
 
             Detach detach = interaction.detach().consumeResponse(Detach.class).getLatestResponse(Detach.class);
             assertThat(detach.getClosed(), anyOf(nullValue(), equalTo(false)));
@@ -674,11 +651,9 @@ public class ResumeDeliveriesTest extends BrokerAdminUsingTestBase
 
             interaction.doCloseConnection();
 
-            if (getBrokerAdmin().isQueueDepthSupported())
-            {
-                assertThat(getBrokerAdmin().getQueueDepthMessages(BrokerAdmin.TEST_QUEUE_NAME),
-                           Matchers.is(Matchers.equalTo(0)));
-            }
+            final String content = getTestName() + "_2";
+            Utils.putMessageOnQueue(getBrokerAdmin(), BrokerAdmin.TEST_QUEUE_NAME, content);
+            assertThat(Utils.receiveMessage(getBrokerAdmin(), BrokerAdmin.TEST_QUEUE_NAME), Matchers.is(Matchers.equalTo(content)));
         }
     }
 
@@ -693,14 +668,13 @@ public class ResumeDeliveriesTest extends BrokerAdminUsingTestBase
         final String destination = BrokerAdmin.TEST_QUEUE_NAME;
         final Binary deliveryTag = new Binary("testDeliveryTag".getBytes(StandardCharsets.UTF_8));
 
-        QpidByteBuffer[] messagePayload = Utils.splitPayload("testData1", 2);
-        try (FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        QpidByteBuffer[] messagePayload = Utils.splitPayload(getTestName(), 2);
+        try (FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
 
             final UnsignedInteger linkHandle1 = UnsignedInteger.ZERO;
             final Interaction interaction = transport.newInteraction();
-            interaction.negotiateProtocol().consumeResponse()
-                       .open().consumeResponse(Open.class)
+            interaction.negotiateOpen()
                        .begin().consumeResponse(Begin.class);
 
             // 1. attach with ReceiverSettleMode.SECOND
@@ -774,4 +748,9 @@ public class ResumeDeliveriesTest extends BrokerAdminUsingTestBase
             interaction.doCloseConnection();
         }
     }
+
+    private void assumeReceiverSettlesSecond(final Attach attach)
+    {
+        assumeThat(attach.getRcvSettleMode(), Matchers.is(Matchers.equalTo(ReceiverSettleMode.SECOND)));
+    }
 }
