@@ -51,7 +51,6 @@ import javax.jms.Session;
 import javax.jms.TemporaryQueue;
 import javax.jms.TemporaryTopic;
 import javax.jms.TextMessage;
-import javax.naming.NamingException;
 
 import com.fasterxml.jackson.databind.ObjectMapper;
 import com.google.common.collect.Sets;
@@ -66,18 +65,13 @@ import org.apache.qpid.server.model.Group;
 import org.apache.qpid.server.model.GroupMember;
 import org.apache.qpid.server.model.Protocol;
 import org.apache.qpid.server.security.access.config.AclFileParser;
-import org.apache.qpid.server.security.access.config.LegacyOperation;
-import org.apache.qpid.server.security.access.config.ObjectProperties;
-import org.apache.qpid.server.security.access.config.ObjectType;
 import org.apache.qpid.server.security.access.config.Rule;
 import org.apache.qpid.server.security.access.config.RuleSet;
 import org.apache.qpid.server.security.access.plugins.AclRule;
 import org.apache.qpid.server.security.access.plugins.RuleBasedVirtualHostAccessControlProvider;
-import org.apache.qpid.server.security.access.plugins.RuleOutcome;
 import org.apache.qpid.server.security.group.GroupProviderImpl;
 import org.apache.qpid.systests.JmsTestBase;
 
-
 public class MessagingACLTest extends JmsTestBase
 {
     private static final Logger LOGGER = LoggerFactory.getLogger(MessagingACLTest.class);
@@ -181,125 +175,6 @@ public class MessagingACLTest extends JmsTestBase
         }
     }
 
-    @Test
-    public void testAuthorizationWithConnectionLimit() throws Exception
-    {
-        final int connectionLimit = 2;
-        configureACL(String.format("ACL ALLOW-LOG %s ACCESS VIRTUALHOST connection_limit='%d'",
-                                   USER2,
-                                   connectionLimit));
-
-        final List<Connection> establishedConnections = new ArrayList<>();
-        try
-        {
-            establishConnections(connectionLimit, establishedConnections);
-
-            verifyConnectionEstablishmentFails(connectionLimit);
-
-            establishedConnections.remove(0).close();
-            getConnectionBuilder().setUsername(USER2).setPassword(USER2_PASSWORD).build().close();
-        }
-        finally
-        {
-            closeConnections(establishedConnections);
-        }
-    }
-
-    @Test
-    public void testAuthorizationWithConnectionFrequencyLimit() throws Exception
-    {
-        final int connectionFrequencyLimit = 1;
-        configureACL(String.format("ACL ALLOW-LOG %s ACCESS VIRTUALHOST connection_frequency_limit='%d'",
-                                   USER2,
-                                   connectionFrequencyLimit));
-
-        final List<Connection> establishedConnections = new ArrayList<>();
-        try
-        {
-            establishConnections(connectionFrequencyLimit, establishedConnections);
-
-            verifyConnectionEstablishmentFails(connectionFrequencyLimit);
-
-            establishedConnections.remove(0).close();
-
-            verifyConnectionEstablishmentFails(connectionFrequencyLimit);
-        }
-        finally
-        {
-            closeConnections(establishedConnections);
-        }
-    }
-
-    @Test
-    public void testAuthorizationWithConnectionLimitAndFrequencyLimit() throws Exception
-    {
-        final int connectionFrequencyLimit = 2;
-        final int connectionLimit = 3;
-        configureACL(String.format("ACL ALLOW-LOG %s ACCESS VIRTUALHOST connection_limit='%d' connection_frequency_limit='%d'",
-                                   USER2,
-                                   connectionLimit,
-                                   connectionFrequencyLimit));
-
-        final List<Connection> establishedConnections = new ArrayList<>();
-        try
-        {
-            establishConnections(connectionFrequencyLimit, establishedConnections);
-
-            verifyConnectionEstablishmentFails(connectionFrequencyLimit);
-
-            establishedConnections.remove(0).close();
-
-            verifyConnectionEstablishmentFails(connectionFrequencyLimit);
-        }
-        finally
-        {
-            closeConnections(establishedConnections);
-        }
-    }
-
-    private void establishConnections(final int connectionNumber, final List<Connection> establishedConnections)
-            throws NamingException, JMSException
-    {
-        for (int i = 0; i < connectionNumber; i++)
-        {
-            establishedConnections.add(getConnectionBuilder().setUsername(USER2)
-                                                             .setPassword(USER2_PASSWORD)
-                                                             .setClientId(getTestName() + i)
-                                                             .build());
-        }
-    }
-
-    private void closeConnections(final List<Connection> establishedConnections) throws JMSException
-    {
-        for (Connection c : establishedConnections)
-        {
-            c.close();
-        }
-    }
-
-    private void verifyConnectionEstablishmentFails(final int frequencyLimit) throws NamingException
-    {
-        try
-        {
-            final Connection connection = getConnectionBuilder().setUsername(USER2)
-                                                                .setPassword(USER2_PASSWORD)
-                                                                .setClientId(getTestName() + frequencyLimit)
-                                                                .build();
-            try
-            {
-                fail("Connection creation should fail due to exceeding limit");
-            }
-            finally
-            {
-                connection.close();
-            }
-        }
-        catch (JMSException e)
-        {
-            //pass
-        }
-    }
-
     @Test
     public void testConsumeFromTempQueueSuccess() throws Exception
     {
@@ -973,40 +848,9 @@ public class MessagingACLTest extends JmsTestBase
         try(StringReader stringReader = new StringReader(Arrays.stream(rules).collect(Collectors.joining(LINE_SEPARATOR))))
         {
             RuleSet ruleSet = AclFileParser.parse(stringReader, eventLoggerProvider);
-            final List<Rule> parsedRules = ruleSet.getAllRules();
-            for(final Rule rule: parsedRules)
+            for (final Rule rule: ruleSet)
             {
-                aclRules.add(new AclRule(){
-                    @Override
-                    public String getIdentity()
-                    {
-                        return rule.getIdentity();
-                    }
-
-                    @Override
-                    public ObjectType getObjectType()
-                    {
-                        return rule.getAction().getObjectType();
-                    }
-
-                    @Override
-                    public LegacyOperation getOperation()
-                    {
-                        return rule.getAction().getOperation();
-                    }
-
-                    @Override
-                    public Map<ObjectProperties.Property, String> getAttributes()
-                    {
-                        return rule.getAttributes();
-                    }
-
-                    @Override
-                    public RuleOutcome getOutcome()
-                    {
-                        return rule.getRuleOutcome();
-                    }
-                });
+                aclRules.add(rule.asAclRule());
             }
         }
 
